# @summary interface network Network section definition
# @see https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html
type Systemd::Interface::Network::Network = Struct[{
    'Description'                        => Optional[String[1]],
    'DHCP'                               => Optional[Enum['yes', 'no', 'ipv4', 'ipv6']],
    'DHCPServer'                         => Optional[Enum['yes', 'no']],
    'LinkLocalAddressing'                => Optional[Enum['yes', 'no', 'ipv4', 'ipv6']],
    'IPv6LinkLocalAddressGenerationMode' => Optional[Enum[
        'eui64', 'none', 'stable-privacy', 'random'
    ]],
    'IPv6StableSecretAddress'            => Optional[String[1]],
    'IPv4LLStartAddress'                 => Optional[String[1]],
    'IPv4LLRoute'                        => Optional[Enum['yes', 'no']],
    'DefaultRouteOnDevice'               => Optional[Enum['yes', 'no']],
    'LLMNR'                              => Optional[Enum['yes', 'no', 'resolve']],
    'MulticastDNS'                       => Optional[Enum['yes', 'no', 'resolve']],
    'DNSOverTLS'                         => Optional[Enum['yes', 'no', 'opportunistic']],
    'DNSSEC'                             => Optional[Enum['yes', 'no', 'allow-downgrade']],
    'DNSSECNegativeTrustAnchors'         => Optional[String[1]],
    'LLDP'                               => Optional[Enum['yes', 'no', 'routers-only']],
    'EmitLLDP'                           => Optional[Enum['yes', 'no', 'nearest-bridge', 'non-tpmr-bridge', 'customer-bridge']],
    'BindCarrier'                        => Optional[String[1]],
    'Address'                            => Optional[Variant[Array[String[1]], String[1]]],
    'Gateway'                            => Optional[Variant[Array[String[1]], String[1]]],
    'DNS'                                => Optional[Variant[Array[String[1]], String[1]]],
    'UseDomains'                         => Optional[Enum['yes', 'no', 'route']],
    'DNSDefaultRoute'                    => Optional[Enum['yes', 'no']],
    'NTP'                                => Optional[Enum['yes', 'no', 'route']],
    'IPv4Forwarding'                     => Optional[Enum['yes', 'no']],
    'IPv6Forwarding'                     => Optional[Enum['yes', 'no']],
    'IPMasquerade'                       => Optional[Enum['ipv4', 'ipv6', 'both', 'no']],
    'IPv6PrivacyExtensions'              => Optional[Enum['yes', 'no', 'prefer-public', 'kernel']],
    'IPv6AcceptRA'                       => Optional[Enum['yes', 'no']],
    'IPv6DuplicateAddressDetection'      => Optional[Integer],
    'IPv6HopLimit'                       => Optional[Integer[1,255]],
    'IPv6RetransmissionTimeSec'          => Optional[Integer[0]],
    'IPv4ReversePathFilter'              => Optional[Enum['no', 'strict', 'loose']],
    'IPv4AcceptLocal'                    => Optional[Enum['yes', 'no']],
    'IPv4RouteLocalnet'                  => Optional[Enum['yes', 'no']],
    'IPv4ProxyARP'                       => Optional[Enum['yes', 'no']],
    'IPv4ProxyARPPrivateVLAN'            => Optional[Enum['yes', 'no']],
    'IPv6ProxyNDP'                       => Optional[Enum['yes', 'no']],
    'IPv6ProxyNDPAddress'                => Optional[Variant[String[1], Array[String[1]]]],
    'IPv6SendRA'                         => Optional[Enum['yes', 'no']],
    'DHCPPrefixDelegation'               => Optional[Enum['yes', 'no']],
    'IPv6MTUBytes'                       => Optional[Integer[1280]],
    'KeepMaster'                         => Optional[Enum['yes', 'no']],
    'BatmanAdvanced'                     => Optional[String[1]],
    'Bond'                               => Optional[String[1]],
    'Bridge'                             => Optional[String[1]],
    'VRF'                                => Optional[String[1]],
    'IPoIB'                              => Optional[Variant[String[1],Array[String[1]]]],
    'IPVLAN'                             => Optional[Variant[String[1],Array[String[1]]]],
    'IPVTAP'                             => Optional[Variant[String[1],Array[String[1]]]],
    'MACsec'                             => Optional[Variant[String[1],Array[String[1]]]],
    'MACVLAN'                            => Optional[Variant[String[1],Array[String[1]]]],
    'MACVTAP'                            => Optional[Variant[String[1],Array[String[1]]]],
    'Tunnel'                             => Optional[Variant[String[1],Array[String[1]]]],
    'VLAN'                               => Optional[Variant[String[1],Array[String[1]]]],
    'VXLAN'                              => Optional[Variant[String[1],Array[String[1]]]],
    'Xfrm'                               => Optional[Variant[String[1],Array[String[1]]]],
    'ActiveSlave'                        => Optional[Enum['yes', 'no']],
    'PrimarySlave'                       => Optional[Enum['yes', 'no']],
    'ConfigureWithoutCarrier'            => Optional[Enum['yes', 'no']],
    # 'IgnoreCarrierLoss'                  => Optional[Variant[Enum['yes', 'no'],Systemd::Unit::Timespan]],
    'KeepConfiguration'                  => Optional[Enum['yes', 'no', 'static', 'dhcp-on-stop', 'dhcp']],
}]
