# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`systemd`](#systemd): This module allows triggering systemd commands once for all modules
* [`systemd::tmpfiles`](#systemd--tmpfiles): Update the systemd temp files

#### Private Classes

* `systemd::coredump`: This class manages the systemd-coredump configuration.
* `systemd::install`: Install any systemd sub packages
* `systemd::journal_remote`: This class manages and configures journal-remote.
* `systemd::journal_upload`: This class manages and configures journal-upload.
* `systemd::journald`: This class manages and configures journald.
* `systemd::logind`: This class manages systemd's login manager configuration.
* `systemd::machine_info`: This class manages systemd's machine-info file (hostnamectl)
* `systemd::modules_loads`: Activate the modules contained in modules-loads.d
* `systemd::networkd`: This class provides an abstract way to trigger systemd-networkd
* `systemd::oomd`: This class manages and configures oomd.
* `systemd::resolved`: This class provides an abstract way to trigger resolved.
* `systemd::service_manager`: This class provides a solution to manage system and/or user service manager settings
* `systemd::timedatectl`: This class provides an abstract way to set elements with timedatectl
* `systemd::timesyncd`: This class provides an abstract way to trigger systemd-timesyncd
* `systemd::udevd`: This class manages systemd's udev config

### Defined types

* [`systemd::daemon_reload`](#systemd--daemon_reload): Run systemctl daemon-reload
* [`systemd::dropin_file`](#systemd--dropin_file): Creates a drop-in file for a systemd unit
* [`systemd::manage_dropin`](#systemd--manage_dropin): Creates a drop-in file for a systemd unit from a template
* [`systemd::manage_unit`](#systemd--manage_unit): Generate unit file from template
* [`systemd::modules_load`](#systemd--modules_load): Creates a modules-load.d drop file
* [`systemd::network`](#systemd--network): Creates network config for systemd-networkd
* [`systemd::service_limits`](#systemd--service_limits): Deprecated - Adds a set of custom limits to the service
* [`systemd::timer`](#systemd--timer): Create a timer and optionally a service unit to execute with the timer unit
* [`systemd::timer_wrapper`](#systemd--timer_wrapper): Helper to define timer and accompanying services for a given task (cron like interface).
* [`systemd::tmpfile`](#systemd--tmpfile): Creates a systemd tmpfile
* [`systemd::udev::rule`](#systemd--udev--rule): Adds a custom udev rule
* [`systemd::unit_file`](#systemd--unit_file): Creates a systemd unit file
* [`systemd::user_service`](#systemd--user_service): Manage a user service running under systemd --user

### Resource types

* [`loginctl_user`](#loginctl_user): An arbitrary name used as the identity of the resource.

### Functions

* [`systemd::escape`](#systemd--escape): Escape strings as systemd-escape does.
* [`systemd::systemd_escape`](#systemd--systemd_escape): Escape strings by call the `systemd-escape` command in the background.

### Data types

* [`Systemd::Boolean`](#Systemd--Boolean): Defines systemd boolean type representation
* [`Systemd::Boolean::False`](#Systemd--Boolean--False): Defines systemd boolean "false" type representation
* [`Systemd::Boolean::True`](#Systemd--Boolean--True): Defines systemd boolean "true" type representation
* [`Systemd::Capabilities`](#Systemd--Capabilities): Defines allowed capabilities
* [`Systemd::CoredumpSettings`](#Systemd--CoredumpSettings): Configurations for coredump.conf
* [`Systemd::Dropin`](#Systemd--Dropin): custom datatype that validates filenames/paths for valid systemd dropin files
* [`Systemd::Interface`](#Systemd--Interface): network interface definition
* [`Systemd::Interface::Link`](#Systemd--Interface--Link): Network device configuration(Link)
* [`Systemd::Interface::Link::Link`](#Systemd--Interface--Link--Link): Network device configuration(Link) Link section definition
* [`Systemd::Interface::Link::Link_advertise`](#Systemd--Interface--Link--Link_advertise): Network device configuration(Link), link advertise speeds
* [`Systemd::Interface::Link::Match`](#Systemd--Interface--Link--Match): Network device configuration(Link) Match section definition
* [`Systemd::Interface::Link::Sr_iov`](#Systemd--Interface--Link--Sr_iov): Network device configuration(Link) SR-IOV section definition
* [`Systemd::Interface::Netdev`](#Systemd--Interface--Netdev): interface netdev configs
* [`Systemd::Interface::Netdev::Bareudp`](#Systemd--Interface--Netdev--Bareudp): netdev BareUDP section
* [`Systemd::Interface::Netdev::Batmanadvanced`](#Systemd--Interface--Netdev--Batmanadvanced): netdev BatmanAdvanced section
* [`Systemd::Interface::Netdev::Bond`](#Systemd--Interface--Netdev--Bond): netdev Bond section
* [`Systemd::Interface::Netdev::Bridge`](#Systemd--Interface--Netdev--Bridge): netdev Bridge section
* [`Systemd::Interface::Netdev::Foooverudp`](#Systemd--Interface--Netdev--Foooverudp): netdev FooOverUDP section
* [`Systemd::Interface::Netdev::Geneve`](#Systemd--Interface--Netdev--Geneve): netdev GENEVE section
* [`Systemd::Interface::Netdev::Ipoib`](#Systemd--Interface--Netdev--Ipoib): netdev IPoIB section
* [`Systemd::Interface::Netdev::Ipvlan`](#Systemd--Interface--Netdev--Ipvlan): netdev IPVLAN and IPVTAP section
* [`Systemd::Interface::Netdev::L2tp`](#Systemd--Interface--Netdev--L2tp): netdev L2TP section
* [`Systemd::Interface::Netdev::L2tpsession`](#Systemd--Interface--Netdev--L2tpsession): netdev L2TPSession section
* [`Systemd::Interface::Netdev::Macsec`](#Systemd--Interface--Netdev--Macsec): netdev MACsec section
* [`Systemd::Interface::Netdev::Macsecreceiveassociation`](#Systemd--Interface--Netdev--Macsecreceiveassociation): netdev MACsecReceiveAssociation section
* [`Systemd::Interface::Netdev::Macsecreceivechannel`](#Systemd--Interface--Netdev--Macsecreceivechannel): netdev MACsecReceiveChannel section
* [`Systemd::Interface::Netdev::Macsectransmitassociation`](#Systemd--Interface--Netdev--Macsectransmitassociation): netdev MACsecTransmitAssociation section
* [`Systemd::Interface::Netdev::Macvlan`](#Systemd--Interface--Netdev--Macvlan): netdev MACVLAN and MACVTAP section
* [`Systemd::Interface::Netdev::Match`](#Systemd--Interface--Netdev--Match): netdev match section
* [`Systemd::Interface::Netdev::Netdev`](#Systemd--Interface--Netdev--Netdev): netdev NetDev section
* [`Systemd::Interface::Netdev::Peer`](#Systemd--Interface--Netdev--Peer): netdev Peer section
* [`Systemd::Interface::Netdev::Tun`](#Systemd--Interface--Netdev--Tun): netdev Tun and Tap section
* [`Systemd::Interface::Netdev::Tunnel`](#Systemd--Interface--Netdev--Tunnel): netdev Tunnel section
* [`Systemd::Interface::Netdev::Vlan`](#Systemd--Interface--Netdev--Vlan): netdev VLAN section
* [`Systemd::Interface::Netdev::Vrf`](#Systemd--Interface--Netdev--Vrf): netdev VRF section
* [`Systemd::Interface::Netdev::Vxcan`](#Systemd--Interface--Netdev--Vxcan): netdev VXCAN section
* [`Systemd::Interface::Netdev::Vxlan`](#Systemd--Interface--Netdev--Vxlan): netdev VXLAN section
* [`Systemd::Interface::Netdev::Wireguard`](#Systemd--Interface--Netdev--Wireguard): netdev WireGuard section
* [`Systemd::Interface::Netdev::Wireguardpeer`](#Systemd--Interface--Netdev--Wireguardpeer): netdev WireGuard section
* [`Systemd::Interface::Netdev::Wlan`](#Systemd--Interface--Netdev--Wlan): netdev WLAN section
* [`Systemd::Interface::Netdev::Xfrm`](#Systemd--Interface--Netdev--Xfrm): netdev Xfrm section
* [`Systemd::Interface::Network`](#Systemd--Interface--Network): interface definition
* [`Systemd::Interface::Network::Address`](#Systemd--Interface--Network--Address): interface network Address section definition
* [`Systemd::Interface::Network::Bfifo`](#Systemd--Interface--Network--Bfifo): interface network BFIFO section definition
* [`Systemd::Interface::Network::Bridge`](#Systemd--Interface--Network--Bridge): interface network Bridge section definition
* [`Systemd::Interface::Network::Bridgefdb`](#Systemd--Interface--Network--Bridgefdb): interface network BridgeFDB section definition
* [`Systemd::Interface::Network::Bridgemdb`](#Systemd--Interface--Network--Bridgemdb): interface network BridgeMDB section definition
* [`Systemd::Interface::Network::Bridgevlan`](#Systemd--Interface--Network--Bridgevlan): interface network BridgeVLAN section definition
* [`Systemd::Interface::Network::Cake`](#Systemd--Interface--Network--Cake): interface network CAKE section definition
* [`Systemd::Interface::Network::Can`](#Systemd--Interface--Network--Can): interface network CAN section definition
* [`Systemd::Interface::Network::Controlleddelay`](#Systemd--Interface--Network--Controlleddelay): interface network ControlledDelay section definition
* [`Systemd::Interface::Network::Deficitroundrobinscheduler`](#Systemd--Interface--Network--Deficitroundrobinscheduler): interface network DeficitRoundRobinScheduler section definition
* [`Systemd::Interface::Network::Deficitroundrobinschedulerclass`](#Systemd--Interface--Network--Deficitroundrobinschedulerclass): interface network DeficitRoundRobinSchedulerClass section definition
* [`Systemd::Interface::Network::Dhcpprefixdelegation`](#Systemd--Interface--Network--Dhcpprefixdelegation): interface network DHCPPrefixDelegation section definition
* [`Systemd::Interface::Network::Dhcpserver`](#Systemd--Interface--Network--Dhcpserver): interface network DHCPServer section definition
* [`Systemd::Interface::Network::Dhcpserverstaticlease`](#Systemd--Interface--Network--Dhcpserverstaticlease): interface network DHCPServerStaticLease section definition
* [`Systemd::Interface::Network::Dhcpv4`](#Systemd--Interface--Network--Dhcpv4): interface network DHCPv4 section definition
* [`Systemd::Interface::Network::Dhcpv6`](#Systemd--Interface--Network--Dhcpv6): interface network DHCPv6 section definition
* [`Systemd::Interface::Network::Enhancedtransmissionselection`](#Systemd--Interface--Network--Enhancedtransmissionselection): interface network EnhancedTransmissionSelection section definition
* [`Systemd::Interface::Network::Fairqueueing`](#Systemd--Interface--Network--Fairqueueing): interface network FairQueueing section definition
* [`Systemd::Interface::Network::Fairqueueingcontrolleddelay`](#Systemd--Interface--Network--Fairqueueingcontrolleddelay): interface network FairQueueingControlledDelay section definition
* [`Systemd::Interface::Network::Flowqueuepie`](#Systemd--Interface--Network--Flowqueuepie): interface network FlowQueuePIE section definition
* [`Systemd::Interface::Network::Genericrandomearlydetection`](#Systemd--Interface--Network--Genericrandomearlydetection): interface network GenericRandomEarlyDetection section definition
* [`Systemd::Interface::Network::Heavyhitterfilter`](#Systemd--Interface--Network--Heavyhitterfilter): interface network HeavyHitterFilter section definition
* [`Systemd::Interface::Network::Hierarchytokenbucket`](#Systemd--Interface--Network--Hierarchytokenbucket): interface network HierarchyTokenBucketClass section definition
* [`Systemd::Interface::Network::Hierarchytokenbucketclass`](#Systemd--Interface--Network--Hierarchytokenbucketclass): interface network HierarchyTokenBucketClass section definition
* [`Systemd::Interface::Network::Ipoib`](#Systemd--Interface--Network--Ipoib): interface network IPoIB section definition
* [`Systemd::Interface::Network::Ipv6acceptra`](#Systemd--Interface--Network--Ipv6acceptra): interface network IPv6AcceptRA section definition
* [`Systemd::Interface::Network::Ipv6addresslabel`](#Systemd--Interface--Network--Ipv6addresslabel): interface network IPv6AddressLabel section definition
* [`Systemd::Interface::Network::Ipv6pref64prefix`](#Systemd--Interface--Network--Ipv6pref64prefix): interface network IPv6PREF64Prefix section definition
* [`Systemd::Interface::Network::Ipv6prefix`](#Systemd--Interface--Network--Ipv6prefix): interface network IPv6Prefix section definition
* [`Systemd::Interface::Network::Ipv6routeprefix`](#Systemd--Interface--Network--Ipv6routeprefix): interface network IPv6RoutePrefix section definition
* [`Systemd::Interface::Network::Ipv6sendra`](#Systemd--Interface--Network--Ipv6sendra): interface network IPv6SendRA section definition
* [`Systemd::Interface::Network::Link`](#Systemd--Interface--Network--Link): interface network Link section definition
* [`Systemd::Interface::Network::Lldp`](#Systemd--Interface--Network--Lldp): interface network LLDP section definition
* [`Systemd::Interface::Network::Match`](#Systemd--Interface--Network--Match): interface network Match section definition
* [`Systemd::Interface::Network::Neighbor`](#Systemd--Interface--Network--Neighbor): interface network Neighbor section definition
* [`Systemd::Interface::Network::Network`](#Systemd--Interface--Network--Network): interface network Network section definition
* [`Systemd::Interface::Network::Networkemulator`](#Systemd--Interface--Network--Networkemulator): interface network NetworkEmulator section definition
* [`Systemd::Interface::Network::Nexthop`](#Systemd--Interface--Network--Nexthop): interface network NextHop section definition
* [`Systemd::Interface::Network::Pfifo`](#Systemd--Interface--Network--Pfifo): interface network PFIFO section definition
* [`Systemd::Interface::Network::Pfifofast`](#Systemd--Interface--Network--Pfifofast): interface network PFIFOFast section definition
* [`Systemd::Interface::Network::Pfifoheaddrop`](#Systemd--Interface--Network--Pfifoheaddrop): interface network PFIFOHeadDrop section definition
* [`Systemd::Interface::Network::Pie`](#Systemd--Interface--Network--Pie): interface network PIE section definition
* [`Systemd::Interface::Network::Qdisc`](#Systemd--Interface--Network--Qdisc): interface network QDisc section definition
* [`Systemd::Interface::Network::Quickfairqueueing`](#Systemd--Interface--Network--Quickfairqueueing): interface network QuickFairQueueingClass section definition
* [`Systemd::Interface::Network::Quickfairqueueingclass`](#Systemd--Interface--Network--Quickfairqueueingclass): interface network QuickFairQueueingClass section definition
* [`Systemd::Interface::Network::Route`](#Systemd--Interface--Network--Route): interface network Route section definition
* [`Systemd::Interface::Network::Routingpolicyrule`](#Systemd--Interface--Network--Routingpolicyrule): interface network RoutingPolicyRule section definition
* [`Systemd::Interface::Network::Sr_iov`](#Systemd--Interface--Network--Sr_iov): interface network SR-IOV section definition
* [`Systemd::Interface::Network::Stochasticfairblue`](#Systemd--Interface--Network--Stochasticfairblue): interface network StochasticFairBlue section definition
* [`Systemd::Interface::Network::Stochasticfairnessqueueing`](#Systemd--Interface--Network--Stochasticfairnessqueueing): interface network StochasticFairnessQueueing section definition
* [`Systemd::Interface::Network::Tokenbucketfilter`](#Systemd--Interface--Network--Tokenbucketfilter): interface network TokenBucketFilter section definition
* [`Systemd::Interface::Network::Triviallinkequalizer`](#Systemd--Interface--Network--Triviallinkequalizer): interface network TrivialLinkEqualizer section definition
* [`Systemd::JournalRemoteSettings`](#Systemd--JournalRemoteSettings): matches Systemd journal remote config Struct
* [`Systemd::JournalUploadSettings`](#Systemd--JournalUploadSettings): matches Systemd journal upload config Struct
* [`Systemd::JournaldSettings`](#Systemd--JournaldSettings): Matches Systemd journald config Struct
* [`Systemd::JournaldSettings::Ensure`](#Systemd--JournaldSettings--Ensure): defines allowed ensure states for systemd-journald settings
* [`Systemd::LogLevel`](#Systemd--LogLevel): Defines allowed log levels
* [`Systemd::LogindSettings`](#Systemd--LogindSettings): Matches Systemd Login Manager Struct
* [`Systemd::LogindSettings::Ensure`](#Systemd--LogindSettings--Ensure): defines allowed ensure states for systemd-logind settings
* [`Systemd::MachineInfoSettings`](#Systemd--MachineInfoSettings): Matches Systemd machine-info (hostnamectl) file Struct
* [`Systemd::OomdSettings`](#Systemd--OomdSettings): Configurations for oomd.conf
* [`Systemd::Output`](#Systemd--Output): Defines allowed output values
* [`Systemd::ServiceLimits`](#Systemd--ServiceLimits): Deprecated - Matches Systemd Service Limit Struct
* [`Systemd::ServiceManagerSettings`](#Systemd--ServiceManagerSettings): Matches Systemd system.conf/user.conf settings
* [`Systemd::SettingEnsure`](#Systemd--SettingEnsure): Defines allowed ensure states for an ini_setting
* [`Systemd::Timespan`](#Systemd--Timespan): Defines a timespan type
* [`Systemd::Unit`](#Systemd--Unit): custom datatype that validates different filenames for systemd units and unit templates
* [`Systemd::Unit::Amount`](#Systemd--Unit--Amount): Systemd definition of amount, often bytes or united bytes
* [`Systemd::Unit::AmountOrPercent`](#Systemd--Unit--AmountOrPercent): Systemd definition of amount, often bytes or united bytes
* [`Systemd::Unit::Install`](#Systemd--Unit--Install): Possible keys for the [Install] section of a unit file
* [`Systemd::Unit::Mount`](#Systemd--Unit--Mount): Possible keys for the [Mount] section of a unit file
* [`Systemd::Unit::Path`](#Systemd--Unit--Path): Possible keys for the [Path] section of a unit file
* [`Systemd::Unit::Percent`](#Systemd--Unit--Percent): Systemd definition of a percentage
* [`Systemd::Unit::Service`](#Systemd--Unit--Service): Possible keys for the [Service] section of a unit file
* [`Systemd::Unit::Service::Exec`](#Systemd--Unit--Service--Exec): Possible strings for ExecStart, ExecStartPrep, ...
* [`Systemd::Unit::Slice`](#Systemd--Unit--Slice): Possible keys for the [Slice] section of a unit file
* [`Systemd::Unit::Socket`](#Systemd--Unit--Socket): Possible keys for the [Socket] section of a unit file
* [`Systemd::Unit::Swap`](#Systemd--Unit--Swap): Possible keys for the [Swap] section of a unit file
* [`Systemd::Unit::Timer`](#Systemd--Unit--Timer): Possible keys for the [Timer] section of a unit file
* [`Systemd::Unit::Timespan`](#Systemd--Unit--Timespan): Timer specification for systemd time spans, e.g. timers.
* [`Systemd::Unit::Unit`](#Systemd--Unit--Unit): Possible keys for the [Unit] section of a unit file

### Tasks

* [`systemctl_show`](#systemctl_show): Get systemctl show output of a unit

## Classes

### <a name="systemd"></a>`systemd`

This module allows triggering systemd commands once for all modules

#### Parameters

The following parameters are available in the `systemd` class:

* [`default_target`](#-systemd--default_target)
* [`service_limits`](#-systemd--service_limits)
* [`networks`](#-systemd--networks)
* [`timers`](#-systemd--timers)
* [`tmpfiles`](#-systemd--tmpfiles)
* [`unit_files`](#-systemd--unit_files)
* [`manage_resolved`](#-systemd--manage_resolved)
* [`resolved_ensure`](#-systemd--resolved_ensure)
* [`resolved_package`](#-systemd--resolved_package)
* [`resolved_libraries`](#-systemd--resolved_libraries)
* [`manage_nspawn`](#-systemd--manage_nspawn)
* [`nspawn_package`](#-systemd--nspawn_package)
* [`dns`](#-systemd--dns)
* [`fallback_dns`](#-systemd--fallback_dns)
* [`domains`](#-systemd--domains)
* [`llmnr`](#-systemd--llmnr)
* [`multicast_dns`](#-systemd--multicast_dns)
* [`dnssec`](#-systemd--dnssec)
* [`dnsovertls`](#-systemd--dnsovertls)
* [`cache`](#-systemd--cache)
* [`dns_stub_listener`](#-systemd--dns_stub_listener)
* [`dns_stub_listener_extra`](#-systemd--dns_stub_listener_extra)
* [`manage_resolv_conf`](#-systemd--manage_resolv_conf)
* [`use_stub_resolver`](#-systemd--use_stub_resolver)
* [`manage_networkd`](#-systemd--manage_networkd)
* [`networkd_ensure`](#-systemd--networkd_ensure)
* [`networkd_package`](#-systemd--networkd_package)
* [`manage_timesyncd`](#-systemd--manage_timesyncd)
* [`timesyncd_ensure`](#-systemd--timesyncd_ensure)
* [`timesyncd_package`](#-systemd--timesyncd_package)
* [`ntp_server`](#-systemd--ntp_server)
* [`fallback_ntp_server`](#-systemd--fallback_ntp_server)
* [`timezone`](#-systemd--timezone)
* [`set_local_rtc`](#-systemd--set_local_rtc)
* [`manage_journald`](#-systemd--manage_journald)
* [`journald_settings`](#-systemd--journald_settings)
* [`manage_journal_upload`](#-systemd--manage_journal_upload)
* [`journal_upload_settings`](#-systemd--journal_upload_settings)
* [`manage_journal_remote`](#-systemd--manage_journal_remote)
* [`journal_remote_settings`](#-systemd--journal_remote_settings)
* [`manage_udevd`](#-systemd--manage_udevd)
* [`udev_log`](#-systemd--udev_log)
* [`udev_children_max`](#-systemd--udev_children_max)
* [`udev_exec_delay`](#-systemd--udev_exec_delay)
* [`udev_event_timeout`](#-systemd--udev_event_timeout)
* [`udev_resolve_names`](#-systemd--udev_resolve_names)
* [`udev_timeout_signal`](#-systemd--udev_timeout_signal)
* [`udev_rules`](#-systemd--udev_rules)
* [`udev_reload`](#-systemd--udev_reload)
* [`machine_info_settings`](#-systemd--machine_info_settings)
* [`manage_logind`](#-systemd--manage_logind)
* [`logind_settings`](#-systemd--logind_settings)
* [`loginctl_users`](#-systemd--loginctl_users)
* [`dropin_files`](#-systemd--dropin_files)
* [`manage_units`](#-systemd--manage_units)
* [`manage_dropins`](#-systemd--manage_dropins)
* [`manage_all_network_files`](#-systemd--manage_all_network_files)
* [`network_path`](#-systemd--network_path)
* [`manage_accounting`](#-systemd--manage_accounting)
* [`accounting`](#-systemd--accounting)
* [`purge_dropin_dirs`](#-systemd--purge_dropin_dirs)
* [`manage_coredump`](#-systemd--manage_coredump)
* [`coredump_settings`](#-systemd--coredump_settings)
* [`coredump_backtrace`](#-systemd--coredump_backtrace)
* [`manage_oomd`](#-systemd--manage_oomd)
* [`oomd_package`](#-systemd--oomd_package)
* [`oomd_ensure`](#-systemd--oomd_ensure)
* [`oomd_settings`](#-systemd--oomd_settings)
* [`udev_purge_rules`](#-systemd--udev_purge_rules)
* [`manage_system_conf`](#-systemd--manage_system_conf)
* [`system_settings`](#-systemd--system_settings)
* [`manage_user_conf`](#-systemd--manage_user_conf)
* [`user_settings`](#-systemd--user_settings)

##### <a name="-systemd--default_target"></a>`default_target`

Data type: `Optional[Pattern['^.+\.target$']]`

The default systemd boot target, unmanaged if set to undef.

Default value: `undef`

##### <a name="-systemd--service_limits"></a>`service_limits`

Data type: `Stdlib::CreateResources`

Deprecated, use dropin_files - Hash of `systemd::service_limits` resources

Default value: `{}`

##### <a name="-systemd--networks"></a>`networks`

Data type: `Stdlib::CreateResources`

Hash of `systemd::network` resources

Default value: `{}`

##### <a name="-systemd--timers"></a>`timers`

Data type: `Stdlib::CreateResources`

Hash of `systemd::timer` resources

Default value: `{}`

##### <a name="-systemd--tmpfiles"></a>`tmpfiles`

Data type: `Stdlib::CreateResources`

Hash of `systemd::tmpfile` resources

Default value: `{}`

##### <a name="-systemd--unit_files"></a>`unit_files`

Data type: `Stdlib::CreateResources`

Hash of `systemd::unit_file` resources

Default value: `{}`

##### <a name="-systemd--manage_resolved"></a>`manage_resolved`

Data type: `Boolean`

Manage the systemd resolver

Default value: `false`

##### <a name="-systemd--resolved_ensure"></a>`resolved_ensure`

Data type: `Enum['stopped','running']`

The state that the ``resolved`` service should be in. When migrating from 'running' to
'stopped' an attempt will be made to restore a working `/etc/resolv.conf` using
`/run/systemd/resolve/resolv.conf`.

Default value: `'running'`

##### <a name="-systemd--resolved_package"></a>`resolved_package`

Data type: `Optional[Enum['systemd-resolved']]`

The name of a systemd sub package needed for systemd-resolved if one needs to be installed.

Default value: `undef`

##### <a name="-systemd--resolved_libraries"></a>`resolved_libraries`

Data type: `Array[String[1]]`

List of library packages needed for systemd-resolved.

Default value: `[]`

##### <a name="-systemd--manage_nspawn"></a>`manage_nspawn`

Data type: `Boolean`

Manage the systemd-nspawn@service and machinectl subsystem.

Default value: `false`

##### <a name="-systemd--nspawn_package"></a>`nspawn_package`

Data type: `Optional[Enum['systemd-container']]`

The name of a systemd sub package needed for the nspawn tools machinectl and
systemd-nspawn if one needs to be installed.

Default value: `undef`

##### <a name="-systemd--dns"></a>`dns`

Data type: `Optional[Variant[Array[String],String]]`

A space-separated list of IPv4 and IPv6 addresses to use as system DNS servers.
DNS requests are sent to one of the listed DNS servers in parallel to suitable
per-link DNS servers acquired from systemd-networkd.service(8) or set at runtime
by external applications. requires puppetlabs-inifile

Default value: `undef`

##### <a name="-systemd--fallback_dns"></a>`fallback_dns`

Data type: `Optional[Variant[Array[String],String]]`

A space-separated list of IPv4 and IPv6 addresses to use as the fallback DNS
servers. Any per-link DNS servers obtained from systemd-networkd take
precedence over this setting. requires puppetlabs-inifile

Default value: `undef`

##### <a name="-systemd--domains"></a>`domains`

Data type: `Optional[Variant[Array[String],String]]`

A space-separated list of domains host names or IP addresses to be used
systemd-resolved take precedence over this setting.

Default value: `undef`

##### <a name="-systemd--llmnr"></a>`llmnr`

Data type: `Optional[Variant[Boolean,Enum['resolve']]]`

Takes a boolean argument or "resolve".

Default value: `undef`

##### <a name="-systemd--multicast_dns"></a>`multicast_dns`

Data type: `Optional[Variant[Boolean,Enum['resolve']]]`

Takes a boolean argument or "resolve".

Default value: `undef`

##### <a name="-systemd--dnssec"></a>`dnssec`

Data type: `Optional[Variant[Boolean,Enum['allow-downgrade']]]`

Takes a boolean argument or "allow-downgrade".

Default value: `undef`

##### <a name="-systemd--dnsovertls"></a>`dnsovertls`

Data type: `Variant[Boolean,Enum['yes', 'opportunistic', 'no']]`

Takes a boolean argument or one of "yes", "opportunistic" or "no". "true" corresponds to
"opportunistic" and "false" (default) to "no".

Default value: `false`

##### <a name="-systemd--cache"></a>`cache`

Data type: `Optional[Variant[Boolean,Enum['no-negative']]]`

Takes a boolean argument or "no-negative". If left `undef` the cache setting will not be modified.

Default value: `undef`

##### <a name="-systemd--dns_stub_listener"></a>`dns_stub_listener`

Data type: `Optional[Variant[Boolean,Enum['udp','tcp','absent']]]`

Takes a boolean argument or one of "udp" and "tcp".
Setting it to `'absent'` will remove `DNSStubListener` existing entries from the configuration file

Default value: `undef`

##### <a name="-systemd--dns_stub_listener_extra"></a>`dns_stub_listener_extra`

Data type: `Optional[Variant[Array[String[1]],Enum['absent']]]`

Additional addresses for the DNS stub listener to listen on
Setting it to `'absent'` will remove `DNSStubListenerExtra` existing entries from the configuration file

Default value: `undef`

##### <a name="-systemd--manage_resolv_conf"></a>`manage_resolv_conf`

Data type: `Boolean`

For when `manage_resolved` is `true` should the file `/etc/resolv.conf` be managed.

Default value: `true`

##### <a name="-systemd--use_stub_resolver"></a>`use_stub_resolver`

Data type: `Boolean`

Takes a boolean argument. When "false" (default) it uses /run/systemd/resolve/resolv.conf
as /etc/resolv.conf. When "true", it uses /run/systemd/resolve/stub-resolv.conf
When `resolved_ensure` is `stopped` this parameter is ignored.

Default value: `false`

##### <a name="-systemd--manage_networkd"></a>`manage_networkd`

Data type: `Boolean`

Manage the systemd network daemon

Default value: `false`

##### <a name="-systemd--networkd_ensure"></a>`networkd_ensure`

Data type: `Enum['stopped','running']`

The state that the ``networkd`` service should be in

Default value: `'running'`

##### <a name="-systemd--networkd_package"></a>`networkd_package`

Data type: `Optional[String[1]]`

Name of the package required for systemd-networkd, if any

Default value: `undef`

##### <a name="-systemd--manage_timesyncd"></a>`manage_timesyncd`

Data type: `Boolean`

Manage the systemd timesyncd daemon

Default value: `false`

##### <a name="-systemd--timesyncd_ensure"></a>`timesyncd_ensure`

Data type: `Enum['stopped','running']`

The state that the ``timesyncd`` service should be in

Default value: `'running'`

##### <a name="-systemd--timesyncd_package"></a>`timesyncd_package`

Data type: `Optional[String[1]]`

Name of the package required for systemd-timesyncd, if any

Default value: `undef`

##### <a name="-systemd--ntp_server"></a>`ntp_server`

Data type: `Optional[Variant[Array,String]]`

comma separated list of ntp servers, will be combined with interface specific
addresses from systemd-networkd. requires puppetlabs-inifile

Default value: `undef`

##### <a name="-systemd--fallback_ntp_server"></a>`fallback_ntp_server`

Data type: `Optional[Variant[Array,String]]`

A space-separated list of NTP server host names or IP addresses to be used
as the fallback NTP servers. Any per-interface NTP servers obtained from
systemd-networkd take precedence over this setting. requires puppetlabs-inifile

Default value: `undef`

##### <a name="-systemd--timezone"></a>`timezone`

Data type: `Optional[String[1]]`

Set the system time zone to the specified value.
Available timezones can be listed with list-timezones.
If the RTC is configured to be in the local time, this will also update
the RTC time. This call will alter the /etc/localtime symlink.

Default value: `undef`

##### <a name="-systemd--set_local_rtc"></a>`set_local_rtc`

Data type: `Optional[Boolean]`

Takes a boolean argument. If "false", the system is configured to maintain
the RTC in universal time.
If "true", it will maintain the RTC in local time instead.
Note that maintaining the RTC in the local timezone is not fully supported
and will create various problems with time zone changes and daylight saving
adjustments. If at all possible, keep the RTC in UTC mode.

Default value: `undef`

##### <a name="-systemd--manage_journald"></a>`manage_journald`

Data type: `Boolean`

Manage the systemd journald

Default value: `true`

##### <a name="-systemd--journald_settings"></a>`journald_settings`

Data type: `Systemd::JournaldSettings`

Config Hash that is used to configure settings in journald.conf

Default value: `{}`

##### <a name="-systemd--manage_journal_upload"></a>`manage_journal_upload`

Data type: `Boolean`

Manage the systemd journal upload to a remote server

Default value: `false`

##### <a name="-systemd--journal_upload_settings"></a>`journal_upload_settings`

Data type: `Systemd::JournalUploadSettings`

Config Hash that is used to configure settings in journal-upload.conf

Default value: `{}`

##### <a name="-systemd--manage_journal_remote"></a>`manage_journal_remote`

Data type: `Boolean`

Manage the systemd journal remote server used to upload journals

Default value: `false`

##### <a name="-systemd--journal_remote_settings"></a>`journal_remote_settings`

Data type: `Systemd::JournalRemoteSettings`

Config Hash that is used to configure settings in journal-remote.conf

Default value: `{}`

##### <a name="-systemd--manage_udevd"></a>`manage_udevd`

Data type: `Boolean`

Manage the systemd udev daemon

Default value: `false`

##### <a name="-systemd--udev_log"></a>`udev_log`

Data type: `Optional[Variant[Integer,String]]`

The value of /etc/udev/udev.conf udev_log

Default value: `undef`

##### <a name="-systemd--udev_children_max"></a>`udev_children_max`

Data type: `Optional[Integer]`

The value of /etc/udev/udev.conf children_max

Default value: `undef`

##### <a name="-systemd--udev_exec_delay"></a>`udev_exec_delay`

Data type: `Optional[Integer]`

The value of /etc/udev/udev.conf exec_delay

Default value: `undef`

##### <a name="-systemd--udev_event_timeout"></a>`udev_event_timeout`

Data type: `Optional[Integer]`

The value of /etc/udev/udev.conf event_timeout

Default value: `undef`

##### <a name="-systemd--udev_resolve_names"></a>`udev_resolve_names`

Data type: `Optional[Enum['early', 'late', 'never']]`

The value of /etc/udev/udev.conf resolve_names

Default value: `undef`

##### <a name="-systemd--udev_timeout_signal"></a>`udev_timeout_signal`

Data type: `Optional[Variant[Integer,String]]`

The value of /etc/udev/udev.conf timeout_signal

Default value: `undef`

##### <a name="-systemd--udev_rules"></a>`udev_rules`

Data type: `Stdlib::CreateResources`

Config Hash that is used to generate instances of our
`udev::rule` define.

Default value: `{}`

##### <a name="-systemd--udev_reload"></a>`udev_reload`

Data type: `Boolean`

Whether udev rules should be automatically reloaded upon change.

Default value: `false`

##### <a name="-systemd--machine_info_settings"></a>`machine_info_settings`

Data type: `Systemd::MachineInfoSettings`

Settings to place into /etc/machine-info (hostnamectl)

Default value: `{}`

##### <a name="-systemd--manage_logind"></a>`manage_logind`

Data type: `Boolean`

Manage the systemd logind

Default value: `false`

##### <a name="-systemd--logind_settings"></a>`logind_settings`

Data type: `Systemd::LogindSettings`

Config Hash that is used to configure settings in logind.conf

Default value: `{}`

##### <a name="-systemd--loginctl_users"></a>`loginctl_users`

Data type: `Stdlib::CreateResources`

Config Hash that is used to generate instances of our type
`loginctl_user`.

Default value: `{}`

##### <a name="-systemd--dropin_files"></a>`dropin_files`

Data type: `Stdlib::CreateResources`

Configure dropin files via hiera and `systemd::dropin_file` with factory pattern

Default value: `{}`

##### <a name="-systemd--manage_units"></a>`manage_units`

Data type: `Stdlib::CreateResources`

Configure units via hiera and `systemd::manage_unit` with factory pattern

Default value: `{}`

##### <a name="-systemd--manage_dropins"></a>`manage_dropins`

Data type: `Stdlib::CreateResources`

Configure dropin files via hiera and `systemd::manage_dropin` with factory pattern

Default value: `{}`

##### <a name="-systemd--manage_all_network_files"></a>`manage_all_network_files`

Data type: `Boolean`



Default value: `false`

##### <a name="-systemd--network_path"></a>`network_path`

Data type: `Stdlib::Absolutepath`

where all networkd files are placed in

Default value: `'/etc/systemd/network'`

##### <a name="-systemd--manage_accounting"></a>`manage_accounting`

Data type: `Boolean`

When enabled, the different accounting options (network traffic, IO,
CPU util...) are enabled for units.

Default value: `false`

##### <a name="-systemd--accounting"></a>`accounting`

Data type: `Hash[String,String]`

Hash of the different accounting options. This highly depends on the used
systemd version. The module provides sane defaults per operating system
using Hiera.

Default value: `{}`

##### <a name="-systemd--purge_dropin_dirs"></a>`purge_dropin_dirs`

Data type: `Boolean`

When enabled, unused directories for dropin files will be purged

Default value: `true`

##### <a name="-systemd--manage_coredump"></a>`manage_coredump`

Data type: `Boolean`

Should systemd-coredump configuration be managed

Default value: `false`

##### <a name="-systemd--coredump_settings"></a>`coredump_settings`

Data type: `Systemd::CoredumpSettings`

Hash of systemd-coredump configurations for coredump.conf

Default value: `{}`

##### <a name="-systemd--coredump_backtrace"></a>`coredump_backtrace`

Data type: `Boolean`

Add --backtrace to systemd-coredump call systemd-coredump@.service unit

Default value: `false`

##### <a name="-systemd--manage_oomd"></a>`manage_oomd`

Data type: `Boolean`

Should systemd-oomd configuration be managed

Default value: `false`

##### <a name="-systemd--oomd_package"></a>`oomd_package`

Data type: `Optional[String[1]]`

Name of the package required for systemd-oomd, if any

Default value: `undef`

##### <a name="-systemd--oomd_ensure"></a>`oomd_ensure`

Data type: `Enum['stopped','running']`

The state that the ``oomd`` service should be in

Default value: `'running'`

##### <a name="-systemd--oomd_settings"></a>`oomd_settings`

Data type: `Systemd::OomdSettings`

Hash of systemd-oomd configurations for oomd.conf

Default value: `{}`

##### <a name="-systemd--udev_purge_rules"></a>`udev_purge_rules`

Data type: `Boolean`

Toggle if unmanaged files in /etc/udev/rules.d should be purged if manage_udevd is enabled

Default value: `false`

##### <a name="-systemd--manage_system_conf"></a>`manage_system_conf`

Data type: `Boolean`

Should system service manager configurations be managed

Default value: `false`

##### <a name="-systemd--system_settings"></a>`system_settings`

Data type: `Systemd::ServiceManagerSettings`

Config Hash that is used to configure settings in system.conf
NOTE: It's currently impossible to have multiple entries of the same key in
the settings.

Default value: `{}`

##### <a name="-systemd--manage_user_conf"></a>`manage_user_conf`

Data type: `Boolean`

Should user service manager configurations be managed

Default value: `false`

##### <a name="-systemd--user_settings"></a>`user_settings`

Data type: `Systemd::ServiceManagerSettings`

Config Hash that is used to configure settings in user.conf
NOTE: It's currently impossible to have multiple entries of the same key in
the settings.

Default value: `{}`

### <a name="systemd--tmpfiles"></a>`systemd::tmpfiles`

Update the systemd temp files

* **See also**
  * systemd-tmpfiles(8)

#### Parameters

The following parameters are available in the `systemd::tmpfiles` class:

* [`operations`](#-systemd--tmpfiles--operations)

##### <a name="-systemd--tmpfiles--operations"></a>`operations`

Data type: `Array[Enum['create','clean','remove']]`

The operations to perform on the systemd tempfiles

* All operations may be combined but you'll probably only ever want to
  use ``create``

Default value: `['create']`

## Defined types

### <a name="systemd--daemon_reload"></a>`systemd::daemon_reload`

Run systemctl daemon-reload

#### Examples

##### Force reload the system systemd

```puppet
notify{ 'fake event to notify from':
  notify => Systemd::Daemon_reload['special']
}
systemd::daemon_reload{ 'special': }
```

##### Force reload a systemd --user

```puppet
notify{ 'fake event to notify from':
  notify => Systemd::Daemon_reload['steve_user']
}
systemd::daemon_reload{ 'steve_user':
  user => 'steve',
}
```

#### Parameters

The following parameters are available in the `systemd::daemon_reload` defined type:

* [`name`](#-systemd--daemon_reload--name)
* [`enable`](#-systemd--daemon_reload--enable)
* [`user`](#-systemd--daemon_reload--user)

##### <a name="-systemd--daemon_reload--name"></a>`name`

A globally unique name for the resource

##### <a name="-systemd--daemon_reload--enable"></a>`enable`

Data type: `Boolean`

Enable the reload exec
* Added in case users want to disable the reload globally using a resource collector

Default value: `true`

##### <a name="-systemd--daemon_reload--user"></a>`user`

Data type: `Optional[String[1]]`

Specify user name of `systemd --user` to reload. This not supported **below** Redhat 9,
Ubuntu 22.04 or Debian 12.

Default value: `undef`

### <a name="systemd--dropin_file"></a>`systemd::dropin_file`

Creates a drop-in file for a systemd unit

* **See also**
  * systemd.unit(5)

#### Parameters

The following parameters are available in the `systemd::dropin_file` defined type:

* [`unit`](#-systemd--dropin_file--unit)
* [`filename`](#-systemd--dropin_file--filename)
* [`ensure`](#-systemd--dropin_file--ensure)
* [`path`](#-systemd--dropin_file--path)
* [`selinux_ignore_defaults`](#-systemd--dropin_file--selinux_ignore_defaults)
* [`content`](#-systemd--dropin_file--content)
* [`source`](#-systemd--dropin_file--source)
* [`target`](#-systemd--dropin_file--target)
* [`owner`](#-systemd--dropin_file--owner)
* [`group`](#-systemd--dropin_file--group)
* [`mode`](#-systemd--dropin_file--mode)
* [`show_diff`](#-systemd--dropin_file--show_diff)
* [`notify_service`](#-systemd--dropin_file--notify_service)
* [`daemon_reload`](#-systemd--dropin_file--daemon_reload)

##### <a name="-systemd--dropin_file--unit"></a>`unit`

Data type: `Systemd::Unit`

The target unit file to create

##### <a name="-systemd--dropin_file--filename"></a>`filename`

Data type: `Systemd::Dropin`

The filename of the drop in. The full path is determined using the path, unit and this filename.

Default value: `$name`

##### <a name="-systemd--dropin_file--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'file']`

the state of this dropin file

Default value: `'present'`

##### <a name="-systemd--dropin_file--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The main systemd configuration path

Default value: `'/etc/systemd/system'`

##### <a name="-systemd--dropin_file--selinux_ignore_defaults"></a>`selinux_ignore_defaults`

Data type: `Boolean`

If Puppet should ignore the default SELinux labels.

Default value: `false`

##### <a name="-systemd--dropin_file--content"></a>`content`

Data type: `Optional[Variant[String,Sensitive[String]]]`

The full content of the unit file (Mutually exclusive with `$source`)

Default value: `undef`

##### <a name="-systemd--dropin_file--source"></a>`source`

Data type: `Optional[String]`

The `File` resource compatible `source` Mutually exclusive with ``$content``

Default value: `undef`

##### <a name="-systemd--dropin_file--target"></a>`target`

Data type: `Optional[Stdlib::Absolutepath]`

If set, will force the file to be a symlink to the given target (Mutually exclusive with both `$source` and `$content`

Default value: `undef`

##### <a name="-systemd--dropin_file--owner"></a>`owner`

Data type: `String`

The owner to set on the dropin file

Default value: `'root'`

##### <a name="-systemd--dropin_file--group"></a>`group`

Data type: `String`

The group to set on the dropin file

Default value: `'root'`

##### <a name="-systemd--dropin_file--mode"></a>`mode`

Data type: `String`

The mode to set on the dropin file

Default value: `'0444'`

##### <a name="-systemd--dropin_file--show_diff"></a>`show_diff`

Data type: `Boolean`

Whether to show the diff when updating dropin file

Default value: `true`

##### <a name="-systemd--dropin_file--notify_service"></a>`notify_service`

Data type: `Boolean`

Notify a service for the unit, if it exists

Default value: `true`

##### <a name="-systemd--dropin_file--daemon_reload"></a>`daemon_reload`

Data type: `Boolean`

Call systemd::daemon_reload

Default value: `true`

### <a name="systemd--manage_dropin"></a>`systemd::manage_dropin`

Creates a drop-in file for a systemd unit from a template

* **See also**
  * systemd.unit(5)

#### Examples

##### drop in file to change Type and override ExecStart

```puppet
systemd::manage_dropin { 'myconf.conf':
  ensure        => present,
  unit          => 'myservice.service',
  service_entry => {
    'Type'      => 'oneshot',
    'ExecStart' => ['', '/usr/bin/doit.sh'],
  },
}
```

##### drop in file to change a path unit and override TriggerLimitBurst

```puppet
systemd::manage_dropin { 'triggerlimit.conf':
  ensure     => present,
  unit       => 'passwd.path',
  path_entry => {
    'TriggerLimitBurst' => 100,
  },
}
```

##### drop in file to override the LimitCORE for a service

```puppet
systemd::manage_dropin { 'corelimit.conf':
  ensure     => present,
  unit       => 'rsyslog.conf',
  path_entry => {
    'LimitCORE' => 'infinity',
  },
}
```

##### make a noisy unit less noisy

```puppet
systemd::manage_dropin { 'maxloglevel.conf':
  ensure        => present,
  unit          => 'chatty.service',
  service_entry => {
    'LogLevelMax' => 'warning',
  }
}
```

##### have a unit instance auto run before user-<uid>.service

```puppet
systemd::manage_dropin { 'user-aklog.conf':
  unit => 'user@.service',
  unit_entry => {
    'After'    => 'user-aklog@%i.service',
    'Requires' => 'user-aklog@%i.service'
  }
}
```

##### set memory limits on the user slices

```puppet
systemd::manage_dropin { 'userlimits.conf':
  unit        => 'user-.slice',
  slice_entry => {
    MemoryMax        => '10G',
    MemoryAccounting => true,
  }
}
```

##### set IO limits on two devices

```puppet
systemd::manage_dropin { 'devicelimits.conf':
  unit          =>  'special.service',
  service_entry => {
   'IOReadIOPSMax' => [
     ['/dev/afs',100],
     ['/dev/gluster','1000K'],
   ],
  },
}
```

#### Parameters

The following parameters are available in the `systemd::manage_dropin` defined type:

* [`unit`](#-systemd--manage_dropin--unit)
* [`filename`](#-systemd--manage_dropin--filename)
* [`ensure`](#-systemd--manage_dropin--ensure)
* [`path`](#-systemd--manage_dropin--path)
* [`selinux_ignore_defaults`](#-systemd--manage_dropin--selinux_ignore_defaults)
* [`owner`](#-systemd--manage_dropin--owner)
* [`group`](#-systemd--manage_dropin--group)
* [`mode`](#-systemd--manage_dropin--mode)
* [`show_diff`](#-systemd--manage_dropin--show_diff)
* [`notify_service`](#-systemd--manage_dropin--notify_service)
* [`daemon_reload`](#-systemd--manage_dropin--daemon_reload)
* [`unit_entry`](#-systemd--manage_dropin--unit_entry)
* [`slice_entry`](#-systemd--manage_dropin--slice_entry)
* [`service_entry`](#-systemd--manage_dropin--service_entry)
* [`install_entry`](#-systemd--manage_dropin--install_entry)
* [`timer_entry`](#-systemd--manage_dropin--timer_entry)
* [`path_entry`](#-systemd--manage_dropin--path_entry)
* [`socket_entry`](#-systemd--manage_dropin--socket_entry)
* [`mount_entry`](#-systemd--manage_dropin--mount_entry)
* [`swap_entry`](#-systemd--manage_dropin--swap_entry)

##### <a name="-systemd--manage_dropin--unit"></a>`unit`

Data type: `Systemd::Unit`

The unit to create a dropfile for

##### <a name="-systemd--manage_dropin--filename"></a>`filename`

Data type: `Systemd::Dropin`

The target unit file to create. The filename of the drop in. The full path is determined using the path, unit and this filename.

Default value: `$name`

##### <a name="-systemd--manage_dropin--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

The state of this dropin file

Default value: `'present'`

##### <a name="-systemd--manage_dropin--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The main systemd configuration path

Default value: `'/etc/systemd/system'`

##### <a name="-systemd--manage_dropin--selinux_ignore_defaults"></a>`selinux_ignore_defaults`

Data type: `Boolean`

If Puppet should ignore the default SELinux labels

Default value: `false`

##### <a name="-systemd--manage_dropin--owner"></a>`owner`

Data type: `String`

The owner to set on the dropin file

Default value: `'root'`

##### <a name="-systemd--manage_dropin--group"></a>`group`

Data type: `String`

The group to set on the dropin file

Default value: `'root'`

##### <a name="-systemd--manage_dropin--mode"></a>`mode`

Data type: `Stdlib::Filemode`

The mode to set on the dropin file

Default value: `'0444'`

##### <a name="-systemd--manage_dropin--show_diff"></a>`show_diff`

Data type: `Boolean`

Whether to show the diff when updating dropin file

Default value: `true`

##### <a name="-systemd--manage_dropin--notify_service"></a>`notify_service`

Data type: `Boolean`

Notify a service for the unit, if it exists

Default value: `false`

##### <a name="-systemd--manage_dropin--daemon_reload"></a>`daemon_reload`

Data type: `Boolean`

Call systemd::daemon_reload

Default value: `true`

##### <a name="-systemd--manage_dropin--unit_entry"></a>`unit_entry`

Data type: `Optional[Systemd::Unit::Unit]`

key value pairs for [Unit] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--slice_entry"></a>`slice_entry`

Data type: `Optional[Systemd::Unit::Slice]`

key value pairs for [Slice] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--service_entry"></a>`service_entry`

Data type: `Optional[Systemd::Unit::Service]`

key value pairs for [Service] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--install_entry"></a>`install_entry`

Data type: `Optional[Systemd::Unit::Install]`

key value pairs for [Install] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--timer_entry"></a>`timer_entry`

Data type: `Optional[Systemd::Unit::Timer]`

key value pairs for [Timer] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--path_entry"></a>`path_entry`

Data type: `Optional[Systemd::Unit::Path]`

key value pairs for [Path] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--socket_entry"></a>`socket_entry`

Data type: `Optional[Systemd::Unit::Socket]`

key value pairs for the [Socket] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--mount_entry"></a>`mount_entry`

Data type: `Optional[Systemd::Unit::Mount]`

key value pairs for the [Mount] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_dropin--swap_entry"></a>`swap_entry`

Data type: `Optional[Systemd::Unit::Swap]`

key value pairs for the [Swap] section of the unit file

Default value: `undef`

### <a name="systemd--manage_unit"></a>`systemd::manage_unit`

Generate unit file from template

* **See also**
  * systemd.unit(5)

#### Examples

##### Generate a service

```puppet
systemd::manage_unit { 'myrunner.service':
  unit_entry    => {
    'Description' => 'My great service',
  },
  service_entry => {
    'Type'      => 'oneshot',
    'ExecStart' => '/usr/bin/doit.sh',
  },
  install_entry => {
    'WantedBy' => 'multi-user.target',
  },
}
```

##### Genenerate a path unit

```puppet
systemd::manage_unit { 'passwd-mon.path':
  ensure        => present,
  unit_entry    => {
    'Description' => 'Monitor the passwd file',
  },
  path_entry    => {
    'PathModified' => '/etc/passwd',
    'Unit'         => 'passwd-mon.service',
  },
  install_entry => {
    'WantedBy' => 'multi-user.target',
  },
}
```

##### Generate a socket and service (xinetd style)

```puppet
systemd::manage_unit {'arcd.socket':
  ensure        => 'present',
  unit_entry    => {
    'Description' => 'arcd.service',
  },
  socket_entry  => {
    'ListenStream' => 4241,
    'Accept'       => true,
    'BindIPv6Only' => 'both',
  },
  install_entry => {
    'WantedBy' => 'sockets.target',
  },
}

systemd::manage_unit{'arcd@.service':
  ensure        => 'present',
  enable        => true,
  active        => true,
  unit_entry    => {
    'Description'   => 'arc sever for %i',
  },
  service_entry => {
    'Type'          => 'simple',
    'ExecStart'     => /usr/sbin/arcd /usr/libexec/arcd/arcd.pl,
    'StandardInput' => 'socket',
  },
}
```

##### Mount a Filesystem and Use for a Service

```puppet
systemd::manage_unit { 'var-lib-sss-db.mount':
  ensure      => present,
  unit_entry  => {
    'Description' => 'Mount sss tmpfs db',
  },
  mount_entry => {
    'What'    => 'tmpfs',
    'Where'   => '/var/lib/sss/db',
    'Type'    => 'tmpfs',
    'Options' => 'size=300M,mode=0700,uid=sssd,gid=sssd,rootcontext=system_u:object_r:sssd_var_lib_t:s0',
  },
}
systemd::manage_dropin { 'tmpfs-db.conf':
  ensure     => present,
  unit       => 'sssd.service',
  unit_entry => {
    'RequiresMountsFor' => '/var/lib/sss/db',
  },
}
```

##### Create and Mount a Swap File

```puppet

systemd::manage_unit{'swapfile.swap':
  ensure        => present,
  enable        => true,
  active        => true,
  unit_entry    => {
    'Description' => 'Mount /swapfile as a swap file',
    'After'       => 'mkswap.service',
    'Requires'    => 'mkswap.service',
  },
  swap_entry    => {
    'What' => '/swapfile',
  },
  install_entry => {
    'WantedBy' => 'multi-user.target',
  },
  require       => Systemd::Manage_unit['mkswap.service'],
}
systemd::manage_unit{'mkswap.service':
  ensure        => present,
  unit_entry    => {
    'Description'         => 'Format a swapfile at /swapfile',
    'ConditionPathExists' => '!/swapfile',
  },
  service_entry => {
    'Type'      => 'oneshot',
    'UMask'     => '0177',
    'ExecStart' => [
      '/usr/bin/dd if=/dev/zero of=/swapfile bs=1024 count=1000',
      '/usr/sbin/mkswap /swapfile',
    ],
  },
}
```

##### Remove a unit file

```puppet
systemd::manage_unit { 'my.service':
  ensure     => 'absent',
}
```

#### Parameters

The following parameters are available in the `systemd::manage_unit` defined type:

* [`name`](#-systemd--manage_unit--name)
* [`ensure`](#-systemd--manage_unit--ensure)
* [`path`](#-systemd--manage_unit--path)
* [`owner`](#-systemd--manage_unit--owner)
* [`group`](#-systemd--manage_unit--group)
* [`mode`](#-systemd--manage_unit--mode)
* [`show_diff`](#-systemd--manage_unit--show_diff)
* [`enable`](#-systemd--manage_unit--enable)
* [`active`](#-systemd--manage_unit--active)
* [`restart`](#-systemd--manage_unit--restart)
* [`selinux_ignore_defaults`](#-systemd--manage_unit--selinux_ignore_defaults)
* [`service_parameters`](#-systemd--manage_unit--service_parameters)
* [`daemon_reload`](#-systemd--manage_unit--daemon_reload)
* [`service_restart`](#-systemd--manage_unit--service_restart)
* [`unit_entry`](#-systemd--manage_unit--unit_entry)
* [`slice_entry`](#-systemd--manage_unit--slice_entry)
* [`service_entry`](#-systemd--manage_unit--service_entry)
* [`install_entry`](#-systemd--manage_unit--install_entry)
* [`timer_entry`](#-systemd--manage_unit--timer_entry)
* [`path_entry`](#-systemd--manage_unit--path_entry)
* [`socket_entry`](#-systemd--manage_unit--socket_entry)
* [`mount_entry`](#-systemd--manage_unit--mount_entry)
* [`swap_entry`](#-systemd--manage_unit--swap_entry)

##### <a name="-systemd--manage_unit--name"></a>`name`

Data type: `Pattern['^[^/]+\.(service|socket|device|mount|automount|swap|target|path|timer|slice|scope)$']`

The target unit file to create

##### <a name="-systemd--manage_unit--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

The state of the unit file to ensure

Default value: `'present'`

##### <a name="-systemd--manage_unit--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The main systemd configuration path

Default value: `'/etc/systemd/system'`

##### <a name="-systemd--manage_unit--owner"></a>`owner`

Data type: `String`

The owner to set on the unit file

Default value: `'root'`

##### <a name="-systemd--manage_unit--group"></a>`group`

Data type: `String`

The group to set on the unit file

Default value: `'root'`

##### <a name="-systemd--manage_unit--mode"></a>`mode`

Data type: `Stdlib::Filemode`

The mode to set on the unit file

Default value: `'0444'`

##### <a name="-systemd--manage_unit--show_diff"></a>`show_diff`

Data type: `Boolean`

Whether to show the diff when updating unit file

Default value: `true`

##### <a name="-systemd--manage_unit--enable"></a>`enable`

Data type: `Optional[Variant[Boolean, Enum['mask']]]`

If set, manage the unit enablement status

Default value: `undef`

##### <a name="-systemd--manage_unit--active"></a>`active`

Data type: `Optional[Boolean]`

If set, will manage the state of the unit

Default value: `undef`

##### <a name="-systemd--manage_unit--restart"></a>`restart`

Data type: `Optional[String]`

Specify a restart command manually. If left unspecified, a standard Puppet service restart happens

Default value: `undef`

##### <a name="-systemd--manage_unit--selinux_ignore_defaults"></a>`selinux_ignore_defaults`

Data type: `Boolean`

maps to the same param on the file resource for the unit. false in the module because it's false in the file resource type

Default value: `false`

##### <a name="-systemd--manage_unit--service_parameters"></a>`service_parameters`

Data type: `Hash[String[1], Any]`

hash that will be passed with the splat operator to the service resource

Default value: `{}`

##### <a name="-systemd--manage_unit--daemon_reload"></a>`daemon_reload`

Data type: `Boolean`

call `systemd::daemon-reload` to ensure that the modified unit file is loaded

Default value: `true`

##### <a name="-systemd--manage_unit--service_restart"></a>`service_restart`

Data type: `Boolean`

restart (notify) the service when unit file changed

Default value: `true`

##### <a name="-systemd--manage_unit--unit_entry"></a>`unit_entry`

Data type: `Optional[Systemd::Unit::Unit]`

key value pairs for [Unit] section of the unit file.

Default value: `undef`

##### <a name="-systemd--manage_unit--slice_entry"></a>`slice_entry`

Data type: `Optional[Systemd::Unit::Slice]`

key value pairs for [Slice] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_unit--service_entry"></a>`service_entry`

Data type: `Optional[Systemd::Unit::Service]`

key value pairs for [Service] section of the unit file.

Default value: `undef`

##### <a name="-systemd--manage_unit--install_entry"></a>`install_entry`

Data type: `Optional[Systemd::Unit::Install]`

key value pairs for [Install] section of the unit file.

Default value: `undef`

##### <a name="-systemd--manage_unit--timer_entry"></a>`timer_entry`

Data type: `Optional[Systemd::Unit::Timer]`

key value pairs for [Timer] section of the unit file

Default value: `undef`

##### <a name="-systemd--manage_unit--path_entry"></a>`path_entry`

Data type: `Optional[Systemd::Unit::Path]`

key value pairs for [Path] section of the unit file.

Default value: `undef`

##### <a name="-systemd--manage_unit--socket_entry"></a>`socket_entry`

Data type: `Optional[Systemd::Unit::Socket]`

kev value paors for [Socket] section of the unit file.

Default value: `undef`

##### <a name="-systemd--manage_unit--mount_entry"></a>`mount_entry`

Data type: `Optional[Systemd::Unit::Mount]`

kev value pairs for [Mount] section of the unit file.

Default value: `undef`

##### <a name="-systemd--manage_unit--swap_entry"></a>`swap_entry`

Data type: `Optional[Systemd::Unit::Swap]`

kev value pairs for [Swap] section of the unit file.

Default value: `undef`

### <a name="systemd--modules_load"></a>`systemd::modules_load`

Creates a modules-load.d drop file

* **See also**
  * modules-load.d(5)

#### Examples

##### load a module

```puppet
systemd::modules_load { 'impi.conf':
   content => "ipmi\n",
}
```

##### override /lib/modules-load.d/myservice.conf in /etc/modules-load.d/myservice.conf

```puppet
systemd::modules_load { 'myservice.conf':
   content => "# Cancel system version of the file\n",
}
```

#### Parameters

The following parameters are available in the `systemd::modules_load` defined type:

* [`filename`](#-systemd--modules_load--filename)
* [`ensure`](#-systemd--modules_load--ensure)
* [`path`](#-systemd--modules_load--path)
* [`content`](#-systemd--modules_load--content)
* [`source`](#-systemd--modules_load--source)

##### <a name="-systemd--modules_load--filename"></a>`filename`

Data type: `Systemd::Dropin`

The name of the modules-load.d file to create

Default value: `$name`

##### <a name="-systemd--modules_load--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'file']`

Whether to drop a file or remove it

Default value: `'file'`

##### <a name="-systemd--modules_load--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The path to the main systemd modules-load.d directory

Default value: `'/etc/modules-load.d'`

##### <a name="-systemd--modules_load--content"></a>`content`

Data type: `Optional[String[1]]`

The literal content to write to the file

* Mutually exclusive with ``$source``

Default value: `undef`

##### <a name="-systemd--modules_load--source"></a>`source`

Data type: `Optional[String[1]]`

A ``File`` resource compatible ``source``

* Mutually exclusive with ``$content``

Default value: `undef`

### <a name="systemd--network"></a>`systemd::network`

Creates network config for systemd-networkd

#### Parameters

The following parameters are available in the `systemd::network` defined type:

* [`ensure`](#-systemd--network--ensure)
* [`path`](#-systemd--network--path)
* [`content`](#-systemd--network--content)
* [`source`](#-systemd--network--source)
* [`target`](#-systemd--network--target)
* [`owner`](#-systemd--network--owner)
* [`group`](#-systemd--network--group)
* [`mode`](#-systemd--network--mode)
* [`show_diff`](#-systemd--network--show_diff)
* [`restart_service`](#-systemd--network--restart_service)

##### <a name="-systemd--network--ensure"></a>`ensure`

Data type: `Enum['file', 'absent']`

configure if the file should be configured or deleted

Default value: `file`

##### <a name="-systemd--network--path"></a>`path`

Data type: `Stdlib::Absolutepath`

directory where the network configs are stored

Default value: `'/etc/systemd/network'`

##### <a name="-systemd--network--content"></a>`content`

Data type: `Optional[String]`

the content of the file

Default value: `undef`

##### <a name="-systemd--network--source"></a>`source`

Data type: `Optional[String]`

a path to a file that's used as source

Default value: `undef`

##### <a name="-systemd--network--target"></a>`target`

Data type: `Optional[Stdlib::Absolutepath]`

optional absolute path  in case the file should be stored somewhere else

Default value: `undef`

##### <a name="-systemd--network--owner"></a>`owner`

Data type: `String`

the user who owns the file

Default value: `'root'`

##### <a name="-systemd--network--group"></a>`group`

Data type: `String`

the group that owns the file

Default value: `'root'`

##### <a name="-systemd--network--mode"></a>`mode`

Data type: `String`

the mode of the file

Default value: `'0444'`

##### <a name="-systemd--network--show_diff"></a>`show_diff`

Data type: `Boolean`

whether the file diff should be shown on modifications

Default value: `true`

##### <a name="-systemd--network--restart_service"></a>`restart_service`

Data type: `Boolean`

whether systemd-networkd should be restarted on changes, defaults to true. `$systemd::manage_networkd` needs to be true as well

Default value: `true`

### <a name="systemd--service_limits"></a>`systemd::service_limits`

Deprecated - Adds a set of custom limits to the service

* **See also**
  * systemd.exec(5)

#### Parameters

The following parameters are available in the `systemd::service_limits` defined type:

* [`name`](#-systemd--service_limits--name)
* [`ensure`](#-systemd--service_limits--ensure)
* [`path`](#-systemd--service_limits--path)
* [`selinux_ignore_defaults`](#-systemd--service_limits--selinux_ignore_defaults)
* [`limits`](#-systemd--service_limits--limits)
* [`source`](#-systemd--service_limits--source)
* [`restart_service`](#-systemd--service_limits--restart_service)

##### <a name="-systemd--service_limits--name"></a>`name`

Data type: `Pattern['^.+\.(service|socket|mount|swap)$']`

The name of the service that you will be modifying

##### <a name="-systemd--service_limits--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'file']`

Whether to drop a file or remove it

Default value: `'present'`

##### <a name="-systemd--service_limits--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The path to the main systemd settings directory

Default value: `'/etc/systemd/system'`

##### <a name="-systemd--service_limits--selinux_ignore_defaults"></a>`selinux_ignore_defaults`

Data type: `Boolean`

If Puppet should ignore the default SELinux labels.

Default value: `false`

##### <a name="-systemd--service_limits--limits"></a>`limits`

Data type: `Optional[Systemd::ServiceLimits]`

A Hash of service limits matching the settings in ``systemd.exec(5)``

* Mutually exclusive with ``$source``

Default value: `undef`

##### <a name="-systemd--service_limits--source"></a>`source`

Data type: `Optional[String]`

A ``File`` resource compatible ``source``

* Mutually exclusive with ``$limits``

Default value: `undef`

##### <a name="-systemd--service_limits--restart_service"></a>`restart_service`

Data type: `Boolean`

Unused parameter for compatibility with older versions. Will fail if true is passed in.

Default value: `false`

### <a name="systemd--timer"></a>`systemd::timer`

Create a timer and optionally a service unit to execute with the timer unit

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.timer.html
    * systemd.timer(5)

#### Parameters

The following parameters are available in the `systemd::timer` defined type:

* [`name`](#-systemd--timer--name)
* [`path`](#-systemd--timer--path)
* [`timer_content`](#-systemd--timer--timer_content)
* [`timer_source`](#-systemd--timer--timer_source)
* [`service_content`](#-systemd--timer--service_content)
* [`service_source`](#-systemd--timer--service_source)
* [`owner`](#-systemd--timer--owner)
* [`group`](#-systemd--timer--group)
* [`mode`](#-systemd--timer--mode)
* [`show_diff`](#-systemd--timer--show_diff)
* [`service_unit`](#-systemd--timer--service_unit)
* [`active`](#-systemd--timer--active)
* [`enable`](#-systemd--timer--enable)
* [`ensure`](#-systemd--timer--ensure)
* [`daemon_reload`](#-systemd--timer--daemon_reload)

##### <a name="-systemd--timer--name"></a>`name`

Data type: `Pattern['^.+\.timer$]`

The target of the timer unit to create

##### <a name="-systemd--timer--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The main systemd configuration path

Default value: `'/etc/systemd/system'`

##### <a name="-systemd--timer--timer_content"></a>`timer_content`

Data type: `Optional[String[1]]`

The full content of the timer unit file

* Mutually exclusive with ``$timer_source``

Default value: `undef`

##### <a name="-systemd--timer--timer_source"></a>`timer_source`

Data type: `Optional[String[1]]`

The ``File`` resource compatible ``source``

* Mutually exclusive with ``$timer_content``

Default value: `undef`

##### <a name="-systemd--timer--service_content"></a>`service_content`

Data type: `Optional[String[1]]`

The full content of the service unit file

* Mutually exclusive with ``$service_source``

Default value: `undef`

##### <a name="-systemd--timer--service_source"></a>`service_source`

Data type: `Optional[String[1]]`

The ``File`` resource compatible ``source``

* Mutually exclusive with ``$service_content``

Default value: `undef`

##### <a name="-systemd--timer--owner"></a>`owner`

Data type: `String[1]`

The owner to set on the dropin file

Default value: `'root'`

##### <a name="-systemd--timer--group"></a>`group`

Data type: `String[1]`

The group to set on the dropin file

Default value: `'root'`

##### <a name="-systemd--timer--mode"></a>`mode`

Data type: `Stdlib::Filemode`

The mode to set on the dropin file

Default value: `'0444'`

##### <a name="-systemd--timer--show_diff"></a>`show_diff`

Data type: `Boolean`

Whether to show the diff when updating dropin file

Default value: `true`

##### <a name="-systemd--timer--service_unit"></a>`service_unit`

Data type: `Optional[Systemd::Unit]`

If set then the service_unit will have this name.
If not set the service unit has the same name
as the timer unit with s/.timer/.service/

Default value: `undef`

##### <a name="-systemd--timer--active"></a>`active`

Data type: `Optional[Boolean]`

If set to true or false the timer service will be maintained.
If true the timer service will be running and enabled, if false it will
explicitly stopped and disabled.

Default value: `undef`

##### <a name="-systemd--timer--enable"></a>`enable`

Data type: `Optional[Variant[Boolean, Enum['mask']]]`

If set, will manage the state of the unit.

Default value: `undef`

##### <a name="-systemd--timer--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'file']`

Defines the desired state of the timer

Default value: `'present'`

##### <a name="-systemd--timer--daemon_reload"></a>`daemon_reload`

Data type: `Boolean`

Call `systemd::daemon_reload`

Default value: `true`

### <a name="systemd--timer_wrapper"></a>`systemd::timer_wrapper`

Helper to define timer and accompanying services for a given task (cron like interface).

#### Examples

##### Create a timer that runs every 5 minutes

```puppet
systemd::timer_wrapper { 'my_timer':
  ensure        => 'present',
  command       => '/usr/bin/echo "Hello World"',
  on_calendar   => '*:0/5',
}
```

##### Create a timer with overrides for the service and timer

```puppet
systemd::timer_wrapper { 'my_timer':
  ensure             => 'present',
  command            => '/usr/bin/echo "Hello World"',
  on_calendar        => '*:0/5',
  service_overrides => { 'Group' => 'nobody' },
  timer_overrides   => { 'OnBootSec' => '10' },
}
```

##### Create a timer with overrides for the service_unit and timer_unit

```puppet
systemd::timer_wrapper { 'my_timer':
  ensure                 => 'present',
  command                => '/usr/bin/echo "Hello World"',
  on_calendar            => '*:0/5',
  service_unit_overrides => { 'Wants' => 'network-online.target' },
  timer_unit_overrides   => { 'Description' => 'Very special timer' },
}
```

#### Parameters

The following parameters are available in the `systemd::timer_wrapper` defined type:

* [`ensure`](#-systemd--timer_wrapper--ensure)
* [`command`](#-systemd--timer_wrapper--command)
* [`user`](#-systemd--timer_wrapper--user)
* [`on_active_sec`](#-systemd--timer_wrapper--on_active_sec)
* [`on_boot_sec`](#-systemd--timer_wrapper--on_boot_sec)
* [`on_start_up_sec`](#-systemd--timer_wrapper--on_start_up_sec)
* [`on_unit_active_sec`](#-systemd--timer_wrapper--on_unit_active_sec)
* [`on_unit_inactive_sec`](#-systemd--timer_wrapper--on_unit_inactive_sec)
* [`on_calendar`](#-systemd--timer_wrapper--on_calendar)
* [`service_overrides`](#-systemd--timer_wrapper--service_overrides)
* [`timer_overrides`](#-systemd--timer_wrapper--timer_overrides)
* [`service_unit_overrides`](#-systemd--timer_wrapper--service_unit_overrides)
* [`timer_unit_overrides`](#-systemd--timer_wrapper--timer_unit_overrides)

##### <a name="-systemd--timer_wrapper--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

whether the timer and service should be present or absent

##### <a name="-systemd--timer_wrapper--command"></a>`command`

Data type: `Optional[Systemd::Unit::Service::Exec]`

the command for the systemd servie to execute

Default value: `undef`

##### <a name="-systemd--timer_wrapper--user"></a>`user`

Data type: `Optional[String[1]]`

the user to run the command as

Default value: `undef`

##### <a name="-systemd--timer_wrapper--on_active_sec"></a>`on_active_sec`

Data type: `Optional[Systemd::Unit::Timespan]`

run service relative to the time when the timer was activated

Default value: `undef`

##### <a name="-systemd--timer_wrapper--on_boot_sec"></a>`on_boot_sec`

Data type: `Optional[Systemd::Unit::Timespan]`

run service relative to when the machine was booted

Default value: `undef`

##### <a name="-systemd--timer_wrapper--on_start_up_sec"></a>`on_start_up_sec`

Data type: `Optional[Systemd::Unit::Timespan]`

run service relative to when the service manager was started

Default value: `undef`

##### <a name="-systemd--timer_wrapper--on_unit_active_sec"></a>`on_unit_active_sec`

Data type: `Optional[Systemd::Unit::Timespan]`

run service relative to when the unit was last activated

Default value: `undef`

##### <a name="-systemd--timer_wrapper--on_unit_inactive_sec"></a>`on_unit_inactive_sec`

Data type: `Optional[Systemd::Unit::Timespan]`

run service relative to when the unit was last deactivated

Default value: `undef`

##### <a name="-systemd--timer_wrapper--on_calendar"></a>`on_calendar`

Data type: `Optional[Systemd::Unit::Timespan]`

the calendar event expressions time to run the service

Default value: `undef`

##### <a name="-systemd--timer_wrapper--service_overrides"></a>`service_overrides`

Data type: `Systemd::Unit::Service`

override for the`[Service]` section of the service

Default value: `{}`

##### <a name="-systemd--timer_wrapper--timer_overrides"></a>`timer_overrides`

Data type: `Systemd::Unit::Timer`

override for the`[Timer]` section of the timer

Default value: `{}`

##### <a name="-systemd--timer_wrapper--service_unit_overrides"></a>`service_unit_overrides`

Data type: `Systemd::Unit::Unit`

override for the`[Unit]` section of the service

Default value: `{}`

##### <a name="-systemd--timer_wrapper--timer_unit_overrides"></a>`timer_unit_overrides`

Data type: `Systemd::Unit::Unit`

override for the `[Unit]` section of the timer

Default value: `{}`

### <a name="systemd--tmpfile"></a>`systemd::tmpfile`

Creates a systemd tmpfile

* **See also**
  * systemd-tmpfiles(8)

#### Parameters

The following parameters are available in the `systemd::tmpfile` defined type:

* [`filename`](#-systemd--tmpfile--filename)
* [`ensure`](#-systemd--tmpfile--ensure)
* [`path`](#-systemd--tmpfile--path)
* [`content`](#-systemd--tmpfile--content)
* [`source`](#-systemd--tmpfile--source)

##### <a name="-systemd--tmpfile--filename"></a>`filename`

Data type: `Systemd::Dropin`

The name of the tmpfile to create

Default value: `$name`

##### <a name="-systemd--tmpfile--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'file']`

Whether to drop a file or remove it

Default value: `'file'`

##### <a name="-systemd--tmpfile--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The path to the main systemd tmpfiles directory

Default value: `'/etc/tmpfiles.d'`

##### <a name="-systemd--tmpfile--content"></a>`content`

Data type: `Optional[String]`

The literal content to write to the file

* Mutually exclusive with ``$source``

Default value: `undef`

##### <a name="-systemd--tmpfile--source"></a>`source`

Data type: `Optional[String]`

A ``File`` resource compatible ``source``

* Mutually exclusive with ``$limits``

Default value: `undef`

### <a name="systemd--udev--rule"></a>`systemd::udev::rule`

Adds a custom udev rule

* **See also**
  * udev(7)

#### Parameters

The following parameters are available in the `systemd::udev::rule` defined type:

* [`name`](#-systemd--udev--rule--name)
* [`ensure`](#-systemd--udev--rule--ensure)
* [`path`](#-systemd--udev--rule--path)
* [`selinux_ignore_defaults`](#-systemd--udev--rule--selinux_ignore_defaults)
* [`notify_services`](#-systemd--udev--rule--notify_services)
* [`rules`](#-systemd--udev--rule--rules)

##### <a name="-systemd--udev--rule--name"></a>`name`

Data type: `Pattern['^.+\.rules$']`

The name of the udev rules to create

##### <a name="-systemd--udev--rule--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'file']`

Whether to drop a file or remove it

Default value: `'file'`

##### <a name="-systemd--udev--rule--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The path to the main systemd settings directory

Default value: `'/etc/udev/rules.d'`

##### <a name="-systemd--udev--rule--selinux_ignore_defaults"></a>`selinux_ignore_defaults`

Data type: `Boolean`

If Puppet should ignore the default SELinux labels.

Default value: `false`

##### <a name="-systemd--udev--rule--notify_services"></a>`notify_services`

Data type: `Variant[Array[String[1]], String[1]]`

List of services to notify when this rule is updated

Default value: `[]`

##### <a name="-systemd--udev--rule--rules"></a>`rules`

Data type: `Array`

The literal udev rules you want to deploy

Default value: `[]`

### <a name="systemd--unit_file"></a>`systemd::unit_file`

Creates a systemd unit file

* **See also**
  * systemd.unit(5)

#### Examples

##### manage unit file + service

```puppet
systemd::unit_file { 'foo.service':
  content => file("${module_name}/foo.service"),
  enable  => true,
  active  => true,
}
```

#### Parameters

The following parameters are available in the `systemd::unit_file` defined type:

* [`name`](#-systemd--unit_file--name)
* [`ensure`](#-systemd--unit_file--ensure)
* [`path`](#-systemd--unit_file--path)
* [`content`](#-systemd--unit_file--content)
* [`source`](#-systemd--unit_file--source)
* [`target`](#-systemd--unit_file--target)
* [`owner`](#-systemd--unit_file--owner)
* [`group`](#-systemd--unit_file--group)
* [`mode`](#-systemd--unit_file--mode)
* [`show_diff`](#-systemd--unit_file--show_diff)
* [`enable`](#-systemd--unit_file--enable)
* [`active`](#-systemd--unit_file--active)
* [`restart`](#-systemd--unit_file--restart)
* [`selinux_ignore_defaults`](#-systemd--unit_file--selinux_ignore_defaults)
* [`service_parameters`](#-systemd--unit_file--service_parameters)
* [`daemon_reload`](#-systemd--unit_file--daemon_reload)
* [`service_restart`](#-systemd--unit_file--service_restart)

##### <a name="-systemd--unit_file--name"></a>`name`

Data type: `Pattern['^[^/]+\.(service|socket|device|mount|automount|swap|target|path|timer|slice|scope)$']`

The target unit file to create

##### <a name="-systemd--unit_file--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

The state of the unit file to ensure

Default value: `'present'`

##### <a name="-systemd--unit_file--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The main systemd configuration path

Default value: `'/etc/systemd/system'`

##### <a name="-systemd--unit_file--content"></a>`content`

Data type: `Optional[Variant[String, Sensitive[String], Deferred]]`

The full content of the unit file

* Mutually exclusive with ``$source``

Default value: `undef`

##### <a name="-systemd--unit_file--source"></a>`source`

Data type: `Optional[String]`

The ``File`` resource compatible ``source``

* Mutually exclusive with ``$content``

Default value: `undef`

##### <a name="-systemd--unit_file--target"></a>`target`

Data type: `Optional[Stdlib::Absolutepath]`

If set, will force the file to be a symlink to the given target

* Mutually exclusive with both ``$source`` and ``$content``

Default value: `undef`

##### <a name="-systemd--unit_file--owner"></a>`owner`

Data type: `String`

The owner to set on the unit file

Default value: `'root'`

##### <a name="-systemd--unit_file--group"></a>`group`

Data type: `String`

The group to set on the unit file

Default value: `'root'`

##### <a name="-systemd--unit_file--mode"></a>`mode`

Data type: `String`

The mode to set on the unit file

Default value: `'0444'`

##### <a name="-systemd--unit_file--show_diff"></a>`show_diff`

Data type: `Boolean`

Whether to show the diff when updating unit file

Default value: `true`

##### <a name="-systemd--unit_file--enable"></a>`enable`

Data type: `Optional[Variant[Boolean, Enum['mask']]]`

If set, will manage the unit enablement status.

Default value: `undef`

##### <a name="-systemd--unit_file--active"></a>`active`

Data type: `Optional[Boolean]`

If set, will manage the state of the unit.

Default value: `undef`

##### <a name="-systemd--unit_file--restart"></a>`restart`

Data type: `Optional[String]`

Specify a restart command manually. If left unspecified, a standard Puppet service restart happens.

Default value: `undef`

##### <a name="-systemd--unit_file--selinux_ignore_defaults"></a>`selinux_ignore_defaults`

Data type: `Boolean`

maps to the same param on the file resource for the unit. false in the module because it's false in the file resource type

Default value: `false`

##### <a name="-systemd--unit_file--service_parameters"></a>`service_parameters`

Data type: `Hash[String[1], Any]`

hash that will be passed with the splat operator to the service resource

Default value: `{}`

##### <a name="-systemd--unit_file--daemon_reload"></a>`daemon_reload`

Data type: `Boolean`

call `systemd::daemon-reload` to ensure that the modified unit file is loaded

Default value: `true`

##### <a name="-systemd--unit_file--service_restart"></a>`service_restart`

Data type: `Boolean`

restart (notify) the service when unit file changed

Default value: `true`

### <a name="systemd--user_service"></a>`systemd::user_service`

Manage a user service running under systemd --user

#### Examples

##### Enable a service for all users

```puppet
systemd::user_service { 'systemd-tmpfiles-clean.timer':
  enable => true,
  global => true,
}
```

##### Enable a particular user's service

```puppet
systemd::user_service { 'podman-auto-update.timer':
  ensure => true,
  enable => true,
  user   => 'steve',
}
```

##### Notify a user's service to restart it

```puppet
file{ '/home/steve/.config/systemd/user/podman-auto-update.timer':
  ensure  => file,
  content => ...,
  notify  => Systemd::User_service['steve-podman-auto-update.timer']
}

systemd::user_service { 'steve-podman-auto-update.timer':
  ensure => true,
  enable => true,
  unit   => 'podman-auto-update.timer',
  user   => 'steve',
}

@param unit Unit name to work on
@param ensure Should the unit be started or stopped. Can only be true if user is specified.
@param enable Should the unit be enabled or disabled
@param user User name of user whose unit should be acted upon. Mutually exclusive with
@param global Act globally for all users. Mutually exclusibe with `user`.
```

#### Parameters

The following parameters are available in the `systemd::user_service` defined type:

* [`unit`](#-systemd--user_service--unit)
* [`ensure`](#-systemd--user_service--ensure)
* [`enable`](#-systemd--user_service--enable)
* [`global`](#-systemd--user_service--global)
* [`user`](#-systemd--user_service--user)

##### <a name="-systemd--user_service--unit"></a>`unit`

Data type: `Systemd::Unit`



Default value: `$title`

##### <a name="-systemd--user_service--ensure"></a>`ensure`

Data type: `Variant[Boolean,Enum['stopped','running']]`



Default value: `false`

##### <a name="-systemd--user_service--enable"></a>`enable`

Data type: `Boolean`



Default value: `false`

##### <a name="-systemd--user_service--global"></a>`global`

Data type: `Boolean`



Default value: `false`

##### <a name="-systemd--user_service--user"></a>`user`

Data type: `Optional[String[1]]`



Default value: `undef`

## Resource types

### <a name="loginctl_user"></a>`loginctl_user`

An arbitrary name used as the identity of the resource.

#### Properties

The following properties are available in the `loginctl_user` type.

##### `linger`

Valid values: `enabled`, `disabled`

Whether linger is enabled for the user.

Default value: `disabled`

#### Parameters

The following parameters are available in the `loginctl_user` type.

* [`name`](#-loginctl_user--name)
* [`provider`](#-loginctl_user--provider)

##### <a name="-loginctl_user--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="-loginctl_user--provider"></a>`provider`

The specific backend to use for this `loginctl_user` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Functions

### <a name="systemd--escape"></a>`systemd::escape`

Type: Puppet Language

Escape strings as systemd-escape does.

#### Examples

##### Escaping a string

```puppet
$result = systemd::escape('foo::bar')
```

##### Escaping a path

```puppet
$result = systemd::escape('/mnt/foobar',true)
```

#### `systemd::escape(String[1] $input, Boolean $path = false)`

The systemd::escape function.

Returns: `String` String

##### Examples

###### Escaping a string

```puppet
$result = systemd::escape('foo::bar')
```

###### Escaping a path

```puppet
$result = systemd::escape('/mnt/foobar',true)
```

##### `input`

Data type: `String[1]`

Input string

##### `path`

Data type: `Boolean`

Use path (-p) ornon-path  style escaping.

### <a name="systemd--systemd_escape"></a>`systemd::systemd_escape`

Type: Ruby 4.x API

Escape strings by call the `systemd-escape` command in the background.

#### `systemd::systemd_escape(String $input, Optional[Optional[Boolean]] $path)`

The systemd::systemd_escape function.

Returns: `String`

##### `input`

Data type: `String`

Input string

##### `path`

Data type: `Optional[Optional[Boolean]]`

Use path (-p) ornon-path  style escaping.

## Data types

### <a name="Systemd--Boolean"></a>`Systemd::Boolean`

Defines systemd boolean type representation

Alias of `Variant[Systemd::Boolean::True, Systemd::Boolean::False]`

### <a name="Systemd--Boolean--False"></a>`Systemd::Boolean::False`

Defines systemd boolean "false" type representation

Alias of `Variant[Integer[0,0], Enum['no', 'false'], Boolean[false]]`

### <a name="Systemd--Boolean--True"></a>`Systemd::Boolean::True`

Defines systemd boolean "true" type representation

Alias of `Variant[Integer[1], Enum['yes', 'true'], Boolean[true]]`

### <a name="Systemd--Capabilities"></a>`Systemd::Capabilities`

Defines allowed capabilities

Alias of `Variant[Pattern[/^~?(CAP_[A-Z_]+ *)+$/]]`

### <a name="Systemd--CoredumpSettings"></a>`Systemd::CoredumpSettings`

Configurations for coredump.conf

* **See also**
  * https://www.freedesktop.org/software/systemd/man/coredump.conf.html

Alias of

```puppet
Struct[{
    Optional['Storage']         => Enum['none', 'external', 'journal'],
    Optional['Compress']        => Enum['yes','no'],
    Optional['ProcessSizeMax']  => Systemd::Unit::Amount,
    Optional['ExternalSizeMax'] => Systemd::Unit::Amount,
    Optional['EnterNamespace']  => Enum['yes','no'],
    Optional['JournalSizeMax']  => Systemd::Unit::Amount,
    Optional['MaxUse']          => Systemd::Unit::Amount,
    Optional['KeepFree']        => Systemd::Unit::Amount,
  }]
```

### <a name="Systemd--Dropin"></a>`Systemd::Dropin`

custom datatype that validates filenames/paths for valid systemd dropin files

Alias of `Pattern['^[^/]+\.conf$']`

### <a name="Systemd--Interface"></a>`Systemd::Interface`

network interface definition

Alias of

```puppet
Struct[{
    filename => Optional[String[1]],
    network  => Optional[Systemd::Interface::Network],
    netdev   => Optional[Systemd::Interface::Netdev],
    link     => Optional[Systemd::Interface::Link],
}]
```

### <a name="Systemd--Interface--Link"></a>`Systemd::Interface::Link`

Network device configuration(Link)

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.link.html

Alias of

```puppet
Struct[{
    'Match'  => Optional[Systemd::Interface::Link::Match],
    'Link'   => Optional[Systemd::Interface::Link::Link],
    'SR-IOV' => Optional[Systemd::Interface::Link::Sr_iov],
}]
```

### <a name="Systemd--Interface--Link--Link"></a>`Systemd::Interface::Link::Link`

Network device configuration(Link) Link section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.link.html

Alias of

```puppet
Struct[{
    'Description'                         => Optional[String[1]],
    'Property'                            => Optional[String[1]],
    'ImportProperty'                      => Optional[String[1]],
    'UnsetProperty'                       => Optional[String[1]],
    'Alias'                               => Optional[String[1]],
    'MACAddressPolicy'                    => Optional[Enum['persistent', 'random', 'none', '']],
    'MACAddress'                          => Optional[String[1]],
    'NamePolicy'                          => Optional[Enum[
        'kernel', 'database', 'onboard', 'slot',
        'path', 'mac', 'keep'
    ]],
    'Name'                                => Optional[String[1]],
    'AlternativeNamesPolicy'              => Optional[String[1]],
    'AlternativeName'                     => Optional[String[1]],
    'TransmitQueues'                      => Optional[Integer[1,4096]],
    'ReceiveQueues'                       => Optional[Integer[1,4096]],
    'TransmitQueueLength'                 => Optional[Integer[0, 4294967294]],
    'MTUBytes'                            => Optional[Integer[1280]],
    'BitsPerSecond'                       => Optional[String[1]],
    'Duplex'                              => Optional[String[1]],
    'AutoNegotiation'                     => Optional[Enum['yes','no']],
    'WakeOnLan'                           => Optional[Enum[
        'phy', 'unicast', 'multicast', 'broadcast',
        'arp', 'magic', 'secureon'
    ]],
    'WakeOnLanPassword'                   => Optional[String[1]],
    'Port'                                => Optional[Enum['tp', 'aui', 'bnc', 'mii', 'fibre']],
    'Advertise'                           => Optional[Variant[
        Systemd::Interface::Link::Link_advertise,
        Array[Systemd::Interface::Link::Link_advertise]
    ]],
    'ReceiveChecksumOffload'              => Optional[Enum['yes','no']],
    'TransmitChecksumOffload'             => Optional[Enum['yes','no']],
    'TCPSegmentationOffload'              => Optional[Enum['yes','no']],
    'TCP6SegmentationOffload'             => Optional[Enum['yes','no']],
    'GenericSegmentationOffload'          => Optional[Enum['yes','no']],
    'GenericReceiveOffload'               => Optional[Enum['yes','no']],
    'LargeReceiveOffload'                 => Optional[Enum['yes','no']],
    'ReceivePacketSteeringCPUMask'        => Optional[String[1]],
    'ReceiveVLANCTAGHardwareAcceleration' => Optional[Enum['yes','no']],
    'TransmitVLANCTAGHardwareAcceleration'=> Optional[Enum['yes','no']],
    'ReceiveVLANCTAGFilter'               => Optional[Enum['yes','no']],
    'TransmitVLANSTAGHardwareAcceleration'=> Optional[Enum['yes','no']],
    'NTupleFilter'                        => Optional[Enum['yes','no']],
    'RxChannels'                          => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'TxChannels'                          => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'OtherChannels'                       => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'CombinedChannels'                    => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'RxBufferSize'                        => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'RxMiniBufferSize'                    => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'RxJumboBufferSize'                   => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'TxBufferSize'                        => Optional[Variant[Enum['max'],Integer[1,4294967295]]],
    'RxFlowControl'                       => Optional[Enum['yes','no']],
    'TxFlowControl'                       => Optional[Enum['yes','no']],
    'AutoNegotiationFlowControl'          => Optional[Enum['yes','no']],
    'GenericSegmentOffloadMaxBytes'       => Optional[String[1]],
    'GenericSegmentOffloadMaxSegments'    => Optional[Integer[1, 65535]],
    'UseAdaptiveRxCoalesce'               => Optional[Enum['yes','no']],
    'UseAdaptiveTxCoalesce'               => Optional[Enum['yes','no']],
    'RxCoalesceSec'                       => Optional[Integer],
    'RxCoalesceIrqSec'                    => Optional[Integer],
    'RxCoalesceLowSec'                    => Optional[Integer],
    'RxCoalesceHighSec'                   => Optional[Integer],
    'TxCoalesceSec'                       => Optional[Integer],
    'TxCoalesceIrqSec'                    => Optional[Integer],
    'TxCoalesceLowSec'                    => Optional[Integer],
    'TxCoalesceHighSec'                   => Optional[Integer],
    'RxMaxCoalescedFrames'                => Optional[Integer],
    'RxMaxCoalescedIrqFrames'             => Optional[Integer],
    'RxMaxCoalescedLowFrames'             => Optional[Integer],
    'RxMaxCoalescedHighFrames'            => Optional[Integer],
    'TxMaxCoalescedFrames'                => Optional[Integer],
    'TxMaxCoalescedIrqFrames'             => Optional[Integer],
    'TxMaxCoalescedLowFrames'             => Optional[Integer],
    'TxMaxCoalescedHighFrames'            => Optional[Integer],
    'CoalescePacketRateLow'               => Optional[Integer],
    'CoalescePacketRateHigh'              => Optional[Integer],
    'CoalescePacketRateSampleIntervalSec' => Optional[Integer],
    'StatisticsBlockCoalesceSec'          => Optional[Integer[1]],
    'MDI'                                 => Optional[Enum['straight', 'mdi', 'crossover', 'mdi-x', 'mdix', 'auto']],
    'SR_IOVVirtualFunctions'              => Optional[Integer[0, 2147483647]],
}]
```

### <a name="Systemd--Interface--Link--Link_advertise"></a>`Systemd::Interface::Link::Link_advertise`

Network device configuration(Link), link advertise speeds

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.link.html

Alias of `Enum['10baset-full', '10baset1l-full', '10baset-half', '100basefx-full', '100baset-full', '100baset1-full', '100basefx-half', '100baset-half', '1000basekx-ful', '1000baset-full', '1000baset1-full', '1000basex-full', '1000baset-half', '2500baset-full', '2500basex-full', '5000baset-full', '10000baser-fec', '10000basecr-full', '10000baseer-full', '10000basekr-full', '10000basekx4-full', '10000baselr-full', '10000baselrm-full', '10000basesr-full', '10000baset-full', '20000basekr2-full', '20000basemld2-full', '25000basecr-full', '25000basekr-full', '25000basesr-full', '40000basecr4-full', '40000basekr4-full', '40000baselr4-full', '40000basesr4-full', '50000basecr-full', '50000basecr2-full', '50000basedr-full', '50000basekr-full', '50000basekr2-full', '50000baselr-er-fr-full', '50000basesr-full', '50000basesr2-full', '56000basecr4-full', '56000basekr4-full', '56000baselr4-full', '56000basesr4-full', '100000basecr-full', '100000basecr2-full', '100000basecr4-full', '100000basedr-full', '100000basedr2-full', '100000basekr-full', '100000basekr2-full', '100000basekr4-full', '100000baselr-er-fr-full', '100000baselr2-er2-fr2-full', '100000baselr4-er4-full', '100000basesr-full', '100000basesr2-full', '100000basesr4-full', '200000basecr2-full', '200000basecr4-full', '200000basedr2-full', '200000basedr4-full', '200000basekr2-full', '200000basekr4-full', '200000baselr2-er2-fr2-full', '200000baselr4-er4-fr4-full', '200000basesr2-full', '200000basesr4-full', '400000basecr4-full', '400000basecr8-full', '400000basedr4-full', '400000basedr8-full', '400000basekr4-full', '400000basekr8-full', '400000baselr4-er4-fr4-full', '400000baselr8-er8-fr8-full', '400000basesr4-full', '400000basesr8-full', '800000basecr8-full', '800000basedr8-2-full', '800000basedr8-full', '800000basekr8-full', '800000basesr8-full', '800000basevr8-full', 'asym-pause', 'aui', 'autonegotiation', 'backplane', 'bnc', 'fec-baser', 'fec-llrs', 'fec-none', 'fec-rs', 'fibre', 'mii', 'pause', 'tp']`

### <a name="Systemd--Interface--Link--Match"></a>`Systemd::Interface::Link::Match`

Network device configuration(Link) Match section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.link.html

Alias of

```puppet
Struct[{
    'Name'                => Optional[String[1]],
    'MACAddress'          => Optional[String[1]],
    'PermanentMACAddress' => Optional[String[1]],
    'Path'                => Optional[String[1]],
    'Driver'              => Optional[String[1]],
    'Type'                => Optional[String[1]],
    'Kind'                => Optional[String[1]],
    'Property'            => Optional[String[1]],
    'OriginalName'        => Optional[String[1]],
    'SSID'                => Optional[String[1]],
    'BSSID'               => Optional[String[1]],
    'Host'                => Optional[String[1]],
    'Virtualization'      => Optional[String[1]],
    'KernelCommandLine'   => Optional[String[1]],
    'KernelVersion'       => Optional[String[1]],
    'Credential'          => Optional[String[1]],
    'Architecture'        => Optional[String[1]],
    'Firmware'            => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Link--Sr_iov"></a>`Systemd::Interface::Link::Sr_iov`

Network device configuration(Link) SR-IOV section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.link.html

Alias of

```puppet
Struct[{
    'VirtualFunction'         => Optional[Integer[0,2147483646]],
    'VLANId'                  => Optional[Integer[1,4095]],
    'QualityOfService'        => Optional[Integer[1,4294967294]],
    'VLANProtocol'            => Optional[Enum['802.1Q', '802.1ad']],
    'MACSpoofCheck'           => Optional[Enum['yes','no']],
    'QueryReceiveSideScaling' => Optional[Enum['yes','no']],
    'Trust'                   => Optional[Enum['yes','no']],
    'LinkState'               => Optional[Enum['yes','no','auto']],
    'MACAddress'              => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Netdev"></a>`Systemd::Interface::Netdev`

interface netdev configs

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Match'                     => Optional[Systemd::Interface::Netdev::Match],
    'NetDev'                    => Optional[Systemd::Interface::Netdev::Netdev],
    'Bridge'                    => Optional[Systemd::Interface::Netdev::Bridge],
    'Vlan'                      => Optional[Systemd::Interface::Netdev::Vlan],
    'MACVLAN'                   => Optional[Systemd::Interface::Netdev::Macvlan],
    'MACVTAP'                   => Optional[Systemd::Interface::Netdev::Macvlan],
    'IPVLAN'                    => Optional[Systemd::Interface::Netdev::Ipvlan],
    'IPVTAP'                    => Optional[Systemd::Interface::Netdev::Ipvlan],
    'VXLAN'                     => Optional[Systemd::Interface::Netdev::Vxlan],
    'GENEVE'                    => Optional[Systemd::Interface::Netdev::Geneve],
    'BareUDP'                   => Optional[Systemd::Interface::Netdev::Bareudp],
    'L2TP'                      => Optional[Systemd::Interface::Netdev::L2tp],
    'L2TPSession'               => Optional[Systemd::Interface::Netdev::L2tpsession],
    'MACsec'                    => Optional[Systemd::Interface::Netdev::Macsec],
    'MACsecReceiveChannel'      => Optional[Systemd::Interface::Netdev::Macsecreceivechannel],
    'MACsecTransmitAssociation' => Optional[Systemd::Interface::Netdev::Macsectransmitassociation],
    'MACsecReceiveAssociation'  => Optional[Systemd::Interface::Netdev::Macsecreceiveassociation],
    'Tunnel'                    => Optional[Systemd::Interface::Netdev::Tunnel],
    'FooOverUDP'                => Optional[Systemd::Interface::Netdev::Foooverudp],
    'Peer'                      => Optional[Systemd::Interface::Netdev::Peer],
    'VXCAN'                     => Optional[Systemd::Interface::Netdev::Vxcan],
    'Tun'                       => Optional[Systemd::Interface::Netdev::Tun],
    'Tap'                       => Optional[Systemd::Interface::Netdev::Tun],
    'WireGuard'                 => Optional[Systemd::Interface::Netdev::Wireguard],
    'WireGuardPeer'             => Optional[Systemd::Interface::Netdev::Wireguardpeer],
    'Bond'                      => Optional[Systemd::Interface::Netdev::Bond],
    'Xfrm'                      => Optional[Systemd::Interface::Netdev::Xfrm],
    'VRF'                       => Optional[Systemd::Interface::Netdev::Vrf],
    'BatmanAdvanced'            => Optional[Systemd::Interface::Netdev::Batmanadvanced],
    'IPoIB'                     => Optional[Systemd::Interface::Netdev::Ipoib],
    'WLAN'                      => Optional[Systemd::Interface::Netdev::Wlan],
}]
```

### <a name="Systemd--Interface--Netdev--Bareudp"></a>`Systemd::Interface::Netdev::Bareudp`

netdev BareUDP section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'DestinationPort' => Integer[1, 65535],
    'EtherType'       => Enum['ipv4', 'ipv6', 'mpls-uc', 'mpls-mc'],
}]
```

### <a name="Systemd--Interface--Netdev--Batmanadvanced"></a>`Systemd::Interface::Netdev::Batmanadvanced`

netdev BatmanAdvanced section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'GatewayMode'           => Optional[Enum['off', 'server', 'client']],
    'Aggregation'           => Optional[Enum['yes','no']],
    'BridgeLoopAvoidance'   => Optional[Enum['yes','no']],
    'DistributedArpTable'   => Optional[Enum['yes','no']],
    'Fragmentation'         => Optional[Enum['yes','no']],
    'HopPenalty'            => Optional[Integer[0,255]],
    'OriginatorIntervalSec' => Optional[String[1]],
    'GatewayBandwidthDown'  => Optional[String[1]],
    'GatewayBandwidthUp'    => Optional[String[1]],
    'RoutingAlgorithm'      => Optional[Enum['batman-v', 'batman-iv']],
}]
```

### <a name="Systemd--Interface--Netdev--Bond"></a>`Systemd::Interface::Netdev::Bond`

netdev Bond section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Mode'                         => Optional[Enum[
        'balance-rr', 'active-backup', 'balance-xor',
        'broadcast', '802.3ad', 'balance-tlb', 'balance-alb'
    ]],
    'TransmitHashPolicy'           => Optional[Enum['layer2', 'layer3+4', 'layer2+3', 'encap2+3', 'encap3+4']],
    'LACPTransmitRate'             => Optional[Enum['slow','fast']],
    'MIIMonitorSec'                => Optional[Integer],
    'PeerNotifyDelaySec'           => Optional[Integer[0,300]],
    'UpDelaySec'                   => Optional[Integer[0]],
    'DownDelaySec'                 => Optional[Integer[0]],
    'LearnPacketIntervalSec'       => Optional[Integer[1]],
    'AdSelect'                     => Optional[Enum['stable', 'bandwidth', 'count']],
    'AdActorSystemPriority'        => Optional[Integer[1,65535]],
    'AdUserPortKey'                => Optional[Integer[1,1023]],
    'AdActorSystem'                => Optional[String[1]],
    'FailOverMACPolicy'            => Optional[Enum['none', 'active', 'follow']],
    'ARPValidate'                  => Optional[Enum['none', 'active', 'backup', 'all']],
    'ARPIntervalSec'               => Optional[String[1]],
    'ARPIPTargets'                 => Optional[String[1]],
    'ARPAllTargets'                => Optional[Enum['any','all']],
    'PrimaryReselectPolicy'        => Optional[Enum['alwayas', 'better', 'failure']],
    'ResendIGMP'                   => Optional[Integer[0,255]],
    'PacketsPerSlave'              => Optional[Integer[0,65535]],
    'GratuitousARP'                => Optional[Integer[0,255]],
    'AllSlavesActive'              => Optional[Enum['yes','no']],
    'DynamicTransmitLoadBalancing' => Optional[Enum['yes','no']],
    'MinLinks'                     => Optional[Integer],
    'ARPMissedMax'                 => Optional[Integer],
}]
```

### <a name="Systemd--Interface--Netdev--Bridge"></a>`Systemd::Interface::Netdev::Bridge`

netdev Bridge section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Description'          => Optional[String[1]],
    'HelloTimeSec'         => Optional[Integer[1]],
    'MaxAgeSec'            => Optional[Integer[1]],
    'ForwardDelaySec'      => Optional[Integer[1]],
    'AgeingTimeSec'        => Optional[Integer[1]],
    'Priority'             => Optional[Integer[0, 65535]],
    'GroupForwardMask'     => Optional[String[1]],
    'DefaultPVID'          => Optional[Variant[Enum['none'],String[1, 4094]]],
    'MulticastQuerier'     => Optional[Enum['yes','no']],
    'MulticastSnooping'    => Optional[Enum['yes','no']],
    'VLANFiltering'        => Optional[Enum['yes','no']],
    'STP'                  => Optional[Enum['yes','no']],
    'MulticastIGMPVersion' => Optional[Integer[2,3]],
}]
```

### <a name="Systemd--Interface--Netdev--Foooverudp"></a>`Systemd::Interface::Netdev::Foooverudp`

netdev FooOverUDP section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Encapsulation'             => Optional[Enum['FooOverUDP','GenericUDPEncapsulation']],
    'Port'                      => Integer[1],
    'PeerPort'                  => Optional[Integer[1]],
    'Protocol'                  => Optional[Variant[Enum['gre','ipip'], Integer[1,255]]],
    'Peer'                      => Optional[String[1]],
    'Local'                     => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Netdev--Geneve"></a>`Systemd::Interface::Netdev::Geneve`

netdev GENEVE section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Id'                   => Integer[0,16777215],
    'Remote'               => Optional[String[1]],
    'TOS'                  => Optional[Integer[1,255]],
    'TTL'                  => Optional[Variant[Enum['inherit'], Integer[0,255]]],
    'UDPChecksum'          => Optional[Enum['yes', 'no']],
    'UDP6ZeroChecksumTx'   => Optional[Enum['yes', 'no']],
    'UDP6ZeroChecksumRx'   => Optional[Enum['yes', 'no']],
    'DestinationPort'      => Optional[Integer[1]],
    'FlowLabel'            => Optional[String[1]],
    'IPDoNotFragment'      => Optional[Enum['yes', 'no']],
    'InheritInnerProtocol' => Optional[Enum['yes', 'no']],
}]
```

### <a name="Systemd--Interface--Netdev--Ipoib"></a>`Systemd::Interface::Netdev::Ipoib`

netdev IPoIB section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'PartitionKey'                  => Optional[Integer[1]],
    'Mode'                          => Optional[Enum['datagram','connected']],
    'IgnoreUserspaceMulticastGroup' => Optional[Enum['yes', 'no']],
}]
```

### <a name="Systemd--Interface--Netdev--Ipvlan"></a>`Systemd::Interface::Netdev::Ipvlan`

netdev IPVLAN and IPVTAP section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Mode'  => Optional[Enum['L2', 'L3', 'L3S']],
    'Flags' => Optional[Enum['bridge', 'private', 'vepa']],
}]
```

### <a name="Systemd--Interface--Netdev--L2tp"></a>`Systemd::Interface::Netdev::L2tp`

netdev L2TP section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'TunnelId'           => Integer[1,4294967295],
    'PeerTunnelId'       => Integer[1,4294967295],
    'Remote'             => String[1],
    'Local'              => Optional[Variant[Enum['auto', 'static', 'dynamic'],String[1]]],
    'EncapsulationType'  => Optional[Enum['udp','ip']],
    'UDPSourcePort'      => Optional[Integer[1]],
    'UDPDestinationPort' => Optional[Integer[1]],
    'UDPChecksum'        => Optional[Enum['yes' ,'no']],
    'UDP6ZeroChecksumTx' => Optional[Enum['yes' ,'no']],
    'UDP6ZeroChecksumRx' => Optional[Enum['yes' ,'no']],
}]
```

### <a name="Systemd--Interface--Netdev--L2tpsession"></a>`Systemd::Interface::Netdev::L2tpsession`

netdev L2TPSession section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Name'                 => String[1],
    'SessionId'            => Integer[1,4294967295],
    'PeerSessionId'        => Integer[1,4294967295],
    'Layer2SpecificHeader' => Optional[Enum['none', 'default']],
}]
```

### <a name="Systemd--Interface--Netdev--Macsec"></a>`Systemd::Interface::Netdev::Macsec`

netdev MACsec section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Port' => Optional[Integer[1, 65535]],
    'Encrypt' => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Netdev--Macsecreceiveassociation"></a>`Systemd::Interface::Netdev::Macsecreceiveassociation`

netdev MACsecReceiveAssociation section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Port'       => Integer[1, 65535],
    'MACAddress' => String[1],
    'PacketNumber'   => Optional[Variant[Integer[1,4],Integer[294,295],Integer[967,967]]],
    'KeyId'          => Optional[Integer[0,255]],
    'Key'            => Optional[String[1]],
    'KeyFile'        => Optional[String[1]],
    'Activate'       => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Netdev--Macsecreceivechannel"></a>`Systemd::Interface::Netdev::Macsecreceivechannel`

netdev MACsecReceiveChannel section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Port'       => Integer[1, 65535],
    'MACAddress' => String[1],
}]
```

### <a name="Systemd--Interface--Netdev--Macsectransmitassociation"></a>`Systemd::Interface::Netdev::Macsectransmitassociation`

netdev MACsecTransmitAssociation section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'PacketNumber'   => Optional[Variant[Integer[1,4],Integer[294,295],Integer[967,967]]],
    'KeyId'          => Optional[Integer[0,255]],
    'Key'            => Optional[String[1]],
    'KeyFile'        => Optional[String[1]],
    'Activate'       => Optional[Enum['yes','no']],
    'UseForEncoding' => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Netdev--Macvlan"></a>`Systemd::Interface::Netdev::Macvlan`

netdev MACVLAN and MACVTAP section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Mode'                          => Optional[Enum['private', 'vepa', 'bridge', 'passthru', 'source']],
    'SourceMACAddress'              => Optional[Variant[String[1],Array[String[1]]]],
    'BroadcastMulticastQueueLength' => Optional[Integer[0,4294967294]],
    'BroadcastQueueThreshold'       => Optional[Variant[Enum['no'],Integer[0,2147483647]]],
}]
```

### <a name="Systemd--Interface--Netdev--Match"></a>`Systemd::Interface::Netdev::Match`

netdev match section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Host'              => Optional[String[1]],
    'Virtualization'    => Optional[String[1]],
    'KernelCommandLine' => Optional[String[1]],
    'KernelVersion'     => Optional[String[1]],
    'Credential'        => Optional[String[1]],
    'Architecture'      => Optional[String[1]],
    'Firmware'          => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Netdev--Netdev"></a>`Systemd::Interface::Netdev::Netdev`

netdev NetDev section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Description' => Optional[String[1]],
    'Name'        => Optional[String[1]],
    'Kind'        => Optional[String[1]],
    'MTUBytes'    => Optional[String[1]],
    'MACAddress'  => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Netdev--Peer"></a>`Systemd::Interface::Netdev::Peer`

netdev Peer section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Name' => String[1],
    'MACAddress' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Netdev--Tun"></a>`Systemd::Interface::Netdev::Tun`

netdev Tun and Tap section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'MultiQueue'  => Optional[Enum['yes','no']],
    'PacketInfo'  => Optional[Enum['yes','no']],
    'VNetHeader'  => Optional[Enum['yes','no']],
    'User'        => Optional[String[1]],
    'Group'       => Optional[String[1]],
    'KeepCarrier' => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Netdev--Tunnel"></a>`Systemd::Interface::Netdev::Tunnel`

netdev Tunnel section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'External'                  => Optional[Enum['yes','no']],
    'Local'                     => Optional[Variant[Enum['any', 'ipv4_link_local', 'ipv6_link_local', 'dhcp4', 'dhcp6', 'slaac'], String[1]]],
    'Remote'                    => Optional[Variant[Enum['any'], String[1]]],
    'TOS'                       => Optional[String[1]],
    'TTL'                       => Optional[Integer[1,255]],
    'DiscoverPathMTU'           => Optional[Enum['yes','no']],
    'IgnoreDontFragment'        => Optional[Enum['yes','no']],
    'IPv6FlowLabel'             => Optional[String[1]],
    'CopyDSCP'                  => Optional[Enum['yes','no']],
    'EncapsulationLimit'        => Optional[Integer[1,255]],
    'Key'                       => Optional[String[1]],
    'InputKey'                  => Optional[String[1]],
    'OutputKey'                 => Optional[String[1]],
    'Mode'                      => Optional[Enum['ip6ip6', 'ipip6', 'any']],
    'Independent'               => Optional[Enum['yes','no']],
    'AssignToLoopback'          => Optional[Enum['yes','no']],
    'AllowLocalRemote'          => Optional[Enum['yes','no']],
    'FooOverUDP'                => Optional[Enum['yes','no']],
    'FOUDestinationPort'        => Optional[Integer[1]],
    'FOUSourcePort'             => Optional[Integer[0]],
    'Encapsulation'             => Optional[Enum['FooOverUDP','GenericUDPEncapsulation']],
    'IPv6RapidDeploymentPrefix' => Optional[String[1]],
    'ISATAP'                    => Optional[Enum['yes','no']],
    'SerializeTunneledPackets'  => Optional[Enum['yes','no']],
    'ERSPANVersion'             => Optional[Integer[0,2]],
    'ERSPANIndex'               => Optional[Integer[0,1048575]],
    'ERSPANDirection'           => Optional[Enum['ingress','egress']],
    'ERSPANHardwareId'          => Optional[Integer[0,63]],
}]
```

### <a name="Systemd--Interface--Netdev--Vlan"></a>`Systemd::Interface::Netdev::Vlan`

netdev VLAN section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Id'             => Optional[Integer[0,4094]],
    'Protocol'       => Optional[Enum['802.1q','802.1ad']],
    'GVRP'           => Optional[Enum['yes','no']],
    'MVRP'           => Optional[Enum['yes','no']],
    'LooseBinding'   => Optional[Enum['yes','no']],
    'ReorderHeader'  => Optional[Enum['yes','no']],
    'EgressQOSMaps'  => Optional[String[1]],
    'IngressQOSMaps' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Netdev--Vrf"></a>`Systemd::Interface::Netdev::Vrf`

netdev VRF section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Table' => Integer[0],
}]
```

### <a name="Systemd--Interface--Netdev--Vxcan"></a>`Systemd::Interface::Netdev::Vxcan`

netdev VXCAN section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'Peer' => String[1],
}]
```

### <a name="Systemd--Interface--Netdev--Vxlan"></a>`Systemd::Interface::Netdev::Vxlan`

netdev VXLAN section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'VNI'                      => Optional[Integer[1, 16777215]],
    'Remote'                   => Optional[String[1]],
    'Local'                    => Optional[Variant[Enum['ipv4_link_local', 'ipv6_link_local', 'dhcp4', 'dhcp6', 'slaac'], String[1]]],
    'Group'                    => Optional[String[1]],
    'TOS'                      => Optional[String[1]],
    'TTL'                      => Optional[Variant[Enum['inherit'], Integer[0,255]]],
    'MacLearning'              => Optional[Enum['yes','no']],
    'FDBAgeingSec'             => Optional[String[1]],
    'MaximumFDBEntries'        => Optional[Integer[1]],
    'ReduceARPProxy'           => Optional[Enum['yes','no']],
    'L2MissNotification'       => Optional[Enum['yes','no']],
    'L3MissNotification'       => Optional[Enum['yes','no']],
    'RouteShortCircuit'        => Optional[Enum['yes','no']],
    'UDPChecksum'              => Optional[Enum['yes','no']],
    'UDP6ZeroChecksumTx'       => Optional[Enum['yes','no']],
    'UDP6ZeroChecksumRx'       => Optional[Enum['yes','no']],
    'RemoteChecksumTx'         => Optional[Enum['yes','no']],
    'RemoteChecksumRx'         => Optional[Enum['yes','no']],
    'GroupPolicyExtension'     => Optional[Enum['yes','no']],
    'GenericProtocolExtension' => Optional[Enum['yes','no']],
    'DestinationPort'          => Optional[Integer[1]],
    'PortRange'                => Optional[String[1]],
    'FlowLabel'                => Optional[Integer[0,1048575]],
    'IPDoNotFragment'          => Optional[Enum['yes','no']],
    'Independent'              => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Netdev--Wireguard"></a>`Systemd::Interface::Netdev::Wireguard`

netdev WireGuard section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'PrivateKey'     => Optional[String[1]],
    'PrivateKeyFile' => Optional[Stdlib::Absolutepath],
    'ListenPort'     => Optional[Variant[Integer[1,65535], Enum['auto']]],
    'FirewallMark'   => Optional[Integer[1,4294967295]],
    'RouteTable'     => Optional[Variant[String[1],Integer[1,4294967295]]],
    'RouteMetric'    => Optional[Integer[0,4294967295]],
}]
```

### <a name="Systemd--Interface--Netdev--Wireguardpeer"></a>`Systemd::Interface::Netdev::Wireguardpeer`

netdev WireGuard section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'PublicKey'           => Optional[String[1]],
    'PresharedKey'        => Optional[String[1]],
    'PresharedKeyFile'    => Optional[Stdlib::Absolutepath],
    'AllowedIPs'          => Optional[Variant[String, Array[String]]],
    'Endpoint'            => Optional[String[1]],
    'PersistentKeepalive' => Optional[Variant[Integer[0,65535],Enum['off']]],
    'RouteTable'          => Optional[Variant[Integer[0,4294967295],String[1]]],
    'RouteMetric'         => Optional[Integer[0,4294967295]],
}]
```

### <a name="Systemd--Interface--Netdev--Wlan"></a>`Systemd::Interface::Netdev::Wlan`

netdev WLAN section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'PhysicalDevice' => Optional[Variant[Integer[0], String[1]]],
    'Type'           => Enum['ad-hoc', 'station', 'ap', 'ap-vlan', 'wds',
    'monitor', 'mesh-point', 'p2p-client', 'p2p-go', 'p2p-device', 'ocb', 'nan'],
    'WDS'            => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Netdev--Xfrm"></a>`Systemd::Interface::Netdev::Xfrm`

netdev Xfrm section

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.netdev.html

Alias of

```puppet
Struct[{
    'InterfaceId' => Optional[Variant[Integer[1],String[1]]],
    'Independent' => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Network"></a>`Systemd::Interface::Network`

interface definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Match'                           => Optional[Systemd::Interface::Network::Match],
    'Link'                            => Optional[Systemd::Interface::Network::Link],
    'SR-IOV'                          => Optional[Systemd::Interface::Network::Sr_iov],
    'Network'                         => Optional[Systemd::Interface::Network::Network],
    'Address'                         => Optional[Variant[
        Systemd::Interface::Network::Address,
        Array[Systemd::Interface::Network::Address],
    ]],
    'Neighbor'                        => Optional[Variant[
        Systemd::Interface::Network::Neighbor,
        Array[Systemd::Interface::Network::Neighbor],
    ]],
    'IPv6AddressLabel'                => Optional[Systemd::Interface::Network::Ipv6addresslabel],
    'RoutingPolicyRule'               => Optional[Variant[
        Systemd::Interface::Network::Routingpolicyrule,
        Array[Systemd::Interface::Network::Routingpolicyrule],
    ]],
    'NextHop'                         => Optional[Variant[
        Systemd::Interface::Network::Nexthop,
        Array[Systemd::Interface::Network::Nexthop],
    ]],
    'Route'                           => Optional[Variant[
        Systemd::Interface::Network::Route,
        Array[Systemd::Interface::Network::Route],
    ]],
    'DHCPv4'                          => Optional[Systemd::Interface::Network::Dhcpv4],
    'DHCPv6'                          => Optional[Systemd::Interface::Network::Dhcpv6],
    'DHCPPrefixDelegation'            => Optional[Systemd::Interface::Network::Dhcpprefixdelegation],
    'IPv6AcceptRA'                    => Optional[Systemd::Interface::Network::Ipv6acceptra],
    'DHCPServer'                      => Optional[Systemd::Interface::Network::Dhcpserver],
    'DHCPServerStaticLease'           => Optional[Variant[
        Systemd::Interface::Network::Dhcpserverstaticlease,
        Array[Systemd::Interface::Network::Dhcpserverstaticlease],
    ]],
    'IPv6SendRA'                      => Optional[Systemd::Interface::Network::Ipv6sendra],
    'IPv6Prefix'                      => Optional[Variant[
        Systemd::Interface::Network::Ipv6prefix,
        Array[Systemd::Interface::Network::Ipv6prefix],
    ]],
    'IPv6RoutePrefix'                 => Optional[Variant[
        Systemd::Interface::Network::Ipv6routeprefix,
        Array[Systemd::Interface::Network::Ipv6routeprefix],
    ]],
    'IPv6PREF64Prefix'                => Optional[Variant[
        Systemd::Interface::Network::Ipv6pref64prefix,
        Array[Systemd::Interface::Network::Ipv6pref64prefix],
    ]],
    'Bridge'                          => Optional[Systemd::Interface::Network::Bridge],
    'BridgeFDB'                       => Optional[Variant[
        Systemd::Interface::Network::Bridgefdb,
        Array[Systemd::Interface::Network::Bridgefdb],
    ]],
    'BridgeMDB'                       => Optional[Variant[
        Systemd::Interface::Network::Bridgemdb,
        Array[Systemd::Interface::Network::Bridgemdb],
    ]],
    'LLDP'                            => Optional[Systemd::Interface::Network::Lldp],
    'CAN'                             => Optional[Systemd::Interface::Network::Can],
    'IPoIB'                           => Optional[Systemd::Interface::Network::Ipoib],
    'QDisc'                           => Optional[Systemd::Interface::Network::Qdisc],
    'NetworkEmulator'                 => Optional[Systemd::Interface::Network::Networkemulator],
    'TokenBucketFilter'               => Optional[Systemd::Interface::Network::Tokenbucketfilter],
    'PIE'                             => Optional[Systemd::Interface::Network::Pie],
    'FlowQueuePIE'                    => Optional[Systemd::Interface::Network::Flowqueuepie],
    'StochasticFairBlue'              => Optional[Systemd::Interface::Network::Stochasticfairblue],
    'StochasticFairnessQueueing'      => Optional[Systemd::Interface::Network::Stochasticfairnessqueueing],
    'BFIFO'                           => Optional[Systemd::Interface::Network::Bfifo],
    'PFIFO'                           => Optional[Systemd::Interface::Network::Pfifo],
    'PFIFOHeadDrop'                   => Optional[Systemd::Interface::Network::Pfifoheaddrop],
    'PFIFOFast'                       => Optional[Systemd::Interface::Network::Pfifofast],
    'CAKE'                            => Optional[Systemd::Interface::Network::Cake],
    'ControlledDelay'                 => Optional[Systemd::Interface::Network::Controlleddelay],
    'DeficitRoundRobinScheduler'      => Optional[Systemd::Interface::Network::Deficitroundrobinscheduler],
    'DeficitRoundRobinSchedulerClass' => Optional[Systemd::Interface::Network::Deficitroundrobinschedulerclass],
    'EnhancedTransmissionSelection'   => Optional[Systemd::Interface::Network::Enhancedtransmissionselection],
    'GenericRandomEarlyDetection'     => Optional[Systemd::Interface::Network::Genericrandomearlydetection],
    'FairQueueingControlledDelay'     => Optional[Systemd::Interface::Network::Fairqueueingcontrolleddelay],
    'FairQueueing'                    => Optional[Systemd::Interface::Network::Fairqueueing],
    'TrivialLinkEqualizer'            => Optional[Systemd::Interface::Network::Triviallinkequalizer],
    'HierarchyTokenBucket'            => Optional[Systemd::Interface::Network::Hierarchytokenbucket],
    'HierarchyTokenBucketClass'       => Optional[Systemd::Interface::Network::Hierarchytokenbucketclass],
    'HeavyHitterFilter'               => Optional[Systemd::Interface::Network::Heavyhitterfilter],
    'QuickFairQueueing'               => Optional[Systemd::Interface::Network::Quickfairqueueing],
    'QuickFairQueueingClass'          => Optional[Systemd::Interface::Network::Quickfairqueueingclass],
    'BridgeVLAN'                      => Optional[Systemd::Interface::Network::Bridgevlan],
}]
```

### <a name="Systemd--Interface--Network--Address"></a>`Systemd::Interface::Network::Address`

interface network Address section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Address'                   => String[1],
    'Peer'                      => Optional[String[1]],
    'Broadcast'                 => Optional[String[1]],
    'Label'                     => Optional[String[1,15]],
    'PreferredLifetime'         => Optional[Enum['forever', 'infinity', '0']],
    'Scope'                     => Optional[Variant[Enum['global', 'link', 'host'],Integer[0,255]]],
    'RouteMetric'               => Optional[Integer[0,4294967295]],
    'HomeAddress'               => Optional[Enum['yes', 'no']],
    'DuplicateAddressDetection' => Optional[Enum['ipv4', 'ipv6', 'both', 'none']],
    'ManageTemporaryAddress'    => Optional[Enum['yes', 'no']],
    'AddPrefixRoute'            => Optional[Enum['yes', 'no']],
    'AutoJoin'                  => Optional[Enum['yes', 'no']],
    'NetLabel'                  => Optional[String[1]],
    'NFTSet'                    => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Bfifo"></a>`Systemd::Interface::Network::Bfifo`

interface network BFIFO section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'     => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'     => Optional[String[1]],
    'LimitBytes' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Bridge"></a>`Systemd::Interface::Network::Bridge`

interface network Bridge section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'UnicastFlood'        => Optional[Enum['yes', 'no']],
    'MulticastFlood'      => Optional[Enum['yes', 'no']],
    'MulticastToUnicast'  => Optional[Enum['yes', 'no']],
    'NeighborSuppression' => Optional[Enum['yes', 'no']],
    'Learning'            => Optional[Enum['yes', 'no']],
    'HairPin'             => Optional[Enum['yes', 'no']],
    'Isolated'            => Optional[Enum['yes', 'no']],
    'UseBPDU'             => Optional[Enum['yes', 'no']],
    'FastLeave'           => Optional[Enum['yes', 'no']],
    'AllowPortToBeRoot'   => Optional[Enum['yes', 'no']],
    'ProxyARP'            => Optional[Enum['yes', 'no']],
    'ProxyARPWiFi'        => Optional[Enum['yes', 'no']],
    'MulticastRouter'     => Optional[Enum['no', 'query', 'permanent', 'temporary']],
    'Cost'                => Optional[Integer[1, 65535]],
    'Priority'            => Optional[Integer[0,63]],
}]
```

### <a name="Systemd--Interface--Network--Bridgefdb"></a>`Systemd::Interface::Network::Bridgefdb`

interface network BridgeFDB section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'MACAddress'        => String[1],
    'Destination'       => Optional[String[1]],
    'VLANId'            => Optional[String[1]],
    'VNI'               => Optional[Integer[1, 16777215]],
    'AssociatedWith'    => Optional[Enum['use', 'self', 'master', 'router']],
    'OutgoingInterface' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Bridgemdb"></a>`Systemd::Interface::Network::Bridgemdb`

interface network BridgeMDB section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'MulticastGroupAddress' => Optional[String[1]],
    'VLANID'                => Optional[Integer[0,4094]],
}]
```

### <a name="Systemd--Interface--Network--Bridgevlan"></a>`Systemd::Interface::Network::Bridgevlan`

interface network BridgeVLAN section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'VLAN'           => Optional[Variant[String[1], Array[String[1]]]],
    'EgressUntagged' => Optional[Variant[String[1], Array[String[1]]]],
    'PVID'           => Optional[Variant[Enum['no','false'],Integer[1]]],
}]
```

### <a name="Systemd--Interface--Network--Cake"></a>`Systemd::Interface::Network::Cake`

interface network CAKE section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'                 => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Bandwidth'              => Optional[String[1]],
    'AutoRateIngress'        => Optional[Enum['yes','no']],
    'OverheadBytes'          => Optional[Integer[-64,256]],
    'MPUBytes'               => Optional[Integer[1,256]],
    'CompensationMode'       => Optional[Enum['none', 'atm', 'ptm']],
    'UseRawPacketSize'       => Optional[Enum['yes','no']],
    'FlowIsolationMode'      => Optional[Enum['none','src-host', 'dst-host', 'hosts', 'flows','dual-src-host', 'dual-dst-host', 'triple']],
    'NAT'                    => Optional[Enum['yes','no']],
    'PriorityQueueingPreset' => Optional[Enum['besteffort','precedence', 'diffserv8', 'diffserv4', 'diffserv3']],
    'FirewallMark'           => Optional[Integer[1,4294967295]],
    'Wash'                   => Optional[Enum['yes','no']],
    'SplitGSO'               => Optional[Enum['yes','no']],
    'RTTSec'                 => Optional[String[1]],
    'AckFilter'              => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Network--Can"></a>`Systemd::Interface::Network::Can`

interface network CAN section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'BitRate'                 => Optional[String[1]],
    'SamplePoint'             => Optional[String[1]],
    'TimeQuantaNSec'          => Optional[String[1]],
    'PropagationSegment'      => Optional[Integer[0,4294967295]],
    'PhaseBufferSegment1'     => Optional[Integer[0,4294967295]],
    'PhaseBufferSegment2'     => Optional[Integer[0,4294967295]],
    'SyncJumpWidth'           => Optional[Integer[0,4294967295]],
    'DataBitRate'             => Optional[String[1]],
    'DataSamplePoint'         => Optional[String[1]],
    'DataTimeQuantaNSec'      => Optional[String[1]],
    'DataPropagationSegment'  => Optional[String[1]],
    'DataPhaseBufferSegment1' => Optional[String[1]],
    'DataPhaseBufferSegment2' => Optional[String[1]],
    'DataSyncJumpWidth'       => Optional[String[1]],
    'FDMode'                  => Optional[Enum['yes','no']],
    'FDNonISO'                => Optional[Enum['yes','no']],
    'RestartSec'              => Optional[String[1]],
    'Termination'             => Optional[Enum['yes','no']],
    'TripleSampling'          => Optional[Enum['yes','no']],
    'BusErrorReporting'       => Optional[Enum['yes','no']],
    'ListenOnly'              => Optional[Enum['yes','no']],
    'Loopback'                => Optional[Enum['yes','no']],
    'OneShot'                 => Optional[Enum['yes','no']],
    'PresumeAck'              => Optional[Enum['yes','no']],
    'ClassicDataLengthCode'   => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Network--Controlleddelay"></a>`Systemd::Interface::Network::Controlleddelay`

interface network ControlledDelay section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'         => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'         => Optional[String[1]],
    'PacketLimit'    => Optional[Integer[0,4294967294]],
    'TargetSec'      => Optional[String[1]],
    'IntervalSec'    => Optional[String[1]],
    'CEThresholdSec' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Deficitroundrobinscheduler"></a>`Systemd::Interface::Network::Deficitroundrobinscheduler`

interface network DeficitRoundRobinScheduler section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Deficitroundrobinschedulerclass"></a>`Systemd::Interface::Network::Deficitroundrobinschedulerclass`

interface network DeficitRoundRobinSchedulerClass section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'       => Optional[Variant[Enum['root'], String[1]]],
    'ClassId'      => Optional[String[1]],
    'QuantumBytes' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Dhcpprefixdelegation"></a>`Systemd::Interface::Network::Dhcpprefixdelegation`

interface network DHCPPrefixDelegation section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'UplinkInterface'        => Optional[String[1]],
    'SubnetId'               => Optional[String[1]],
    'Announce'               => Optional[Enum['yes','no']],
    'Assign'                 => Optional[Enum['yes','no']],
    'Token'                  => Optional[String[1]],
    'ManageTemporaryAddress' => Optional[Enum['yes', 'no']],
    'RouteMetric'            => Optional[Integer[0,4294967295]],
    'NetLabel'               => Optional[String[1]],
    'NFTSet'                 => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Dhcpserver"></a>`Systemd::Interface::Network::Dhcpserver`

interface network DHCPServer section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'ServerAddress'        => Optional[String[1]],
    'PoolOffset'           => Optional[String[1]],
    'PoolSize'             => Optional[String[1]],
    'DefaultLeaseTimeSec'  => Optional[String[1]],
    'MaxLeaseTimeSec'      => Optional[String[1]],
    'UplinkInterface'      => Optional[String[1]],
    'EmitDNS'              => Optional[Enum['yes','no']],
    'DNS'                  => Optional[String[1]],
    'EmitNTP'              => Optional[Enum['yes','no']],
    'NTP'                  => Optional[String[1]],
    'EmitSIP'              => Optional[Enum['yes','no']],
    'SIP'                  => Optional[String[1]],
    'EmitPOP3'             => Optional[Enum['yes','no']],
    'POP3'                 => Optional[String[1]],
    'EmitSMTP'             => Optional[Enum['yes','no']],
    'SMTP'                 => Optional[String[1]],
    'EmitLPR'              => Optional[Enum['yes','no']],
    'LPR'                  => Optional[String[1]],
    'EmitRouter'           => Optional[Enum['yes','no']],
    'Router'               => Optional[String[1]],
    'EmitTimezone'         => Optional[Enum['yes','no']],
    'Timezone'             => Optional[String[1]],
    'BootServerAddress'    => Optional[String[1]],
    'BootServerName'       => Optional[String[1]],
    'BootFilename'         => Optional[String[1]],
    'IPv6OnlyPreferredSec' => Optional[String[1]],
    'SendOption'           => Optional[String[1]],
    'SendVendorOption'     => Optional[String[1]],
    'BindToInterface'      => Optional[Enum['yes','no']],
    'RelayTarget'          => Optional[String[1]],
    'RelayAgentCircuitId'  => Optional[String[1]],
    'RelayAgentRemoteId'   => Optional[String[1]],
    'RapidCommit'          => Optional[Enum['yes','no']],
    'PersistLeases'        => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Network--Dhcpserverstaticlease"></a>`Systemd::Interface::Network::Dhcpserverstaticlease`

interface network DHCPServerStaticLease section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'MACAddress' => String[1],
    'Address'    => String[1],
}]
```

### <a name="Systemd--Interface--Network--Dhcpv4"></a>`Systemd::Interface::Network::Dhcpv4`

interface network DHCPv4 section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'RequestAddress'                 => Optional[String[1]],
    'SendHostname'                   => Optional[Enum['yes','no']],
    'Hostname'                       => Optional[String[1]],
    'MUDURL'                         => Optional[String[1]],
    'ClientIdentifier'               => Optional[String[1]],
    'VendorClassIdentifier'          => Optional[String[1]],
    'UserClass'                      => Optional[String[1]],
    'DUIDType'                       => Optional[String[1]],
    'DUIDRawData'                    => Optional[String[1]],
    'IAID'                           => Optional[String[1]],
    'RapidCommit'                    => Optional[Enum['yes','no']],
    'Anonymize'                      => Optional[Enum['yes','no']],
    'RequestOptions'                 => Optional[String[1]],
    'SendOption'                     => Optional[String[1]],
    'SendVendorOption'               => Optional[String[1]],
    'IPServiceType'                  => Optional[Enum['none','CS6', 'CS3']],
    'SocketPriority'                 => Optional[Integer[0,6]],
    'Label'                          => Optional[String[1]],
    'UseDNS'                         => Optional[Enum['yes','no']],
    'RoutesToDNS'                    => Optional[Enum['yes','no']],
    'UseNTP'                         => Optional[Enum['yes','no']],
    'RoutesToNTP'                    => Optional[Enum['yes','no']],
    'UseSIP'                         => Optional[Enum['yes','no']],
    'UseCaptivePortal'               => Optional[Enum['yes','no']],
    'UseMTU'                         => Optional[Enum['yes','no']],
    'UseHostname'                    => Optional[Enum['yes','no']],
    'UseDomains'                     => Optional[Enum['yes','no']],
    'UseRoutes'                      => Optional[Enum['yes','no']],
    'RouteMetric'                    => Optional[Integer[0,4294967295]],
    'RouteTable'                     => Optional[Variant[String[1],Integer[0,4294967295]]],
    'RouteMTUBytes'                  => Optional[String[1]],
    'QuickAck'                       => Optional[Enum['yes','no']],
    'InitialCongestionWindow'        => Optional[String[1]],
    'InitialAdvertisedReceiveWindow' => Optional[String[1]],
    'UseGateway'                     => Optional[Enum['yes','no']],
    'UseTimezone'                    => Optional[Enum['yes','no']],
    'Use6RD'                         => Optional[Enum['yes','no']],
    'IPv6OnlyMode'                   => Optional[Enum['yes','no']],
    'FallbackLeaseLifetimeSec'       => Optional[Enum['forever', 'infinity']],
    'RequestBroadcast'               => Optional[Enum['yes','no']],
    'MaxAttempts'                    => Optional[Variant[Integer[0],Enum['forever', 'infinity']]],
    'ListenPort'                     => Optional[String[1]],
    'ServerPort'                     => Optional[String[1]],
    'DenyList'                       => Optional[String[1]],
    'AllowList'                      => Optional[String[1]],
    'SendRelease'                    => Optional[Enum['yes','no']],
    'SendDecline'                    => Optional[Enum['yes','no']],
    'NetLabel'                       => Optional[String[1]],
    'NFTSet'                         => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Dhcpv6"></a>`Systemd::Interface::Network::Dhcpv6`

interface network DHCPv6 section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'MUDURL'                         => Optional[String[1]],
    'IAID'                           => Optional[String[1]],
    'DUIDType'                       => Optional[String[1]],
    'DUIDRawData'                    => Optional[String[1]],
    'RequestOptions'                 => Optional[String[1]],
    'SendOption'                     => Optional[Integer[1,65536]],
    'SendVendorOption'               => Optional[String[1]],
    'UserClass'                      => Optional[String[1]],
    'VendorClass'                    => Optional[String[1]],
    'PrefixDelegationHint'           => Optional[String[1]],
    'RapidCommit'                    => Optional[Enum['yes','no']],
    'SendHostname'                   => Optional[Enum['yes','no']],
    'Hostname'                       => Optional[String[1]],
    'UseAddress'                     => Optional[Enum['yes','no']],
    'UseCaptivePortal'               => Optional[Enum['yes','no']],
    'UseDelegatedPrefix'             => Optional[Enum['yes','no']],
    'UseDNS'                         => Optional[Enum['yes','no']],
    'UseNTP'                         => Optional[Enum['yes','no']],
    'UseHostname'                    => Optional[Enum['yes','no']],
    'UseDomains'                     => Optional[Enum['yes','no']],
    'NetLabel'                       => Optional[Enum['yes','no']],
    'SendRelease'                    => Optional[Enum['yes','no']],
    'NFTSet'                         => Optional[String[1]],
    'WithoutRA'                      => Optional[Enum['no', 'solicit', 'information-request']],
}]
```

### <a name="Systemd--Interface--Network--Enhancedtransmissionselection"></a>`Systemd::Interface::Network::Enhancedtransmissionselection`

interface network EnhancedTransmissionSelection section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'       => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'       => Optional[String[1]],
    'Bands'        => Optional[Integer[1,16]],
    'StrictBands'  => Optional[Integer[1,16]],
    'QuantumBytes' => Optional[String[1]],
    'PriorityMap'  => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Fairqueueing"></a>`Systemd::Interface::Network::Fairqueueing`

interface network FairQueueing section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'              => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'              => Optional[String[1]],
    'PacketLimit'         => Optional[Integer[0,4294967294]],
    'FlowLimit'           => Optional[Integer[1]],
    'QuantumBytes'        => Optional[String[1]],
    'InitialQuantumBytes' => Optional[String[1]],
    'MaximumRate'         => Optional[String[1]],
    'Buckets'             => Optional[String[1]],
    'OrphanMask'          => Optional[Integer[0]],
    'Pacing'              => Optional[Enum['yes','no']],
    'CEThresholdSec'      => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Fairqueueingcontrolleddelay"></a>`Systemd::Interface::Network::Fairqueueingcontrolleddelay`

interface network FairQueueingControlledDelay section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'           => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'           => Optional[String[1]],
    'PacketLimit'      => Optional[Integer[0,4294967294]],
    'MemoryLimitBytes' => Optional[String[1]],
    'Flows'            => Optional[String[1]],
    'TargetSec'        => Optional[String[1]],
    'IntervalSec'      => Optional[String[1]],
    'QuantumBytes'     => Optional[String[1]],
    'ECN'              => Optional[Enum['yes','no']],
    'CEThresholdSec'   => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Flowqueuepie"></a>`Systemd::Interface::Network::Flowqueuepie`

interface network FlowQueuePIE section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
    'PacketLimit' => Optional[Integer[1,4294967294]],
}]
```

### <a name="Systemd--Interface--Network--Genericrandomearlydetection"></a>`Systemd::Interface::Network::Genericrandomearlydetection`

interface network GenericRandomEarlyDetection section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'               => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'               => Optional[String[1]],
    'VirtualQueues'        => Optional[Integer[1,16]],
    'DefaultVirtualQueues' => Optional[Integer[1,16]],
    'GenericRIO'           => Optional[Enum['yes','no']],
}]
```

### <a name="Systemd--Interface--Network--Heavyhitterfilter"></a>`Systemd::Interface::Network::Heavyhitterfilter`

interface network HeavyHitterFilter section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
    'PacketLimit' => Optional[Integer[0,4294967294]]
}]
```

### <a name="Systemd--Interface--Network--Hierarchytokenbucket"></a>`Systemd::Interface::Network::Hierarchytokenbucket`

interface network HierarchyTokenBucketClass section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'        => Optional[Variant[Enum['root','clsact','ingress'], String[1]]],
    'Handle'        => Optional[String[1]],
    'DefaultClass'  => Optional[String[1]],
    'RateToQuantum' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Hierarchytokenbucketclass"></a>`Systemd::Interface::Network::Hierarchytokenbucketclass`

interface network HierarchyTokenBucketClass section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'          => Optional[Variant[Enum['root'], String[1]]],
    'ClassId'         => Optional[String[1]],
    'Priority'        => Optional[String[1]],
    'QuantumBytes'    => Optional[String[1]],
    'MTUBytes'        => Optional[String[1]],
    'OverheadBytes'   => Optional[String[1]],
    'Rate'            => Optional[String[1]],
    'CeilRate'        => Optional[String[1]],
    'BufferBytes'     => Optional[String[1]],
    'CeilBufferBytes' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Ipoib"></a>`Systemd::Interface::Network::Ipoib`

interface network IPoIB section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Mode'                          => Optional[Enum['datagram','connected']],
    'IgnoreUserspaceMulticastGroup' => Optional[Enum['yes', 'no']],
}]
```

### <a name="Systemd--Interface--Network--Ipv6acceptra"></a>`Systemd::Interface::Network::Ipv6acceptra`

interface network IPv6AcceptRA section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'UseRedirect'           => Optional[Enum['yes','no']],
    'Token'                 => Optional[String[1]],
    'UseDNS'                => Optional[Enum['yes','no']],
    'UseDomains'            => Optional[Enum['yes','no']],
    'RouteTable'            => Optional[Variant[String[1],Integer[0,4294967295]]],
    'RouteMetric'           => Optional[String[1]],
    'QuickAck'              => Optional[Enum['yes','no']],
    'UseMTU'                => Optional[Enum['yes','no']],
    'UseHopLimit'           => Optional[Enum['yes','no']],
    'UseReachableTime'      => Optional[Enum['yes','no']],
    'UseRetransmissionTime' => Optional[Enum['yes','no']],
    'UseGateway'            => Optional[Enum['yes','no']],
    'UseRoutePrefix'        => Optional[Enum['yes','no']],
    'UseCaptivePortal'      => Optional[Enum['yes','no']],
    'UsePREF64'             => Optional[Enum['yes','no']],
    'UseAutonomousPrefix'   => Optional[Enum['yes','no']],
    'UseOnLinkPrefix'       => Optional[Enum['yes','no']],
    'RouterDenyList'        => Optional[String[1]],
    'RouterAllowList'       => Optional[String[1]],
    'PrefixDenyList'        => Optional[String[1]],
    'PrefixAllowList'       => Optional[String[1]],
    'RouteDenyList'         => Optional[String[1]],
    'RouteAllowList'        => Optional[String[1]],
    'DHCPv6Client'          => Optional[Enum['yes','no', 'always']],
    'NetLabel'              => Optional[String[1]],
    'NFTSet'                => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Ipv6addresslabel"></a>`Systemd::Interface::Network::Ipv6addresslabel`

interface network IPv6AddressLabel section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Label'  => Optional[Integer[0,4294967294]],
    'Prefix' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Ipv6pref64prefix"></a>`Systemd::Interface::Network::Ipv6pref64prefix`

interface network IPv6PREF64Prefix section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Prefix'       => Optional[String[1]],
    'LifetimeSec' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Ipv6prefix"></a>`Systemd::Interface::Network::Ipv6prefix`

interface network IPv6Prefix section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'AddressAutoconfiguration' => Optional[Enum['yes','no']],
    'OnLink'                   => Optional[Enum['yes','no']],
    'Prefix'                   => Optional[String[1]],
    'PreferredLifetimeSec'     => Optional[String[1]],
    'ValidLifetimeSec'         => Optional[String[1]],
    'Assign'                   => Optional[Enum['yes','no']],
    'Token'                    => Optional[String[1]],
    'RouteMetric'              => Optional[Integer[0, 4294967295]],
}]
```

### <a name="Systemd--Interface--Network--Ipv6routeprefix"></a>`Systemd::Interface::Network::Ipv6routeprefix`

interface network IPv6RoutePrefix section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Route'       => Optional[String[1]],
    'LifetimeSec' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Ipv6sendra"></a>`Systemd::Interface::Network::Ipv6sendra`

interface network IPv6SendRA section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Managed'              => Optional[Enum['yes','no']],
    'OtherInformation'     => Optional[Enum['yes','no']],
    'RouterLifetimeSec'    => Optional[String[1]],
    'ReachableTimeSec'     => Optional[String[1]],
    'RetransmitSec'        => Optional[String[1]],
    'RouterPreference'     => Optional[Enum['high', 'medium', 'low', 'normal', 'default']],
    'HopLimit'             => Optional[Integer[0,255]],
    'UplinkInterface'      => Optional[String[1]],
    'EmitDNS'              => Optional[Enum['yes','no']],
    'DNS'                  => Optional[String[1]],
    'EmitDomains'          => Optional[Enum['yes','no']],
    'Domains'              => Optional[String[1]],
    'DNSLifetimeSec'       => Optional[String[1]],
    'HomeAgent'            => Optional[Enum['yes','no']],
    'HomeAgentLifetimeSec' => Optional[String[1]],
    'HomeAgentPreference'  => Optional[Integer[0,65535]],
}]
```

### <a name="Systemd--Interface--Network--Link"></a>`Systemd::Interface::Network::Link`

interface network Link section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'MACAddress'              => Optional[String[1]],
    'MTUBytes'                => Optional[Integer[1280]],
    'ARP'                     => Optional[Enum['yes','no']],
    'Multicast'               => Optional[Enum['yes','no']],
    'AllMulticast'            => Optional[Enum['yes','no']],
    'Promiscuous'             => Optional[Enum['yes','no']],
    'Unmanaged'               => Optional[Enum['yes','no']],
    'Group'                   => Optional[Integer[0,2147483647]],
    'RequiredForOnline'       => Optional[String[1]],
    'RequiredFamilyForOnline' => Optional[Enum['no', 'ipv4', 'ipv6', 'both', 'any']],
    'ActivationPolicy'        => Optional[Enum[
        'up', 'always-up', 'manual', 'always-down', 'down', 'bound'
    ]],
}]
```

### <a name="Systemd--Interface--Network--Lldp"></a>`Systemd::Interface::Network::Lldp`

interface network LLDP section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'MUDURL' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Match"></a>`Systemd::Interface::Network::Match`

interface network Match section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'MACAddress'          => Optional[String[1]],
    'PermanentMACAddress' => Optional[String[1]],
    'Path'                => Optional[String[1]],
    'Driver'              => Optional[String[1]],
    'Type'                => Optional[String[1]],
    'Kind'                => Optional[String[1]],
    'Property'            => Optional[String[1]],
    'Name'                => Optional[String[1]],
    'WLANInterfaceType'   => Optional[Enum[
        'ad-hoc', 'station', 'ap', 'ap-vlan', 'wds', 'monitor',
        'mesh-point', 'p2p-client', 'p2p-go', 'p2p-device', 'ocb', 'nan',
        '!ad-hoc', '!station', '!ap', '!ap-vlan', '!wds', '!monitor',
        '!mesh-point', '!p2p-client', '!p2p-go', '!p2p-device', '!ocb', '!nan'
    ]],
    'SSID'                => Optional[String[1]],
    'BSSID'               => Optional[String[1]],
    'Host'                => Optional[String[1]],
    'Virtualization'      => Optional[String[1]],
    'KernelCommandLine'   => Optional[String[1]],
    'KernelVersion'       => Optional[String[1]],
    'Credential'          => Optional[String[1]],
    'Architecture'        => Optional[String[1]],
    'Firmware'            => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Neighbor"></a>`Systemd::Interface::Network::Neighbor`

interface network Neighbor section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Address'          => Optional[String[1]],
    'LinkLayerAddress' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Network"></a>`Systemd::Interface::Network::Network`

interface network Network section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Description'                        => Optional[String[1]],
    'DHCP'                               => Optional[Enum['yes', 'no', 'ipv4', 'ipv6']],
    'DHCPServer'                         => Optional[Enum['yes', 'no']],
    'LinkLocalAddressing'                => Optional[Enum['yes', 'no', 'ipv4', 'ipv6']],
    'IPv6LinkLocalAddressGenerationMode' => Optional[Enum[
        'eui64', 'none', 'stable-privacy', 'random'
    ]],
    'IPv6StableSecretAddress'            => Optional[String[1]],
    'IPv4LLStartAddress'                 => Optional[String[1]],
    'IPv4LLRoute'                        => Optional[Enum['yes', 'no']],
    'DefaultRouteOnDevice'               => Optional[Enum['yes', 'no']],
    'LLMNR'                              => Optional[Enum['yes', 'no', 'resolve']],
    'MulticastDNS'                       => Optional[Enum['yes', 'no', 'resolve']],
    'DNSOverTLS'                         => Optional[Enum['yes', 'no', 'opportunistic']],
    'DNSSEC'                             => Optional[Enum['yes', 'no', 'allow-downgrade']],
    'DNSSECNegativeTrustAnchors'         => Optional[String[1]],
    'LLDP'                               => Optional[Enum['yes', 'no', 'routers-only']],
    'EmitLLDP'                           => Optional[Enum['yes', 'no', 'nearest-bridge', 'non-tpmr-bridge', 'customer-bridge']],
    'BindCarrier'                        => Optional[String[1]],
    'Address'                            => Optional[Variant[Array[String[1]], String[1]]],
    'Gateway'                            => Optional[Variant[Array[String[1]], String[1]]],
    'DNS'                                => Optional[Variant[Array[String[1]], String[1]]],
    'UseDomains'                         => Optional[Enum['yes', 'no', 'route']],
    'DNSDefaultRoute'                    => Optional[Enum['yes', 'no']],
    'NTP'                                => Optional[Enum['yes', 'no', 'route']],
    'IPv4Forwarding'                     => Optional[Enum['yes', 'no']],
    'IPv6Forwarding'                     => Optional[Enum['yes', 'no']],
    'IPMasquerade'                       => Optional[Enum['ipv4', 'ipv6', 'both', 'no']],
    'IPv6PrivacyExtensions'              => Optional[Enum['yes', 'no', 'prefer-public', 'kernel']],
    'IPv6AcceptRA'                       => Optional[Enum['yes', 'no']],
    'IPv6DuplicateAddressDetection'      => Optional[Integer],
    'IPv6HopLimit'                       => Optional[Integer[1,255]],
    'IPv6RetransmissionTimeSec'          => Optional[Integer[0]],
    'IPv4ReversePathFilter'              => Optional[Enum['no', 'strict', 'loose']],
    'IPv4AcceptLocal'                    => Optional[Enum['yes', 'no']],
    'IPv4RouteLocalnet'                  => Optional[Enum['yes', 'no']],
    'IPv4ProxyARP'                       => Optional[Enum['yes', 'no']],
    'IPv4ProxyARPPrivateVLAN'            => Optional[Enum['yes', 'no']],
    'IPv6ProxyNDP'                       => Optional[Enum['yes', 'no']],
    'IPv6ProxyNDPAddress'                => Optional[Variant[String[1], Array[String[1]]]],
    'IPv6SendRA'                         => Optional[Enum['yes', 'no']],
    'DHCPPrefixDelegation'               => Optional[Enum['yes', 'no']],
    'IPv6MTUBytes'                       => Optional[Integer[1280]],
    'KeepMaster'                         => Optional[Enum['yes', 'no']],
    'BatmanAdvanced'                     => Optional[String[1]],
    'Bond'                               => Optional[String[1]],
    'Bridge'                             => Optional[String[1]],
    'VRF'                                => Optional[String[1]],
    'IPoIB'                              => Optional[Variant[String[1],Array[String[1]]]],
    'IPVLAN'                             => Optional[Variant[String[1],Array[String[1]]]],
    'IPVTAP'                             => Optional[Variant[String[1],Array[String[1]]]],
    'MACsec'                             => Optional[Variant[String[1],Array[String[1]]]],
    'MACVLAN'                            => Optional[Variant[String[1],Array[String[1]]]],
    'MACVTAP'                            => Optional[Variant[String[1],Array[String[1]]]],
    'Tunnel'                             => Optional[Variant[String[1],Array[String[1]]]],
    'VLAN'                               => Optional[Variant[String[1],Array[String[1]]]],
    'VXLAN'                              => Optional[Variant[String[1],Array[String[1]]]],
    'Xfrm'                               => Optional[Variant[String[1],Array[String[1]]]],
    'ActiveSlave'                        => Optional[Enum['yes', 'no']],
    'PrimarySlave'                       => Optional[Enum['yes', 'no']],
    'ConfigureWithoutCarrier'            => Optional[Enum['yes', 'no']],
    # 'IgnoreCarrierLoss'                  => Optional[Variant[Enum['yes', 'no'],Systemd::Unit::Timespan]],
    'KeepConfiguration'                  => Optional[Enum['yes', 'no', 'static', 'dhcp-on-stop', 'dhcp']],
}]
```

### <a name="Systemd--Interface--Network--Networkemulator"></a>`Systemd::Interface::Network::Networkemulator`

interface network NetworkEmulator section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'         => Optional[Variant[Enum['root', 'clsact','ingress'],String[1]]],
    'Handle'         => Optional[String[1]],
    'DelayJitterSec' => Optional[String[1]],
    'PacketLimit'    => Optional[Integer[0,4294967294]],
    'LossRate'       => Optional[String[1]],
    'DuplicateRate'  => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Nexthop"></a>`Systemd::Interface::Network::Nexthop`

interface network NextHop section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Id'        => Optional[Integer[1, 4294967295]],
    'Gateway'   => Optional[Variant[Array[String[1]], String[1]]],
    'Familiy'   => Optional[Enum['ipv4','ipv6']],
    'OnLink'    => Optional[Enum['yes','no']],
    'Blackhole' => Optional[Enum['yes','no']],
    'Group'     => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Pfifo"></a>`Systemd::Interface::Network::Pfifo`

interface network PFIFO section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
    'PacketLimit' => Optional[Integer[0,4294967294]]
}]
```

### <a name="Systemd--Interface--Network--Pfifofast"></a>`Systemd::Interface::Network::Pfifofast`

interface network PFIFOFast section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Pfifoheaddrop"></a>`Systemd::Interface::Network::Pfifoheaddrop`

interface network PFIFOHeadDrop section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
    'PacketLimit' => Optional[Integer[0,4294967294]],
}]
```

### <a name="Systemd--Interface--Network--Pie"></a>`Systemd::Interface::Network::Pie`

interface network PIE section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
    'PacketLimit' => Optional[Integer[1,4294967294]],
}]
```

### <a name="Systemd--Interface--Network--Qdisc"></a>`Systemd::Interface::Network::Qdisc`

interface network QDisc section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent' => Optional[Enum['clsact', 'ingress']],
    'Handle' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Quickfairqueueing"></a>`Systemd::Interface::Network::Quickfairqueueing`

interface network QuickFairQueueingClass section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent' => Optional[Variant[Enum['root','clsact','ingress'], String[1]]],
    'Handle' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Quickfairqueueingclass"></a>`Systemd::Interface::Network::Quickfairqueueingclass`

interface network QuickFairQueueingClass section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'         => Optional[Variant[Enum['root'], String[1]]],
    'ClassId'        => Optional[String[1]],
    'Weight'         => Optional[Integer[1,1023]],
    'MaxPacketBytes' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Route"></a>`Systemd::Interface::Network::Route`

interface network Route section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Gateway'                            => Optional[Variant[Array[String[1]], String[1]]],
    'GatewayOnLink'                      => Optional[Enum['yes', 'no']],
    'Destination'                        => Optional[String[1]],
    'Source'                             => Optional[String[1]],
    'Metric'                             => Optional[Integer[0,4294967295]],
    'IPv6Preference'                     => Optional[Enum['low','medium', 'high']],
    'Scope'                              => Optional[Enum['global', 'site', 'link', 'host', 'nowhere']],
    'PreferredSource'                    => Optional[String[1]],
    'Table'                              => Optional[Variant[String[1], Enum['default','main', 'local'], Integer[1,4294967295]]],
    'HopLimit'                           => Optional[Integer[1,255]],
    'Protocol'                           => Optional[Variant[Integer[0,255], Enum['kernel', 'boot', 'static', 'ra', 'dhcp']]],
    'Type'                               => Optional[Enum[
        'unicast', 'local', 'broadcast', 'anycast', 'multicast',
        'blackhole', 'unreachable', 'prohibit', 'throw', 'nat', 'xresolve'
    ]],
    'InitialCongestionWindow'            => Optional[Integer[0,1023]],
    'InitialAdvertisedReceiveWindow'     => Optional[Integer[0,1023]],
    'QuickAck'                           => Optional[Enum['yes', 'no',]],
    'FastOpenNoCookie'                   => Optional[Enum['yes', 'no',]],
    'MTUBytes'                           => Optional[String[1]],
    'TCPAdvertisedMaximumSegmentSize'    => Optional[String[1]],
    'TCPCongestionControlAlgorithm'      => Optional[Enum['bbr', 'dctcp', 'vegas']],
    'TCPRetransmissionTimeoutSeca'       => Optional[Integer[1]],
    'MultiPathRoute'                     => Optional[Variant[String[1],Array[String[1]]]],
    'NextHop'                            => Optional[Integer[1, 4294967295]],
}]
```

### <a name="Systemd--Interface--Network--Routingpolicyrule"></a>`Systemd::Interface::Network::Routingpolicyrule`

interface network RoutingPolicyRule section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'TypeOfService'          => Optional[Integer[0,255]],
    'From'                   => Optional[String[1]],
    'To'                     => Optional[String[1]],
    'FirewallMark'           => Optional[Variant[String[1],Integer[1, 4294967295]]],
    'Table'                  => Optional[Variant[Enum['default','main','local'],Integer[1,4294967295],String[1]]],
    'Priority'               => Optional[Integer[0,4294967295]],
    'IncomingInterface'      => Optional[String[1]],
    'OutgoingInterface'      => Optional[String[1]],
    'L3MasterDevice'         => Optional[Enum['yes','no']],
    'SourcePort'             => Optional[String[1]],
    'DestinationPort'        => Optional[String[1]],
    'IPProtocol'             => Optional[String[1]],
    'InvertRule'             => Optional[Enum['yes','no']],
    'Family'                 => Optional[Enum['ipv4', 'ipv6', 'both']],
    'User'                   => Optional[String[1]],
    'SuppressPrefixLength'   => Optional[Integer[0,128]],
    'SuppressInterfaceGroup' => Optional[Integer[0,2147483647]],
    'Type'                   => Optional[Enum['blackhole','unreachable','prohibit']],
}]
```

### <a name="Systemd--Interface--Network--Sr_iov"></a>`Systemd::Interface::Network::Sr_iov`

interface network SR-IOV section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'VirtualFunction'         => Optional[Integer[0,2147483646]],
    'VLANId'                  => Optional[Integer[1,4095]],
    'QualityOfService'        => Optional[Integer[0,4294967294]],
    'VLANProtocol'            => Optional[Enum['802.1Q', '802.1ad']],
    'MACSpoofCheck'           => Optional[Enum['no','yes']],
    'QueryReceiveSideScaling' => Optional[Enum['no','yes']],
    'Trust'                   => Optional[Enum['no','yes']],
    'LinkState'               => Optional[Enum['no','yes','auto']],
    'MACAddress'              => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Stochasticfairblue"></a>`Systemd::Interface::Network::Stochasticfairblue`

interface network StochasticFairBlue section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'      => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'      => Optional[String[1]],
    'PacketLimit' => Optional[Integer[1,4294967294]],
}]
```

### <a name="Systemd--Interface--Network--Stochasticfairnessqueueing"></a>`Systemd::Interface::Network::Stochasticfairnessqueueing`

interface network StochasticFairnessQueueing section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'           => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'           => Optional[String[1]],
    'PerturbPeriodSec' => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Tokenbucketfilter"></a>`Systemd::Interface::Network::Tokenbucketfilter`

interface network TokenBucketFilter section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'     => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'     => Optional[String[1]],
    'LatencySec' => Optional[String[1]],
    'LimitBytes' => Optional[String[1]],
    'BurstBytes' => Optional[String[1]],
    'Rate'       => Optional[String[1]],
    'MPUBytes'   => Optional[String[1]],
    'PeakRate'   => Optional[String[1]],
    'MTUBytes'   => Optional[String[1]],
}]
```

### <a name="Systemd--Interface--Network--Triviallinkequalizer"></a>`Systemd::Interface::Network::Triviallinkequalizer`

interface network TrivialLinkEqualizer section definition

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.network.html

Alias of

```puppet
Struct[{
    'Parent'        => Optional[Variant[Enum['root', 'clsact', 'ingress'], String[1]]],
    'Handle'        => Optional[String[1]],
    'DefaultClass'  => Optional[String[1]],
    'RateToQuantum' => Optional[Integer[0]]
}]
```

### <a name="Systemd--JournalRemoteSettings"></a>`Systemd::JournalRemoteSettings`

matches Systemd journal remote config Struct

Alias of

```puppet
Struct[{
    Optional['Seal']                   => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['SplitMode']              => Variant[Enum['host','none'],Systemd::JournaldSettings::Ensure],
    Optional['ServerKeyFile']          => Variant[Stdlib::Unixpath,Systemd::JournaldSettings::Ensure],
    Optional['ServerCertificateFile']  => Variant[Stdlib::Unixpath,Systemd::JournaldSettings::Ensure],
    Optional['TrustedCertificateFile'] => Variant[Stdlib::Unixpath,Systemd::JournaldSettings::Ensure],
    Optional['MaxUse']                 => Variant[Systemd::Unit::Amount,Systemd::JournaldSettings::Ensure],
    Optional['KeepFree']               => Variant[Systemd::Unit::Amount,Systemd::JournaldSettings::Ensure],
    Optional['MaxFileSize']            => Variant[Systemd::Unit::Amount,Systemd::JournaldSettings::Ensure],
    Optional['MaxFiles']               => Variant[Integer,Systemd::JournaldSettings::Ensure],
  }]
```

### <a name="Systemd--JournalUploadSettings"></a>`Systemd::JournalUploadSettings`

matches Systemd journal upload config Struct

Alias of

```puppet
Struct[{
    Optional['URL']                    => Variant[Stdlib::HTTPUrl,Systemd::JournaldSettings::Ensure],
    Optional['ServerKeyFile']          => Variant[Stdlib::Unixpath,Systemd::JournaldSettings::Ensure],
    Optional['ServerCertificateFile']  => Variant[Stdlib::Unixpath,Systemd::JournaldSettings::Ensure],
    Optional['TrustedCertificateFile'] => Variant[Stdlib::Unixpath,Systemd::JournaldSettings::Ensure],
    Optional['NetworkTimeoutSec']      => Variant[Systemd::Unit::Timespan,Systemd::JournaldSettings::Ensure],
  }]
```

### <a name="Systemd--JournaldSettings"></a>`Systemd::JournaldSettings`

Matches Systemd journald config Struct

Alias of

```puppet
Struct[{
    Optional['Storage']              => Variant[Enum['volatile','persistent','auto','none'],Systemd::JournaldSettings::Ensure],
    Optional['Compress']             => Variant[Enum['yes','no'], Systemd::Unit::Amount ,Systemd::JournaldSettings::Ensure],
    Optional['Seal']                 => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['SplitMode']            => Variant[Enum['uid','none'],Systemd::JournaldSettings::Ensure],
    Optional['RateLimitInterval']    => Variant[Pattern[/^[0-9]+(s|min|h|ms|us)?$/],Systemd::JournaldSettings::Ensure],
    Optional['RateLimitIntervalSec'] => Variant[Pattern[/^[0-9]+(s|min|h|ms|us)?$/],Systemd::JournaldSettings::Ensure],
    Optional['RateLimitBurst']       => Variant[Integer[0], Pattern[/^[0-9]+$/],Systemd::JournaldSettings::Ensure],
    Optional['SystemMaxUse']         => Variant[Systemd::Unit::AmountOrPercent,Systemd::JournaldSettings::Ensure],
    Optional['SystemKeepFree']       => Variant[Systemd::Unit::AmountOrPercent,Systemd::JournaldSettings::Ensure],
    Optional['SystemMaxFileSize']    => Variant[Systemd::Unit::AmountOrPercent,Systemd::JournaldSettings::Ensure],
    Optional['SystemMaxFiles']       => Variant[Integer[0], Pattern[/^[0-9]+$/],Systemd::JournaldSettings::Ensure],
    Optional['RuntimeMaxUse']        => Variant[Systemd::Unit::AmountOrPercent ,Systemd::JournaldSettings::Ensure],
    Optional['RuntimeKeepFree']      => Variant[Systemd::Unit::AmountOrPercent ,Systemd::JournaldSettings::Ensure],
    Optional['RuntimeMaxFileSize']   => Variant[Systemd::Unit::AmountOrPercent ,Systemd::JournaldSettings::Ensure],
    Optional['RuntimeMaxFiles']      => Variant[Integer[0], Pattern[/^[0-9]+$/],Systemd::JournaldSettings::Ensure],
    Optional['MaxFileSec']           => Variant[Pattern[/^[0-9]+(year|month|week|day|h|m)?$/],Systemd::JournaldSettings::Ensure],
    Optional['MaxRetentionSec']      => Variant[Pattern[/^[0-9]+(year|month|week|day|h|m)?$/],Systemd::JournaldSettings::Ensure],
    Optional['SyncIntervalSec']      => Variant[Pattern[/^[0-9]+(year|month|week|day|h|m)?$/],Systemd::JournaldSettings::Ensure],
    Optional['ForwardToSyslog']      => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['ForwardToKMsg']        => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['ForwardToConsole']     => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['ForwardToSocket']      => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['ForwardToWall']        => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['MaxLevelStore']        => Variant[Enum['emerg','alert','crit','err','warning','notice','info','debug'],Integer[0,7],Systemd::JournaldSettings::Ensure],
    Optional['MaxLevelSyslog']       => Variant[Enum['emerg','alert','crit','err','warning','notice','info','debug'],Integer[0,7],Systemd::JournaldSettings::Ensure],
    Optional['MaxLevelKMsg']         => Variant[Enum['emerg','alert','crit','err','warning','notice','info','debug'],Integer[0,7],Systemd::JournaldSettings::Ensure],
    Optional['MaxLevelConsole']      => Variant[Enum['emerg','alert','crit','err','warning','notice','info','debug'],Integer[0,7],Systemd::JournaldSettings::Ensure],
    Optional['MaxLevelSocket']       => Variant[Enum['emerg','alert','crit','err','warning','notice','info','debug'],Integer[0,7],Systemd::JournaldSettings::Ensure],
    Optional['MaxLevelWall']         => Variant[Enum['emerg','alert','crit','err','warning','notice','info','debug'],Integer[0,7],Systemd::JournaldSettings::Ensure],
    Optional['Audit']                => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['ReadKMsg']             => Variant[Enum['yes','no'],Systemd::JournaldSettings::Ensure],
    Optional['TTYPath']              => Variant[Stdlib::Absolutepath,Systemd::JournaldSettings::Ensure],
    Optional['LineMax']              => Variant[Systemd::Unit::Amount,Systemd::JournaldSettings::Ensure],
  }]
```

### <a name="Systemd--JournaldSettings--Ensure"></a>`Systemd::JournaldSettings::Ensure`

defines allowed ensure states for systemd-journald settings

Alias of `Struct[{ 'ensure' => Enum['present','absent'] }]`

### <a name="Systemd--LogLevel"></a>`Systemd::LogLevel`

Defines allowed log levels

Alias of `Variant[Enum['emerg','alert','crit','err','warning','notice','info','debug'], Integer[0,7]]`

### <a name="Systemd--LogindSettings"></a>`Systemd::LogindSettings`

Matches Systemd Login Manager Struct

Alias of

```puppet
Struct[{
    Optional['DesignatedMaintenanceTime']    => Variant[Systemd::Unit::Amount,Systemd::LogindSettings::Ensure],
    Optional['HandleHibernateKey']           => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleHibernateKeyLongPress']  => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleLidSwitch']              => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleLidSwitchDocked']        => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleLidSwitchExternalPower'] => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandlePowerKey']               => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandlePowerKeyLongPress']      => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleRebootKey']              => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleRebootKeyLongPress']     => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleSecureAttentionKey']     => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleSuspendKey']             => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HandleSuspendKeyLongPress']    => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['HibernateKeyIgnoreInhibited']  => Variant[Enum['yes','no'],Systemd::LogindSettings::Ensure],
    Optional['HoldoffTimeoutSec']            => Variant[Integer,Systemd::LogindSettings::Ensure],
    Optional['IdleAction']                   => Variant[Enum['ignore','poweroff','reboot','halt','kexec','suspend','hibernate','hybrid-sleep','suspend-then-hibernate','lock'],Systemd::LogindSettings::Ensure],
    Optional['IdleActionSec']                => Variant[Integer,Systemd::LogindSettings::Ensure],
    Optional['InhibitDelayMaxSec']           => Variant[Integer,Systemd::LogindSettings::Ensure],
    Optional['InhibitorsMax']                => Variant[Integer,Systemd::LogindSettings::Ensure],
    Optional['KillExcludeUsers']             => Variant[Array[String],Systemd::LogindSettings::Ensure],
    Optional['KillOnlyUsers']                => Variant[Array[String],Systemd::LogindSettings::Ensure],
    Optional['KillUserProcesses']            => Variant[Enum['yes','no'],Systemd::LogindSettings::Ensure],
    Optional['LidSwitchIgnoreInhibited']     => Variant[Enum['yes','no'],Systemd::LogindSettings::Ensure],
    Optional['NAutoVTs']                     => Variant[Integer,Systemd::LogindSettings::Ensure],
    Optional['PowerKeyIgnoreInhibited']      => Variant[Enum['yes','no'],Systemd::LogindSettings::Ensure],
    Optional['RebootKeyIgnoreInhibited']     => Variant[Enum['yes','no'],Systemd::LogindSettings::Ensure],
    Optional['RemoveIPC']                    => Variant[Enum['yes','no'],Systemd::LogindSettings::Ensure],
    Optional['ReserveVT']                    => Variant[Integer,Systemd::LogindSettings::Ensure],
    Optional['RuntimeDirectoryInodesMax']    => Variant[Systemd::Unit::Amount,Systemd::LogindSettings::Ensure],
    Optional['RuntimeDirectorySize']         => Variant[Systemd::Unit::AmountOrPercent,Systemd::LogindSettings::Ensure],
    Optional['SessionsMax']                  => Variant[Systemd::Unit::Amount,Systemd::LogindSettings::Ensure],
    Optional['SleepOperation']               => Variant[Array[Enum['suspend','hibernate','hybrid-sleep','suspend-then-hibernate']],Systemd::LogindSettings::Ensure],
    Optional['StopIdleSessionSec']           => Variant[Systemd::Unit::Amount,Systemd::LogindSettings::Ensure],
    Optional['SuspendKeyIgnoreInhibited']    => Variant[Enum['yes','no'],Systemd::LogindSettings::Ensure],
    Optional['UserStopDelaySec']             => Variant[Systemd::Unit::Amount,Systemd::LogindSettings::Ensure],
    Optional['UserTasksMax']                 => Variant[Systemd::Unit::Amount,Systemd::LogindSettings::Ensure],
  }]
```

### <a name="Systemd--LogindSettings--Ensure"></a>`Systemd::LogindSettings::Ensure`

defines allowed ensure states for systemd-logind settings

Alias of `Struct[{ 'ensure' => Enum['present','absent'] }]`

### <a name="Systemd--MachineInfoSettings"></a>`Systemd::MachineInfoSettings`

Matches Systemd machine-info (hostnamectl) file Struct

Alias of

```puppet
Struct[{
    Optional['PRETTY_HOSTNAME'] => String[1],
    Optional['ICON_NAME']       => String[1],
    Optional['CHASSIS']         => String[1],
    Optional['DEPLOYMENT']      => String[1],
    Optional['LOCATION']        => String[1],
    Optional['HARDWARE_VENDOR'] => String[1],
    Optional['HARDWARE_MODEL']  => String[1],
  }]
```

### <a name="Systemd--OomdSettings"></a>`Systemd::OomdSettings`

Configurations for oomd.conf

* **See also**
  * https://www.freedesktop.org/software/systemd/man/oomd.conf.html

Alias of

```puppet
Struct[{
    Optional['SwapUsedLimit']                    => Pattern[/^[0-9]+[%|‰|‱]$/],
    Optional['DefaultMemoryPressureLimit']       => Pattern[/^[0-9]+%$/],
    Optional['DefaultMemoryPressureDurationSec'] => Integer[0],
  }]
```

### <a name="Systemd--Output"></a>`Systemd::Output`

Used in DefaultStandardOutput/DefaultStandardError e.g.

Alias of `Enum['inherit', 'null', 'tty', 'journal', 'journal+console', 'kmsg', 'kmsg+console']`

### <a name="Systemd--ServiceLimits"></a>`Systemd::ServiceLimits`

Deprecated - Matches Systemd Service Limit Struct

Alias of

```puppet
Struct[{
    Optional['LimitCPU']            => Pattern['^\d+(s|m|h|d|w|M|y)?(:\d+(s|m|h|d|w|M|y)?)?$'],
    Optional['LimitFSIZE']          => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitDATA']           => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitSTACK']          => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitCORE']           => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitRSS']            => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitNOFILE']         => Variant[Integer[-1],Pattern['^(infinity|\d+(:(infinity|\d+))?)$']],
    Optional['LimitAS']             => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitNPROC']          => Variant[Integer[-1],Pattern['^(infinity|\d+(:(infinity|\d+))?)$']],
    Optional['LimitMEMLOCK']        => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitLOCKS']          => Integer[1],
    Optional['LimitSIGPENDING']     => Integer[1],
    Optional['LimitMSGQUEUE']       => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitNICE']           => Variant[Integer[0,40], Pattern['^(-\+([0-1]?[0-9]|20))|([0-3]?[0-9]|40)$']],
    Optional['LimitRTPRIO']         => Integer[0],
    Optional['LimitRTTIME']         => Pattern['^\d+(ms|s|m|h|d|w|M|y)?(:\d+(ms|s|m|h|d|w|M|y)?)?$'],
    Optional['CPUAccounting']       => Boolean,
    Optional['CPUShares']           => Integer[2,262144],
    Optional['StartupCPUShares']    => Integer[2,262144],
    Optional['CPUQuota']            => Pattern['^([1-9][0-9]*)%$'],
    Optional['MemoryAccounting']    => Boolean,
    Optional['MemoryLow']           => Pattern['\A(infinity|\d+(K|M|G|T|%)?(:\d+(K|M|G|T|%)?)?)\z'],
    Optional['MemoryMin']           => Pattern['\A(infinity|\d+(K|M|G|T|%)?(:\d+(K|M|G|T|%)?)?)\z'],
    Optional['MemoryHigh']          => Pattern['\A(infinity|\d+(K|M|G|T|%)?(:\d+(K|M|G|T|%)?)?)\z'],
    Optional['MemoryMax']           => Pattern['\A(infinity|\d+(K|M|G|T|%)?(:\d+(K|M|G|T|%)?)?)\z'],
    Optional['MemoryLimit']         => Pattern['\A(infinity|\d+(K|M|G|T|%)?(:\d+(K|M|G|T|%)?)?)\z'],
    Optional['MemorySwapMax']       => Pattern['\A(infinity|\d+(K|M|G|T|%)?(:\d+(K|M|G|T|%)?)?)\z'],
    Optional['TasksAccounting']     => Boolean,
    Optional['TasksMax']            => Variant[Integer[1],Pattern['^(infinity|([1-9][0-9]?$|^100)%)$']],
    Optional['IOAccounting']        => Boolean,
    Optional['IOWeight']            => Integer[1,10000],
    Optional['StartupIOWeight']     => Integer[1,10000],
    Optional['IODeviceWeight']      => Array[Hash[Stdlib::Absolutepath, Integer[1,10000], 1, 1]],
    Optional['IOReadBandwidthMax']  => Array[Hash[Stdlib::Absolutepath, Pattern['^(\d+(K|M|G|T)?)$'], 1, 1]],
    Optional['IOWriteBandwidthMax'] => Array[Hash[Stdlib::Absolutepath, Pattern['^(\d+(K|M|G|T)?)$'], 1, 1]],
    Optional['IOReadIOPSMax']       => Array[Hash[Stdlib::Absolutepath, Pattern['^(\d+(K|M|G|T)?)$'], 1, 1]],
    Optional['IOWriteIOPSMax']      => Array[Hash[Stdlib::Absolutepath, Pattern['^(\d+(K|M|G|T)?)$'], 1, 1]],
    Optional['DeviceAllow']         => String[1],
    Optional['DevicePolicy']        => Enum['auto','closed','strict'],
    Optional['Slice']               => String[1],
    Optional['Delegate']            => Boolean,
    Optional['OOMScoreAdjust']      => Integer[-1000,1000]
  }]
```

### <a name="Systemd--ServiceManagerSettings"></a>`Systemd::ServiceManagerSettings`

NOTE: Systemd::SettingEnsure here allows to delete the setting from the INI
file. See the example below for Hiera:

```yaml
systemd::system_settings:
  LogLevel:
    ensure: absent
```

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd-system.conf.html

Alias of

```puppet
Struct[{
    Optional['LogLevel'] => Variant[Systemd::LogLevel, Systemd::SettingEnsure],
    Optional['LogTarget'] => Variant[Enum['console','console-prefixed','kmsg','journal','journal-or-kmsg','auto','null'], Systemd::SettingEnsure],
    Optional['LogColor'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['LogLocation'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['LogTime'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['DumpCore'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['ShowStatus'] => Variant[Systemd::Boolean, Enum['auto','error'], Systemd::SettingEnsure],
    Optional['CrashChangeVT'] => Variant[Systemd::Boolean, Integer[1,63], Systemd::SettingEnsure],
    Optional['CrashShell'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['CrashReboot'] => Variant[Systemd::Boolean, Systemd::SettingEnsure], # Obsoleted by CrashAction in v256, delete after Debian 12 EOL
    Optional['CrashAction'] => Variant[Enum['freeze', 'reboot', 'poweroff'], Systemd::SettingEnsure],
    Optional['CtrlAltDelBurstAction'] => Variant[Enum['reboot-force','poweroff-force','reboot-immediate','poweroff-immediate','none'], Systemd::SettingEnsure],
    Optional['CPUAffinity'] => Variant[Enum['numa'], Pattern['^[0-9, -]+$'], Systemd::SettingEnsure],
    Optional['NUMAPolicy'] => Variant[Enum['default','preferred','bind','interleave','local'], Systemd::SettingEnsure],
    Optional['NUMAMask'] => Variant[Enum['all'], Pattern['^[0-9, -]+$'], Systemd::SettingEnsure],
    Optional['RuntimeWatchdogSec'] => Variant[Enum['off','default'], Systemd::Timespan, Systemd::SettingEnsure],
    Optional['RuntimeWatchdogPreSec'] => Variant[Enum['off'], Systemd::Timespan, Systemd::SettingEnsure],
    Optional['RuntimeWatchdogPreGovernor'] => Variant[Enum['noop', 'panic'], String[1], Systemd::SettingEnsure],
    Optional['RebootWatchdogSec'] => Variant[Enum['off','default'], Systemd::Timespan, Systemd::SettingEnsure],
    Optional['KExecWatchdogSec'] => Variant[Enum['off','default'], Systemd::Timespan, Systemd::SettingEnsure],
    Optional['WatchdogDevice'] => Variant[Stdlib::Absolutepath, Systemd::SettingEnsure],
    Optional['CapabilityBoundingSet'] => Variant[Systemd::Capabilities, Systemd::SettingEnsure],
    Optional['NoNewPrivileges'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['ProtectSystem'] => Variant[Enum['auto'], Systemd::Boolean, Systemd::SettingEnsure],
    Optional['SystemCallArchitectures'] => Variant[String[1], Systemd::SettingEnsure],
    Optional['TimerSlackNSec'] => Variant[Systemd::Timespan, Systemd::SettingEnsure],
    Optional['StatusUnitFormat'] => Variant[Enum['combined','description','name'], Systemd::SettingEnsure],
    Optional['DefaultTimerAccuracySec'] => Variant[Systemd::Timespan, Systemd::SettingEnsure],
    Optional['DefaultStandardOutput'] => Variant[Systemd::Output, Systemd::SettingEnsure],
    Optional['DefaultStandardError'] => Variant[Systemd::Output, Systemd::SettingEnsure],
    Optional['DefaultTimeoutStartSec'] => Variant[Systemd::Timespan, Systemd::SettingEnsure],
    Optional['DefaultTimeoutStopSec'] => Variant[Systemd::Timespan, Systemd::SettingEnsure],
    Optional['DefaultTimeoutAbortSec'] => Variant[Systemd::Timespan, Systemd::SettingEnsure],
    Optional['DefaultDeviceTimeoutSec'] => Variant[Systemd::Timespan, Systemd::SettingEnsure],
    Optional['DefaultRestartSec'] => Variant[Systemd::Timespan, Systemd::SettingEnsure],
    Optional['DefaultStartLimitIntervalSec'] => Variant[Enum['infinity'], Systemd::Timespan, Systemd::SettingEnsure],
    Optional['DefaultStartLimitBurst'] => Variant[Integer[0], Systemd::SettingEnsure],
    Optional['DefaultEnvironment'] => Variant[String, Systemd::SettingEnsure],
    Optional['ManagerEnvironment'] => Variant[String, Systemd::SettingEnsure],
    Optional['DefaultCPUAccounting'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['DefaultBlockIOAccounting'] => Variant[Systemd::Boolean, Systemd::SettingEnsure], # Deprecated in v252. Delete after Debian 11 EOL
    Optional['DefaultIOAccounting'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['DefaultIPAccounting'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['DefaultMemoryAccounting'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['DefaultTasksAccounting'] => Variant[Systemd::Boolean, Systemd::SettingEnsure],
    Optional['DefaultTasksMax'] => Variant[Enum['infinity'], Integer[0], Systemd::Unit::Percent, Systemd::SettingEnsure],
    Optional['DefaultLimitCPU'] => Variant[Enum['infinity'], Pattern['^\d+(s|m|h|d|w|M|y)?(:\d+(s|m|h|d|w|M|y)?)?$'], Systemd::SettingEnsure],
    Optional['DefaultLimitFSIZE'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitDATA'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitSTACK'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitCORE'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitRSS'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitNOFILE'] => Variant[Integer[-1], Pattern['^(infinity|\d+(:(infinity|\d+))?)$'], Systemd::SettingEnsure],
    Optional['DefaultLimitAS'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitNPROC'] => Variant[Integer[-1],Pattern['^(infinity|\d+(:(infinity|\d+))?)$'], Systemd::SettingEnsure],
    Optional['DefaultLimitMEMLOCK'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitLOCKS'] => Variant[Integer[1], Systemd::SettingEnsure],
    Optional['DefaultLimitSIGPENDING'] => Variant[Integer[1], Systemd::SettingEnsure],
    Optional['DefaultLimitMSGQUEUE'] => Variant[Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'], Systemd::SettingEnsure],
    Optional['DefaultLimitNICE'] => Variant[Integer[0,40], Pattern['^(-\+([0-1]?[0-9]|20))|([0-3]?[0-9]|40)$'], Systemd::SettingEnsure],
    Optional['DefaultLimitRTPRIO'] => Variant[Integer[0], Systemd::SettingEnsure],
    Optional['DefaultLimitRTTIME'] => Variant[Pattern['^\d+(ms|s|m|h|d|w|M|y)?(:\d+(ms|s|m|h|d|w|M|y)?)?$'], Systemd::SettingEnsure],
    Optional['DefaultOOMPolicy'] => Variant[Enum['continue', 'stop','kill'], Systemd::SettingEnsure],
    Optional['DefaultOOMScoreAdjust'] => Variant[Integer[-1000,1000], Systemd::SettingEnsure],
    Optional['DefaultSmackProcessLabel'] => Variant[String, Systemd::SettingEnsure],
    Optional['ReloadLimitIntervalSec'] => Variant[Enum['infinity'], Systemd::Timespan, Systemd::SettingEnsure],
    Optional['ReloadLimitBurst'] => Variant[Integer[0], Systemd::SettingEnsure],
    Optional['DefaultMemoryPressureWatch'] => Variant[Systemd::SettingEnsure],
    Optional['DefaultMemoryPressureThresholdSec'] => Variant[Systemd::SettingEnsure],
  }]
```

### <a name="Systemd--SettingEnsure"></a>`Systemd::SettingEnsure`

Defines allowed ensure states for an ini_setting

Alias of `Struct[{ 'ensure' => Enum['absent'] }]`

### <a name="Systemd--Timespan"></a>`Systemd::Timespan`

Defines a timespan type

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.time.html

Alias of `Variant[Integer[0], Pattern[/^([0-9]+ *(usec|us|msec|ms|seconds?|sec|s|minutes?|min|m|hours?|hr|h|days?|d|weeks?|w|months?|M|years?|y)? *)+$/]]`

### <a name="Systemd--Unit"></a>`Systemd::Unit`

custom datatype that validates different filenames for systemd units and unit templates

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.unit.html

Alias of `Pattern[/^[a-zA-Z0-9:\-_.\\@%]+\.(service|socket|device|mount|automount|swap|target|path|timer|slice|scope)$/]`

### <a name="Systemd--Unit--Amount"></a>`Systemd::Unit::Amount`

Systemd definition of amount, often bytes or united bytes
Some man pages are lagging behind and only report support up to Tera.
https://github.com/systemd/systemd/blob/main/src/basic/format-util.c
shows support for Peta and Exa.

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.service.html
  * https://www.freedesktop.org/software/systemd/man/systemd.slice.html

Alias of `Variant[Integer[0], Pattern['\A(infinity|\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)\z']]`

### <a name="Systemd--Unit--AmountOrPercent"></a>`Systemd::Unit::AmountOrPercent`

Systemd definition of amount, often bytes or united bytes

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.service.html
  * https://www.freedesktop.org/software/systemd/man/systemd.slice.html

Alias of `Variant[Systemd::Unit::Amount, Systemd::Unit::Percent]`

### <a name="Systemd--Unit--Install"></a>`Systemd::Unit::Install`

Possible keys for the [Install] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.unit.html

Alias of

```puppet
Struct[{
    Optional['Alias']      => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['WantedBy']   => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['RequiredBy'] => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['Also']       => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
  }]
```

### <a name="Systemd--Unit--Mount"></a>`Systemd::Unit::Mount`

Possible keys for the [Mount] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.mount.html

Alias of

```puppet
Struct[{
    Optional['What']           => String[1],
    Optional['Where']          => Stdlib::Unixpath,
    Optional['Type']           => String[1],
    Optional['Options']        => String[1],
    Optional['SloppyOptions']  => Boolean,
    Optional['LazyUnmount']    => Boolean,
    Optional['ReadWriteOnly']  => Boolean,
    Optional['ForceUnmount']   => Boolean,
    Optional['DirectoryMode']  => Stdlib::Filemode,
    Optional['TimeoutSec']     => String[0],
    Optional['OOMScoreAdjust'] => Integer[-1000,1000],
  }]
```

### <a name="Systemd--Unit--Path"></a>`Systemd::Unit::Path`

Possible keys for the [Path] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.path.html

Alias of

```puppet
Struct[{
    Optional['PathExists']              => Variant[Enum[''],Stdlib::Unixpath,Array[Variant[Enum[''],Stdlib::Unixpath],1]],
    Optional['PathExistsGlob']          => Variant[Enum[''],Stdlib::Unixpath,Array[Variant[Enum[''],Stdlib::Unixpath],1]],
    Optional['PathChanged']             => Variant[Enum[''],Stdlib::Unixpath,Array[Variant[Enum[''],Stdlib::Unixpath],1]],
    Optional['PathModified']            => Variant[Enum[''],Stdlib::Unixpath,Array[Variant[Enum[''],Stdlib::Unixpath],1]],
    Optional['DirectoryNotEmpty']       => Variant[Enum[''],Stdlib::Unixpath,Array[Variant[Enum[''],Stdlib::Unixpath],1]],
    Optional['Unit']                    => Systemd::Unit,
    Optional['MakeDirectory']           => Boolean,
    Optional['DirectoryMode']           => Pattern[/\A[0-7]{1,4}\z/],
    Optional['TriggerLimitIntervalSec'] => String,
    Optional['TriggerLimitBurst']       => Integer[0],
  }]
```

### <a name="Systemd--Unit--Percent"></a>`Systemd::Unit::Percent`

Systemd definition of a percentage

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.service.html
  * https://www.freedesktop.org/software/systemd/man/systemd.slice.html

Alias of `Pattern['\A([0-9][0-9]?|100)%\z']`

### <a name="Systemd--Unit--Service"></a>`Systemd::Unit::Service`

Possible keys for the [Service] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.service.html
  * https://www.freedesktop.org/software/systemd/man/systemd.exec.html

Alias of

```puppet
Struct[{
    Optional['AmbientCapabilities']       => Variant[Pattern[/^CAP_[A-Z_]+$/],Array[Pattern[/^CAP_[A-Z_]+$/],1]],
    Optional['UMask']                     => String[3,4],
    Optional['User']                      => String[1],
    Optional['Group']                     => String[1],
    Optional['DynamicUser']               => Boolean,
    Optional['SupplementaryGroups']       => Variant[String[0],Array[String[0],1]],
    Optional['WorkingDirectory']          => String[0],
    Optional['Type']                      => Enum['simple', 'exec', 'forking', 'oneshot', 'dbus', 'notify', 'idle'],
    Optional['ExitType']                  => Enum['main', 'cgroup'],
    Optional['RemainAfterExit']           => Boolean,
    Optional['GuessMainPID']              => Boolean,
    Optional['PIDFile']                   => Stdlib::Unixpath,
    Optional['BusName']                   => String[1],
    Optional['ExecStart']                 => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecStartPre']              => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecStartPost']             => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecCondition']             => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecReload']                => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecStop']                  => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecStopPost']              => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['KillSignal']                => Pattern[/^SIG[A-Z]+$/],
    Optional['KillMode']                  => Enum['control-group', 'mixed', 'process', 'none'],
    Optional['Nice']                      => Variant[String[0,0],Integer[-20,19]],
    Optional['CPUSchedulingPolicy']       => Enum['','batch','fifo','idle','other','rr'],
    Optional['IOSchedulingClass']         => Enum['','realtime','best-effort','idle'],
    Optional['IOSchedulingPriority']      => Variant[String[0,0],Integer[0,7]],
    Optional['SyslogIdentifier']          => String,
    Optional['LogLevelMax']               => Enum['emerg','alert','crit','err','warning','notice','info','debug'],
    Optional['LimitCPU']                  => Pattern['^\d+(s|m|h|d|w|M|y)?(:\d+(s|m|h|d|w|M|y)?)?$'],
    Optional['LimitFSIZE']                => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitDATA']                 => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitSTACK']                => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitCORE']                 => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitRSS']                  => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitNOFILE']               => Variant[Integer[-1],Pattern['^(infinity|\d+(:(infinity|\d+))?)$']],
    Optional['LimitAS']                   => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitNPROC']                => Variant[Integer[-1],Pattern['^(infinity|\d+(:(infinity|\d+))?)$']],
    Optional['LimitMEMLOCK']              => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitLOCKS']                => Integer[1],
    Optional['LimitSIGPENDING']           => Integer[1],
    Optional['LimitMSGQUEUE']             => Pattern['^(infinity|((\d+(K|M|G|T|P|E)?(:\d+(K|M|G|T|P|E)?)?)))$'],
    Optional['LimitNICE']                 => Variant[Integer[0,40], Pattern['^(-\+([0-1]?[0-9]|20))|([0-3]?[0-9]|40)$']],
    Optional['LimitRTPRIO']               => Integer[0],
    Optional['LimitRTTIME']               => Pattern['^\d+(ms|s|m|h|d|w|M|y)?(:\d+(ms|s|m|h|d|w|M|y)?)?$'],
    Optional['CPUAccounting']             => Boolean,
    Optional['CPUShares']                 => Integer[2,262144],
    Optional['StartupCPUShares']          => Integer[2,262144],
    Optional['CPUQuota']                  => Pattern['^([1-9][0-9]*)%$'], # bigger than 100% is okay.
    Optional['MemoryAccounting']          => Boolean,
    Optional['MemoryLow']                 => Systemd::Unit::AmountOrPercent,
    Optional['MemoryMin']                 => Systemd::Unit::AmountOrPercent,
    Optional['MemoryHigh']                => Systemd::Unit::AmountOrPercent,
    Optional['MemoryMax']                 => Systemd::Unit::AmountOrPercent,
    Optional['MemoryLimit']               => Systemd::Unit::Amount,
    Optional['MemorySwapMax']             => Systemd::Unit::AmountOrPercent,
    Optional['TasksAccounting']           => Boolean,
    Optional['TasksMax']                  => Systemd::Unit::AmountOrPercent,
    Optional['IOAccounting']              => Boolean,
    Optional['IOWeight']                  => Integer[1,10000],
    Optional['StartupIOWeight']           => Integer[1,10000],
    Optional['IODeviceWeight']            => Variant[Tuple[Stdlib::Absolutepath, Integer[1,10000]],Array[Tuple[Stdlib::Absolutepath, Integer[1,10000]]]],
    Optional['IOReadBandwidthMax']        => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['IOWriteBandwidthMax']       => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['IOReadIOPSMax']             => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['IOWriteIOPSMax']            => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['DeviceAllow']               => String[1],
    Optional['DevicePolicy']              => Enum['auto','closed','strict'],
    Optional['Slice']                     => String[1],
    Optional['Delegate']                  => Boolean,
    Optional['RestartSec']                => Variant[Integer[0],String],
    Optional['TimeoutStartSec']           => Variant[Integer[0],String],
    Optional['TimeoutStopSec']            => Variant[Integer[0],String],
    Optional['TimeoutAbortSec']           => Variant[Integer[0],String],
    Optional['TimeoutSec']                => Variant[Integer[0],String],
    Optional['TimeoutStartFailureMode']   => Enum['terminate', 'abort', 'kill'],
    Optional['TimeoutStopFailureMode']    => Enum['terminate', 'abort', 'kill'],
    Optional['RuntimeMaxSec']             => Variant[Integer[0],String],
    Optional['RuntimeRandomizedExtraSec'] => Variant[Integer[0],String],
    Optional['WatchdogSec']               => Variant[Integer[0],String],
    Optional['Restart']                   => Enum['no', 'on-success', 'on-failure', 'on-abnormal', 'on-watchdog', 'on-abort', 'always'],
    Optional['SuccessExitStatus']         => String,
    Optional['RestartPreventExitStatus']  => String,
    Optional['RestartForceExitStatus']    => String,
    Optional['RootDirectoryStartOnly']    => Boolean,
    Optional['NonBlocking']               => Boolean,
    Optional['NotifyAccess']              => Enum['none', 'default', 'main', 'exec',  'all'],
    Optional['OOMPolicy']                 => Enum['continue', 'stop','kill'],
    Optional['OOMScoreAdjust']            => Integer[-1000,1000],
    Optional['Environment']               => Variant[String[0],Array[String[1],1]],
    Optional['EnvironmentFile']           => Variant[
      Stdlib::Unixpath,Pattern[/-\/.+/],
      Array[Variant[Stdlib::Unixpath,Pattern[/-\/.+/]],1],
    ],
    Optional['StandardOutput']            => Variant[Enum['inherit','null','tty','journal','kmsg','journal+console','kmsg+console','socket'],Pattern[/\A(file:|append:|truncate:).+$\z/]],
    Optional['StandardError']             => Variant[Enum['inherit','null','tty','journal','kmsg','journal+console','kmsg+console','socket'],Pattern[/\A(file:|append:|truncate:).+$\z/]],
    Optional['StandardInput']             => Variant[Enum['null','tty','tty-force','tty-fail','data','socket'], Pattern[/\A(file:|fd:).+$\z/]],
    Optional['PrivateTmp']                => Boolean,
    Optional['RuntimeDirectory']          => String,
    Optional['RuntimeDirectoryMode']      => Stdlib::Filemode,
    Optional['StateDirectory']            => String,
    Optional['LogsDirectory']             => String,
    Optional['LogsDirectoryMode']         => Stdlib::Filemode,
    Optional['LogRateLimitIntervalSec']   => Variant[Pattern[/^[0-9]+(s|min|h|ms|us)?$/]],
    Optional['LogRateLimitBurst']         => Variant[Integer[0], Pattern[/^[0-9]+$/]],
    Optional['ProtectSystem']             => Variant[Boolean, Enum['full', 'strict']],
    Optional['ProtectHome']               => Variant[Boolean, Enum['read-only', 'tmpfs']],
    Optional['BindPaths']                 => Variant[Stdlib::Unixpath,Pattern[/-\/.+/], Array[Variant[Stdlib::Unixpath,Pattern[/-\/.+/]],1]],
    Optional['BindReadOnlyPaths']         => Variant[Stdlib::Unixpath,Pattern[/-\/.+/], Array[Variant[Stdlib::Unixpath,Pattern[/-\/.+/]],1]],
    Optional['PrivateDevices']            => Boolean,
    Optional['RemoveIPC']                 => Boolean,
    Optional['ProtectKernelModules']      => Boolean,
    Optional['ProtectKernelTunables']     => Boolean,
    Optional['ProtectControlGroups']      => Boolean,
    Optional['RestrictRealtime']          => Boolean,
    Optional['RestrictAddressFamilies']   => Variant[Enum['AF_UNIX', 'AF_INET', 'AF_INET6', 'AF_NETLINK', 'none'], Array[Enum['AF_UNIX', 'AF_INET', 'AF_INET6', 'AF_NETLINK', 'none']]],
    Optional['RestrictNamespaces']        => Variant[Boolean, Enum['ipc', 'net', 'mnt', 'pid', 'user', 'uts', 'cgroup'], Array[Enum['ipc', 'net', 'mnt', 'pid', 'user', 'uts', 'cgroup']]],
    Optional['SystemCallArchitectures']   => Variant[String, Array[String]],
    Optional['SystemCallFilter']          => Variant[String, Array[String]],
    Optional['SystemCallErrorNumber']     => String,
    Optional['ProtectClock']              => Boolean,
    Optional['PrivateUsers']              => Boolean,
    Optional['ProtectKernelLogs']         => Boolean,
    Optional['ProtectProc']               => Enum['noaccess', 'invisible', 'ptraceable', 'default'],
    Optional['ProtectHostname']           => Boolean,
    Optional['RestrictSUIDSGID']          => Boolean,
    Optional['CapabilityBoundingSet']     => Variant[String, Array[String]],
    Optional['NoNewPrivileges']           => Boolean,
    Optional['LockPersonality']           => Boolean,
    Optional['NetworkNamespacePath']      => Stdlib::Unixpath,
    Optional['MemoryDenyWriteExecute']    => Boolean,
    Optional['PAMName']                   => String,
    Optional['SetLoginEnvironment']       => Boolean,
    Optional['RootImage']                 => Stdlib::Unixpath,
    Optional['RootImageOptions']          => String,
    Optional['RootEphemeral']             => Boolean,
    Optional['RootHash']                  => String,
    Optional['LoadCredential']            => Variant[String[0],Array[String[0],1]],
    Optional['LoadCredentialEncrypted']   => Variant[String[0],Array[String[0],1]],
    Optional['SetCredential']             => Variant[String[0],Array[String[0],1]],
    Optional['SetCredentialEncrypted']    => Variant[String[0],Array[String[0],1]],
  }]
```

### <a name="Systemd--Unit--Service--Exec"></a>`Systemd::Unit::Service::Exec`

Possible strings for ExecStart, ExecStartPrep, ...

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.service.html
  * https://www.freedesktop.org/software/systemd/man/systemd.exec.html

Alias of `Variant[Enum[''], Pattern[/^[@\-:]*(\+|!|!!)?[@\-:]*\/.*/], Pattern[/^[@\-:]*(\+|!|!!)?[@\-:]*[^\/]*(\s.*)?$/]]`

### <a name="Systemd--Unit--Slice"></a>`Systemd::Unit::Slice`

Possible keys for the [Slice] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.slice.html
  * https://www.freedesktop.org/software/systemd/man/systemd.resource-control.html

Alias of

```puppet
Struct[{
    Optional['CPUAccounting']       => Boolean,
    Optional['CPUQuota']            => Pattern['^([1-9][0-9]*)%$'], # bigger than 100% is okay.
    Optional['CPUShares']           => Integer[2,262144],
    Optional['CPUWeight']           => Variant[Enum['idle'],Integer[1,10000]],
    Optional['Delegate']            => Boolean,
    Optional['DeviceAllow']         => Pattern['^(/dev/)|(char-)|(block-).*$'],
    Optional['DevicePolicy']        => Enum['auto','closed','strict'],
    Optional['IOAccounting']        => Boolean,
    Optional['IODeviceWeight']      => Variant[Tuple[Stdlib::Absolutepath, Integer[1,10000]],Array[Tuple[Stdlib::Absolutepath, Integer[1,10000]]]],
    Optional['IOReadBandwidthMax']  => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['IOReadIOPSMax']       => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['IOWeight']            => Integer[1,10000],
    Optional['IOWriteBandwidthMax'] => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['IOWriteIOPSMax']      => Variant[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount],Array[Tuple[Stdlib::Absolutepath, Systemd::Unit::Amount]]],
    Optional['IPAccounting']        => Boolean,
    Optional['MemoryAccounting']    => Boolean,
    Optional['MemoryHigh']          => Systemd::Unit::AmountOrPercent,
    Optional['MemoryLimit']         => Systemd::Unit::AmountOrPercent, # depprecated in systemd
    Optional['MemoryLow']           => Systemd::Unit::AmountOrPercent,
    Optional['MemoryMax']           => Systemd::Unit::AmountOrPercent,
    Optional['MemoryMin']           => Systemd::Unit::AmountOrPercent,
    Optional['MemorySwapMax']       => Systemd::Unit::AmountOrPercent,
    Optional['Slice']               => String[1],
    Optional['StartupCPUShares']    => Integer[2,262144],
    Optional['StartupIOWeight']     => Integer[1,10000],
    Optional['TasksAccounting']     => Boolean,
    Optional['TasksMax']            => Systemd::Unit::AmountOrPercent,
  }]
```

### <a name="Systemd--Unit--Socket"></a>`Systemd::Unit::Socket`

Possible keys for the [Socket] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.socket.html

Alias of

```puppet
Struct[{
    Optional['ListenStream']            => Variant[Stdlib::Port,String[1]],
    Optional['ListenDatagram']          => Variant[Stdlib::Port,String[1]],
    Optional['ListenSequentialPacket']  => Variant[Stdlib::Port,String[1]],
    Optional['ListenFIFO']              => Stdlib::Unixpath,
    Optional['ListenSpecial']           => Stdlib::Unixpath,
    Optional['ListenNetlink']           => String[1],
    Optional['ListenMessageQueue']      => Pattern[/\A\/.*\z/],
    Optional['ListenUSBFunction']       => Stdlib::Unixpath,
    Optional['SocketProtocol']          => Enum['udplite', 'sctp'],
    Optional['BindIPv6Only']            => Enum['default', 'both', 'ipv6-only'],
    Optional['Backlog']                 => Integer[0],
    Optional['BindToDevice']            => String[1],
    Optional['SocketUser']              => String[1],
    Optional['SocketGroup']             => String[1],
    Optional['SocketMode']              => Stdlib::Filemode,
    Optional['DirectoryMode']           => Stdlib::Filemode,
    Optional['Accept']                  => Boolean,
    Optional['Writable']                => Boolean,
    Optional['FlushPending']            => Boolean,
    Optional['MaxConnections']          => Integer[0],
    Optional['MaxConnectionsPerSource'] => Integer[0],
    Optional['KeepAlive']               => Boolean,
    Optional['KeepAliveTimeSec']        => Integer[0],
    Optional['KeepAliveIntervalSec']    => Integer[0],
    Optional['KeepAliveProbes']         => Integer[0],
    Optional['NoDelay']                 => Boolean,
    Optional['Priority']                => Integer,
    Optional['DeferAcceptSec']          => Integer[0],
    Optional['ReceiveBuffer']           => Variant[Integer[0],String[1]],
    Optional['SendBuffer']              => Variant[Integer[0],String[1]],
    Optional['IPTOS']                   => Variant[Integer,Enum['low-delay', 'throughput', 'reliability', 'low-cost']],
    Optional['IPTTL']                   => Integer[0],
    Optional['Mark']                    => String[1],
    Optional['ReusePort']               => Boolean,
    Optional['SmackLabel']              => String[1],
    Optional['SmackLabelIPIn']          => String[1],
    Optional['SmackLabelIPOut']         => String[1],
    Optional['SELinuxContextFromNet']   => Boolean,
    Optional['PipeSize']                => Variant[Integer[0],String[1]],
    Optional['FreeBind']                => Boolean,
    Optional['Transparent']             => Boolean,
    Optional['Broadcast']               => Boolean,
    Optional['PassCredentials']         => Boolean,
    Optional['PassSecurity']            => Boolean,
    Optional['PassPacketInfo']          => Boolean,
    Optional['Timestamping']            => Enum['off', 'us', 'usec', 'ns'],
    Optional['TCPCongestion']           => Enum['westwood', 'veno', 'cubic', 'lp'],
    Optional['ExecStartPre']            => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecStartPost']           => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecStopPre']             => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['ExecStopPost']            => Variant[Systemd::Unit::Service::Exec,Array[Systemd::Unit::Service::Exec,1]],
    Optional['TimeoutSec']              => String[1],
    Optional['Service']                 => Systemd::Unit,
    Optional['RemoveOnStop']            => Boolean,
    Optional['Symlinks']                => Variant[Stdlib::Unixpath,Array[Stdlib::Unixpath,1]],
    Optional['FileDescriptorName']      => String[1,255],
    Optional['TriggerLimitIntervalSec'] => String[1],
    Optional['TriggerLimitBurst']       => Integer[0],
    Optional['OOMScoreAdjust']          => Integer[-1000,1000],
  }]
```

### <a name="Systemd--Unit--Swap"></a>`Systemd::Unit::Swap`

Possible keys for the [Swap] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/latest/systemd.swap.html

Alias of

```puppet
Struct[{
    Optional['What']           => String[1],
    Optional['Options']        => String[1],
    Optional['Priority']       => Integer,
    Optional['TimeoutSec']     => Variant[Integer[0],String[0]],
    Optional['OOMScoreAdjust'] => Integer[-1000,1000],
  }]
```

### <a name="Systemd--Unit--Timer"></a>`Systemd::Unit::Timer`

Possible keys for the [Timer] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.timer.html

Alias of

```puppet
Struct[{
    Optional['OnActiveSec']        => Systemd::Unit::Timespan,
    Optional['OnBootSec']          => Systemd::Unit::Timespan,
    Optional['OnStartUpSec']       => Systemd::Unit::Timespan,
    Optional['OnUnitActiveSec']    => Systemd::Unit::Timespan,
    Optional['OnUnitInactiveSec']  => Systemd::Unit::Timespan,
    Optional['OnCalendar']         => Systemd::Unit::Timespan,
    Optional['AccuracySec']        => Variant[Integer[0],String],
    Optional['RandomizedDelaySec'] => Variant[Integer[0],String],
    Optional['FixedRandomDelay']   => Boolean,
    Optional['OnClockChange']      => Boolean,
    Optional['OnTimezoneChange']   => Boolean,
    Optional['Unit']               => Systemd::Unit,
    Optional['Persistent']         => Boolean,
    Optional['WakeSystem']         => Boolean,
    Optional['RemainAfterElapse']  => Boolean,
  }]
```

### <a name="Systemd--Unit--Timespan"></a>`Systemd::Unit::Timespan`

Timer specification for systemd time spans, e.g. timers.

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.time.html

Alias of `Variant[Integer[0], String, Array[Variant[Integer[0],String]]]`

### <a name="Systemd--Unit--Unit"></a>`Systemd::Unit::Unit`

Possible keys for the [Unit] section of a unit file

* **See also**
  * https://www.freedesktop.org/software/systemd/man/systemd.unit.html

Alias of

```puppet
Struct[{
    Optional['Description']                 => Variant[String,Array[String,1]],
    Optional['Documentation']               => Variant[String,Array[String,1]],
    Optional['Wants']                       => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['Requires']                    => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['Requisite']                   => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['BindsTo']                     => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['PartOf']                      => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['Upholds']                     => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['Conflicts']                   => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['Before']                      => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['After']                       => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['OnFailure']                   => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['OnSuccess']                   => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['PropagatesReloadTo']          => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['ReloadPropagatedFrom']        => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['PropagatesStopTo']            => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['StopPropagatedFrom']          => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['JoinsNamespaceOf']            => Variant[Enum[''],Systemd::Unit,Array[Variant[Enum[''],Systemd::Unit],1]],
    Optional['RequiresMountsFor']           => Variant[Enum[''],Stdlib::Unixpath,Array[Variant[Enum[''],Stdlib::Unixpath],1]],
    Optional['OnSuccessJobMode']            => Enum['fail', 'replace', 'replace-irreversibly', 'isolate', 'flush', 'ignore-dependencies', 'ignore-requirements'],
    Optional['OnFailureJobMode']            => Enum['fail', 'replace', 'replace-irreversibly', 'isolate', 'flush', 'ignore-dependencies', 'ignore-requirements'],
    Optional['IgnoreOnIsolate']             => Boolean,
    Optional['StopWhenUnneeded']            => Boolean,
    Optional['RefuseManualStart']           => Boolean,
    Optional['RefuseManualStop']            => Boolean,
    Optional['AllowIsolate']                => Boolean,
    Optional['DefaultDependencies']         => Boolean,
    Optional['SurviveFinalKillSignal']      => Boolean,
    Optional['CollectMode']                 => Enum['inactive', 'inactive-or-failed'],
    Optional['FailureAction']               => Enum['none', 'reboot', 'reboot-force', 'reboot-immediate', 'poweroff', 'poweroff-force', 'poweroff-immediate', 'exit', 'exit-force', 'soft-reboot', 'soft-reboot-force', 'kexec', 'kexec-force', 'halt', 'halt-force', 'halt-immediate'],
    Optional['SuccessAction']               => Enum['none', 'reboot', 'reboot-force', 'reboot-immediate', 'poweroff', 'poweroff-force', 'poweroff-immediate', 'exit', 'exit-force', 'soft-reboot', 'soft-reboot-force', 'kexec', 'kexec-force', 'halt', 'halt-force', 'halt-immediate'],
    Optional['FailureActionExitStatus']     => Variant[Enum[''],Integer[0, 255]],
    Optional['SuccessActionExitStatus']     => Variant[Enum[''],Integer[0, 255]],
    # Conditions and Asserts
    Optional['AssertPathExists']            => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['AssertPathIsDirectory']       => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionPathExists']         => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionPathExistsGlob']     => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionPathIsDirectory']    => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionPathIsSymbolicLink'] => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionPathIsMountPoint']   => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionPathIsReadWrite']    => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionPathIsEncrypted']    => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionFileNotEmpty']       => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['ConditionFileIsExecutable']   => Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/],Array[Variant[Enum[''],Stdlib::Unixpath,Pattern[/^!.*$/]],1]],
    Optional['StartLimitIntervalSec']       => String[1],
    Optional['StartLimitBurst']             => Integer[1],
  }]
```

## Tasks

### <a name="systemctl_show"></a>`systemctl_show`

Get systemctl show output of a unit

**Supports noop?** false

#### Parameters

##### `bin_path`

Data type: `String[1]`

Path to systemctl binary

##### `properties`

Data type: `Array[String[1]]`

Properties to retrieve from the unit

##### `unit_name`

Data type: `String[1]`

Name of the unit

